function MakeFig3_10()
% Function to reproduce Fig. 3.10
% Propagation/decay lengths (normalized to the wavelength) for surface
% modes for a silver/air (left) and a gold/air (right) planar interface. 
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

%%%%%%%%%%%%%%%%%%
% Computations
%%%%%%%%%%%%%%%%%%

% wavelengths (column)
lambda=transpose(200:2:1500); 

% epsilon
% metals: silver and gold
eAg=epsAg(lambda); % column
eAu=epsAu(lambda); % column
% dielectric (air here)
eM=1.0; % scalar

% Get kx from dispersion relation (Eq. 3.15)
k0=2*pi./lambda; % column
kxAg=k0.*sqrt(eM*eAg./(eM+eAg));
kxAu=k0.*sqrt(eM*eAu./(eM+eAu));

% Get propagation length LSPP from Eq. 3.16
LSPPAg=0.5./abs(imag(kxAg));
LSPPAu=0.5./abs(imag(kxAu));

% Get k1z outside (in air) and k2z inside (the metal)
% using Eq. F.9/F.10
% These are only valid up to a sign, which is irrelevant here
% see Fig. 3.7 and Sec. F.2.5 for more detail on this point
k1zOutAg=sqrt(k0.^2*eM-kxAg.^2);
k2zInAg=sqrt(k0.^2.*eAg-kxAg.^2);

k1zOutAu=sqrt(k0.^2*eM-kxAu.^2);
k2zInAu=sqrt(k0.^2.*eAu-kxAu.^2);

% Get decay lengths L1z outside (in air) and L2z inside (the metal)
L1zOutAg=0.5./abs(imag(k1zOutAg));
L2zInAg=0.5./abs(imag(k2zInAg));

L1zOutAu=0.5./abs(imag(k1zOutAu));
L2zInAu=0.5./abs(imag(k2zInAu));


%%%%%%%%%%%%%%%%%%
% Drawing
%%%%%%%%%%%%%%%%%%

% create, position, and resize figure
scrsz = get(0,'ScreenSize'); % scrsz(3) contains screen width
figAspectRatio=3;
figWidth=3/4*scrsz(3);
figure('Name','Fig. 3.10', ...
    'Position',[(scrsz(3)-figWidth)/2 scrsz(4)-150-figWidth/figAspectRatio figWidth figWidth/figAspectRatio]);

% plot for Ag/air
subplot(1,2,1);
semilogy(lambda,LSPPAg./lambda,'-',lambda,L1zOutAg./lambda,':',lambda,L2zInAg./lambda,'--');
% format graph
axis([200 1500 0.005 500]);
xlabel('Wavelength [nm]');
ylabel('L/\lambda');
legend('L_{SPP}/\lambda','L_{1z}/\lambda','L_{2z}/\lambda','Location','Best');
title('Propagation/decay lengths - PSPPs on air/silver interface');
set(gca,'YGrid','on','YMinorGrid','off','GridLineStyle','-');

% plot for Ag/air
subplot(1,2,2);
semilogy(lambda,LSPPAu./lambda,'-',lambda,L1zOutAu./lambda,':',lambda,L2zInAu./lambda,'--');
% format graph
axis([200 1500 0.005 500]);
xlabel('Wavelength [nm]');
ylabel('L/\lambda');
legend('L_{SPP}/\lambda','L_{1z}/\lambda','L_{2z}/\lambda','Location','Best');
title('Propagation/decay lengths - PSPPs on air/gold interface');
set(gca,'YGrid','on','YMinorGrid','off','GridLineStyle','-');




