function MakeFig3_14a()
% Function to reproduce Fig. 3.14(a)
% Angle dependence of the reflection coefficient at three wavelengths
% (514, 633, 1000 nm) for coupling to PSPPs at a silver/water interface
% with a sapphire prism using the Otto ATR configuration.
% Thickness of water layer is 500 nm.
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

%%%%%%%%%%%%%%%%%%
% Computations
%%%%%%%%%%%%%%%%%%

% lambda in nm (column)
lambda=[514; 633; 1000]; % column [3 x 1]

% angles in degrees (row)
aideg=48:0.005:60; % row [1 x 2401]

% gap thickness
Lgap=500; % in nm

% calculate epsilon for silver
eAg=epsAg(lambda);
% refractive indices
nP=1.766; % Sapphire - Prism
nM=1.33; % Water - Dielectric for PSPPs

% Defines Otto configuration, 2 interfaces, 3 layers
% Prism/Dielectric/Metal
% all epsilons must be columns (lambda dependent)
nNbSurf=2;
Cepsilon{1}=nP^2+0*lambda; % Prism
Cepsilon{2}=nM^2+0*lambda; % Dielectric for PSPP
Cepsilon{3}=eAg; % Metal
CL{1}=0; % interfaces positions
CL{2}=Lgap;

% solves the problem for TM waves
stResTM=PlnMultiRef ('TM',nNbSurf, lambda, Cepsilon, CL, aideg);


%Reflectivity (reflection coefficient $R^p=|r^p|^2$)
% Rp is matrix [3 x 2401]
Rp=abs(stResTM.rP).^2;


%%%%%%%%%%%%%%%%%%
% Drawing
%%%%%%%%%%%%%%%%%%

% create, position, and resize figure
scrsz = get(0,'ScreenSize'); % scrsz(3) contains screen width
figAspectRatio=1.5;
figWidth=3/4*scrsz(3);
figure('Name','Fig. 3.14(a)', ...
    'Position',[(scrsz(3)-figWidth)/2 scrsz(4)-150-figWidth/figAspectRatio figWidth figWidth/figAspectRatio]);

% create plot 
plot(aideg,Rp(1,:),aideg,Rp(2,:),aideg,Rp(3,:));
title('Water/Ag PSPP excitation in the Otto configuration - L_{gap}=500 nm');
% format graph
axis([48 58 0 1.15]);
xlabel('angle of incidence [degrees]');
ylabel('Reflectivity');
legend('\lambda=514 nm','\lambda=633 nm','\lambda=1000 nm','Location','East');





