function MakeFig3_14b()
% Function to reproduce Fig. 3.14(b)
% Angle dependence of the reflection coefficient at 633 nm for three
% dielectric refractive index close to water (nM=1.32, 1.33, or 1.34),
% for coupling to PSPPs at a silver/water interface with a sapphire prism
% using the Otto ATR configuration.
% Thickness of dielectric layer is 500 nm.
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

%%%%%%%%%%%%%%%%%%
% Computations
%%%%%%%%%%%%%%%%%%

% lambda in nm 
lambda=633; % [1 x 1]

% angles in degrees (row)
aideg=50:0.005:55; % row [1 x 1001]

% gap thickness
Lgap=500; % in nm

% calculate epsilon for silver
eAg=epsAg(lambda);
% refractive indices
nP=1.766; % Sapphire - Prism
nM={1.32, 1.33, 1.34}; % cell of 3 scalars
nNbnM=length(nM);

% Initialize reflectivity cell Rp (one cell element for each nM)
Rp=cell(1,nNbnM);

% Defines Otto configuration, 2 interfaces, 3 layers
% Prism/Dielectric/Metal
% all epsilons are scalar here (one lambda only)
nNbSurf=2;
Cepsilon{1}=nP^2+0*lambda; % Prism
Cepsilon{3}=eAg; % Metal
CL{1}=0; % interfaces positions
CL{2}=Lgap;

% loop through each possible nM
for ii=1:nNbnM
    Cepsilon{2}=nM{ii}^2+0*lambda; % Dielectric for PSPP
    % solves the problem for TM waves
    stResTM=PlnMultiRef ('TM',nNbSurf, lambda, Cepsilon, CL, aideg);
    % extract reflectivity for this nM: rP is [1 x 1001]
    Rp{ii}=abs(stResTM.rP).^2;
end

%%%%%%%%%%%%%%%%%%
% Drawing
%%%%%%%%%%%%%%%%%%

% create, position, and resize figure
scrsz = get(0,'ScreenSize'); % scrsz(3) contains screen width
figAspectRatio=1.5;
figWidth=3/4*scrsz(3);
figure('Name','Fig. 3.14(b)', ...
    'Position',[(scrsz(3)-figWidth)/2 scrsz(4)-150-figWidth/figAspectRatio figWidth figWidth/figAspectRatio]);

% create plot 
plot(aideg,Rp{1},aideg,Rp{2},aideg,Rp{3});
title('Dielectric/Ag PSPP excitation in the Otto configuration - L_{gap}=500 nm, \lambda=633 nm');
% format graph
axis([50.5 55 0 1.15]);
xlabel('angle of incidence [degrees]');
ylabel('Reflectivity');
legend('n_M=1.32','n_M=1.33','n_M=1.34','Location','East');





