function MakeFig3_14c()
% Function to reproduce Fig. 3.14(c)
% Wavelength-dependence of the reflection coefficient at theta_inc=53 for three
% dielectric refractive index close to water (nM=1.32, 1.33, or 1.34),
% for coupling to PSPPs at a silver/dielectric interface with a sapphire prism
% using the Kretschmann ATR configuration.
% Thickness of metal layer is 50 nm.
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

%%%%%%%%%%%%%%%%%%
% Computations
%%%%%%%%%%%%%%%%%%

% lambda in nm (column)
lambda=transpose(500:0.5:800); % [601 x 1]

% angles in degrees 
aideg=53; % [1 x 1]

% metal thickness
Lmetal=50; % in nm

% calculate epsilon for silver
eAg=epsAg(lambda);
% refractive indices
nP=1.766; % Sapphire - Prism
nM={1.32, 1.33, 1.34}; % cell of 3 scalars
nNbnM=length(nM);

% Initialize reflectivity cell Rp (one cell element for each nM)
Rp=cell(1,nNbnM);

% Defines Krestschmann configuration, 2 interfaces, 3 layers
% Prism/Metal/Dielectric
% all epsilons are column (lambda-dependent)
nNbSurf=2;
Cepsilon{1}=nP^2+0*lambda; % Prism
Cepsilon{2}=eAg; % Metal
CL{1}=0; % interfaces positions
CL{2}=Lmetal;

% loop through each possible nM
for ii=1:nNbnM
    Cepsilon{3}=nM{ii}^2+0*lambda; % Dielectric for PSPP
    % solves the problem for TM waves
    stResTM=PlnMultiRef ('TM',nNbSurf, lambda, Cepsilon, CL, aideg);
    % extract reflectivity for this nM: rP is [601 x 1]
    Rp{ii}=abs(stResTM.rP).^2;
end

%%%%%%%%%%%%%%%%%%
% Drawing
%%%%%%%%%%%%%%%%%%

% create, position, and resize figure
scrsz = get(0,'ScreenSize'); % scrsz(3) contains screen width
figAspectRatio=1.5;
figWidth=3/4*scrsz(3);
figure('Name','Fig. 3.14(c)', ...
    'Position',[(scrsz(3)-figWidth)/2 scrsz(4)-150-figWidth/figAspectRatio figWidth figWidth/figAspectRatio]);

% create plot 
plot(lambda,Rp{1},lambda,Rp{2},lambda,Rp{3});
title('Dielectric/Ag PSPP excitation in the Kretschmann configuration - L_{metal}=50 nm, \theta_{inc}=53^\circ');
% format graph
axis([500 800 0 1.15]);
xlabel('Wavelength [nm]');
ylabel('Reflectivity');
legend('n_M=1.32','n_M=1.33','n_M=1.34','Location','East');





