function MakeFig3_14d()
% Function to reproduce Fig. 3.14(d)
% Wavelength-dependence of the reflection coefficient at theta_inc=36
% for coupling to PSPPs at a silver/air interface with a sapphire prism
% using the Kretschmann ATR configuration. The effect of an adsorbate layer
% of varying thickness L_{ads} and refractive index nA=1.5 is modeled using
% a four-layer configuration: prism/metal/adsorbate/dielectric.
% Thickness of metal layer is 50 nm.
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

%%%%%%%%%%%%%%%%%%
% Computations
%%%%%%%%%%%%%%%%%%

% lambda in nm (column)
lambda=transpose(500:0.5:1000); % [1001 x 1]

% angles in degrees 
aideg=36; % [1 x 1]

% metal thickness
Lmetal=50; % in nm
% thickness of adsorbed layer (in nm)
Lads={0,1,2,3,5,10,50}; % cell of scalar elements
nNbLads=length(Lads);

% calculate epsilon for silver
eAg=epsAg(lambda);
% refractive indices
nP=1.766; % Sapphire - Prism
nA=1.5; % Oil - Adsorbate layer ("effective refractive index")
nM=1.0; % air - Dielectric


% Initialize cell for reflectivity Rp (one cell element for each Lads)
Rp=cell(1,nNbLads);

% Defines Krestschmann configuration with adsorbed layer, 3 interfaces, 4 layers
% Prism/Metal/Adsorbate/Dielectric
% all epsilons are column (lambda-dependent)
nNbSurf=3;
Cepsilon{1}=nP^2+0*lambda; % Prism
Cepsilon{2}=eAg; % Metal
Cepsilon{3}=nA^2+0*lambda; % Adosrbed layer
Cepsilon{4}=nM^2+0*lambda; % Dielectric for PSPP
CL{1}=0; % interfaces positions
CL{2}=Lmetal; % Metal thickness


% loop through each possible nM
for ii=1:nNbLads
    CL{3}=Lads{ii}; % Adsorbate layer thickness
    % solves the problem for TM waves
    stResTM=PlnMultiRef ('TM',nNbSurf, lambda, Cepsilon, CL, aideg);
    % extract reflectivity for this Lads: rP is [1001 x 1]
    Rp{ii}=abs(stResTM.rP).^2;
end

%%%%%%%%%%%%%%%%%%
% Drawing
%%%%%%%%%%%%%%%%%%

% create, position, and resize figure
scrsz = get(0,'ScreenSize'); % scrsz(3) contains screen width
figAspectRatio=1.5;
figWidth=3/4*scrsz(3);
figure('Name','Fig. 3.14(d)', ...
    'Position',[(scrsz(3)-figWidth)/2 scrsz(4)-150-figWidth/figAspectRatio figWidth figWidth/figAspectRatio]);

% create plot 
plot(lambda,Rp{1},lambda,Rp{2},lambda,Rp{3},lambda,Rp{4},lambda,Rp{5},lambda,Rp{6},lambda,Rp{7});
title('Air/Ag PSPP excitation in the Kretschmann configuration with an adsorbed layer - L_{metal}=50 nm, \theta_{inc}=36^\circ');
% format graph
axis([500 1000 0 1.15]);
xlabel('Wavelength [nm]');
ylabel('Reflectivity');
legend('L_{ads}=0 nm','L_{ads}=1 nm','L_{ads}=2 nm','L_{ads}=3 nm', ...
    'L_{ads}=5 nm','L_{ads}=10 nm','L_{ads}=50 nm','Location','East');





