function MakeFig3_15b()
% Function to reproduce Fig. 3.15(b)
% Angle dependence of the reflection coefficient and local field intensity
% EF at 633 nm for coupling to PSPPs at a silver/air interface with a sapphire
% prism using the Kretschmann ATR configuration.
% Thickness of metal layer is 50 nm.
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

%%%%%%%%%%%%%%%%%%
% Computations
%%%%%%%%%%%%%%%%%%

% lambda in nm 
lambda=633; % [1 x 1]

% angles in degrees (row)
aideg=34.5:0.005:37; % row [1 x 601]

% metal thickness
Lmetal=50; % in nm

% calculate epsilon for silver
eAg=epsAg(lambda); % [1 x 1]
% refractive indices
nP=1.766; % Sapphire - Prism
nM=1.0; % Air - Dielectric for PSPPs

% Defines Kretschmann configuration, 2 interfaces, 3 layers
% Prism/Metal/Dielectric
nNbSurf=2;
Cepsilon{1}=nP^2+0*lambda; % Prism
Cepsilon{2}=eAg; % Metal
Cepsilon{3}=nM^2+0*lambda; % Dielectric for PSPP
CL{1}=0; % interfaces positions
CL{2}=Lmetal;

% solves the problem for TM waves
stResTM=PlnMultiRef ('TM',nNbSurf, lambda, Cepsilon, CL, aideg);


% Reflectivity (reflection coefficient $R^p=|r^p|^2$)
% Rp is row [1 x 601]
Rp=abs(stResTM.rP).^2;
% Local field EF on metal/air interface, i.e. interface 2, on the air side
% MLoc is row [1 x 601]
MLoc=stResTM.MinPerp{2}+stResTM.MinPara{2};

% Local field EF from Eq. 3.27 [1 x 601]
MLocEq3_27=2*abs(eAg)/(nM^2 * imag(eAg)) * imag(eAg*sqrt(1/(eAg+nM^2)))*nP*cos(aideg*pi/180).*(1-Rp);

%%%%%%%%%%%%%%%%%%
% Drawing
%%%%%%%%%%%%%%%%%%

% create, position, and resize figure
scrsz = get(0,'ScreenSize'); % scrsz(3) contains screen width
figAspectRatio=1.5;
figWidth=3/4*scrsz(3);
figure('Name','Fig. 3.15(b)', ...
    'Position',[(scrsz(3)-figWidth)/2 scrsz(4)-150-figWidth/figAspectRatio figWidth figWidth/figAspectRatio]);

line(aideg,Rp,'Color','b');
ax1 = gca;
set(ax1,'XColor','k','YColor','b')
set(ax1,'XLimMode','Manual','YLimMode','Manual');
set(ax1,'XLim',[34.5 37],'YLim',[0 1.15]);
set(get(ax1,'XLabel'),'String','Angle of incidence [degrees]');
set(get(ax1,'YLabel'),'String','Reflectivity');
legend('R','Location','NorthWest');
title('Air/Ag PSPP excitation in the Kretschmann configuration - L_{metal}=50 nm, \lambda=633 nm');

ax2=axes('Position',get(ax1,'Position'),...
           'XAxisLocation','top','XColor','k', ...
           'YAxisLocation','right','Ycolor','r', ...
           'Color','none', ...
           'YScale','Log', ...
           'XTickLabel',{}, ...
           'XLimMode','Manual','YLimMode','Manual', ... 
           'XLim',[34.5 37],'YLim',[0.2 800]);
set(get(ax2,'Ylabel'),'String','Local field intensity EF');

line(aideg,MLoc,'Color','r');
indMarker=10:20:length(aideg);
line(aideg(indMarker),MLocEq3_27(indMarker),'Color','r','Marker','o','LineStyle','none');
legend({'M_{Loc}','M_{Loc} from Eq. 3.27'},'Location','SouthEast','Color','w');
       

