function MakeFig4_2()
% Function to reproduce Fig. 4.2
% Example of local field intensity enhancement factor (LFIEF) on the
% surface (at d=1 nm) of a glass and silver sphere of radius 25 nm.
% Note that the third column (dimer) cannot be reproduced with these codes.
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

%%%%%%%%%%%%%%%%%%
% Computations
%%%%%%%%%%%%%%%%%%

global noCheckSum;
noCheckSum=true; % no check for numerical problems (much faster)
% noCheckSum=false; % to check for numerical problems with Mie

% N_{max} for Mie series
nNmax=50; 

% sphere radius in nm
a=25;

% wavelengths (column)
lambda=transpose(300:1:600);

% dielectric constant of outside medium (real positive)
epsilonM=1.0; % air

% create, position, and resize figure
scrsz = get(0,'ScreenSize'); % scrsz(3) contains screen width
figAspectRatio=3;
figWidth=3/4*scrsz(3);
figure('Name','Fig. 4.2', ...
    'Position',[(scrsz(3)-figWidth)/2 scrsz(4)-150-figWidth/figAspectRatio figWidth figWidth/figAspectRatio]);

% distance of point from sphere in nm
d=1;

eGlass=2.25; % glass
eAg=epsAg(lambda);

% Solve problems using Mie theory
stMGlass=PweSolveSingleSphere(nNmax,a,lambda,epsilonM,eGlass,'noplot','coeff');
stMAg=PweSolveSingleSphere(nNmax,a,lambda,epsilonM,eAg,'noplot','coeff');
% all necessary results are in structures stM
% Note that this results in numerical problems for Q_{Ext}
% for the glass (non-absorbing) sphere.
% These are irrelevant since Q_{Ext}=Q_{Sca} in that case.


% define point where LFIEF is calculated
stPtA=struct('x',a+d,'y',0,'z',0);
% Calculate LFIEF at pt A
stEptGlass=PweEpts(lambda,epsilonM,stMGlass,stPtA,'Outside');
stEptAg=PweEpts(lambda,epsilonM,stMAg,stPtA,'Outside');
 


%%%%%%%%%%%%%%%%%%
% Drawing
%%%%%%%%%%%%%%%%%%

% Glass sphere
subplot(1,2,1);
plot(lambda,stEptGlass.MLoc);
axis([275 625 2.25 2.81]);
title('Glass sphere in air - a=25nm');
xlabel('Wavelength [nm]');
ylabel('M_{Loc}(A)');
    
% Glass sphere
subplot(1,2,2);
semilogy(lambda,stEptAg.MLoc);
axis([275 625 0.5 4000]);
title('Silver sphere in air - a=25nm');
xlabel('Wavelength [nm]');
ylabel('M_{Loc}(A)');
