function MakeFig4_3()
% Function to reproduce Fig. 4.3
% Example of modification of dipole emission on the surface (at d=1 nm)
% of a glass and silver sphere of radius 25 nm.
% Note that the third column (dimer) cannot be reproduced with these codes.
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

%%%%%%%%%%%%%%%%%%
% Computations
%%%%%%%%%%%%%%%%%%

global noCheckSum;
noCheckSum=true; % no check for numerical problems (much faster)
% noCheckSum=false; % to check for numerical problems with Mie

% N_{max} for Mie series
nNmax=50; 
% N_{max} for Mtot in the ESA (not used here)
nNmaxESA=50; 

% sphere radius in nm
a=25;
% distance of dipole from sphere in nm
d=1;

% wavelengths (column)
lambda=transpose(300:1:600);

% dielectric constant of outside medium (real positive)
epsilonM=1.0; % air

% create, position, and resize figure
scrsz = get(0,'ScreenSize'); % scrsz(4) contains screen height
figAspectRatio=1;
figHeight=scrsz(4)-150;
figWidth=figAspectRatio*figHeight;
figure('Name','Fig. 4.3', ...
    'Position',[(scrsz(3)-figWidth)/2 50 figWidth figHeight]);

% loop twice for Ag and Glass
for gg=1:2

    % wavelength-dependent dielectric function of sphere material
    % vector column, same size as lambda [L x 1] or scalar
    if gg==1
        epsilonIn=2.25; % glass
        sTitle='Glass sphere in air';
        sYscale='linear';
        axScale=[275 625 0.3 2.8];
        sLegLoc='East';
    else
        epsilonIn=epsAg(lambda); % silver
        sTitle='Silver sphere in air';
        sYscale='log';
        axScale=[275 625 0.09 600];
        sLegLoc='NorthEast';
end
    
    % Solve problem for all wavelength using Mie theory
    stMdip=DipSolveSingleSphere(nNmax,a,lambda,epsilonM,epsilonIn,d,nNmaxESA,'noplot','coeff');
    % all necessary results are in structure stMdip

    % Calculate radiation profiles (for all lambda here, even if not needed
    % for the plots)
    nNbTheta=361;
    stEfarAllP=DipFarFieldAllP(stMdip,nNbTheta);
    theta=stEfarAllP.theta;
    % create negative theta for a 2pi plot
    indNegTheta=length(theta):-1:2;
    indAllTheta=[indNegTheta,1:length(theta)];
    % substract pi/2 from all to rotate graph as in Fig. 4.2
    thetaAll=[-theta(indNegTheta), theta] - pi/2;
    
    %%%%%%%%%%%%%%%%%%
    % Drawing
    %%%%%%%%%%%%%%%%%%

    % plot MRad
    subplot(3,2,gg);
    plot(lambda,stMdip.MRadPerp,lambda,stMdip.MRadPara);
    set(gca,'YScale',sYscale);
    axis(axScale);
    title(sTitle);
    legend({'M_{Rad}^{perp}','M_{Rad}^{//}'},'Location',sLegLoc);
    xlabel('Wavelength [nm]');
    ylabel('M_{Rad}');
    
    % plot radiation profile modification, M^d_Rad,
    % for lambda=360 for perpendicular dipole
    indlambda=find(lambda==360);
    subplot(3,2,2+gg);
    polar(thetaAll,stEfarAllP.MdRadPerpAllPhi(indlambda,indAllTheta));
    ylabel('M^{d-Perp}_{Rad}');
    title([sTitle '- \lambda=360nm - M^{Perp}_{Rad}=' ...
        num2str(stMdip.MRadPerp(indlambda))]);

    % plot radiation profile modification, M^d_Rad,
    % for lambda=360 for perpendicular dipole
    subplot(3,2,4+gg);
    polar(thetaAll,stEfarAllP.MdRadParaPhi0(indlambda,indAllTheta));
    ylabel('M^{d-Para}_{Rad}');
    title([sTitle '- \lambda=360nm - M^{Para}_{Rad}=' ...
        num2str(stMdip.MRadPara(indlambda))]);

end