function MakeFig6_10a()
% Function to reproduce Fig. 6.10(a)
% Spatial distribution of the local field,
% characterized by the enhancement factor log10(MLoc) (left),
% and the proportion of the normal component |Eperp|2/|ELoc|2 (right),
% computed at the quadrupolar LSP resonance of a 50 nm radius silver
% sphere in water at 393 nm.
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

global noCheckSum;
noCheckSum=true; % no check for numerical problems (much faster)
% noCheckSum=false; % to check for numerical problems with Mie

% N_{max} for Mie series
nNmax=50; % same for all plots

% dielectric constant of outside medium (real positive)
epsilonM=1.77; % water (same for all plots)

% create, position, and resize figure
scrsz = get(0,'ScreenSize'); % scrsz(4) contains screen height
figAspectRatio=2;
figWidth=3/4*scrsz(3);
figure('Name','Fig. 6.10(a)', ...
    'Position',[(scrsz(3)-figWidth)/2 scrsz(4)-150-figWidth/figAspectRatio figWidth figWidth/figAspectRatio]);

nNbTheta=31; % = T
theta=transpose(linspace(0,pi,nNbTheta)); % col [T x 1]
nNbPhi=nNbTheta;
phi=linspace(-pi,pi,nNbPhi); % row [1 x F]
% point coordinates on sphere, matrices [T x F]
xs=sin(theta) * cos(phi); 
ys=sin(theta) * sin(phi); 
zs=repmat(cos(theta),1,nNbPhi); 

% wavelenght in nm
lambda=393; 
% dielectric function of sphere material
% vector column, same size as lambda [1 x 1] here
epsilonIn=epsAg(lambda); % silver

% sphere radius in nm
a=50;

% Solve problem using Mie theory
stM=PweSolveSingleSphere(nNmax,a,lambda,epsilonM,epsilonIn,'noplot','coeff');
% all necessary results are in structure stM
% stM contains fields cn1 and dn1
% calculate field for all points on the surface (just outside)
stEsurf=PweEsurf(lambda,epsilonM,stM,a,nNbTheta,'Outside');
    
% theta dependence
Ecr2=transpose(abs(stEsurf.Ecr).^2); % col [T x 1]
Ec2=Ecr2+transpose(abs(stEsurf.Ect).^2); % col [T x 1]
Es2=transpose(abs(stEsurf.Esf).^2); % col [T x 1]

% phi-and-theta dependence
% these are matrices [T x F]
MLoc=Ec2 * (cos(phi).^2) + Es2 * (sin(phi).^2); 
MLocPerp=Ecr2 * (cos(phi).^2);
    
% plot results

hpl1=subplot(1,2,1);
set(hpl1,'Outerposition',[0,0,0.5,1]);
% main surface plot
surf(xs,ys,zs,log10(MLoc));
axis tight; axis equal; axis off;
colormap gray; colorbar('eastOutside','fontsize',8);
set(hpl1,'CameraViewAngle',8.5);
hold on;
line([-1.6;1.6], [0;0],[0;0],'LineStyle','--','Color','k');
line([0;0],[-1.8;1.8], [0;0],'LineStyle','--','Color','k');
line([0;0],[0;0],[-1.4;1.4], 'LineStyle','--','Color','k');
quiver3(-1.7,0,0,0.5,0,0,'k');
text(-1.55,-0.1,-0.07,'\bf E_0');
quiver3(-1.7,0,0,0,0,0.5,'k');
text(-1.9,0,0.3,'\bf k');
text(-0.9,0,1.85,'\bf log_{10}( M_{Loc}=|E_{Loc}|^2/|E_{Inc}|^2 )');
ht=title('Silver sphere in water - a=50nm - \lambda=393 nm');
set(ht,'Position',get(ht,'Position')+[1.4 -1.1 0]);
hold off;
    
hpl2=subplot(1,2,2);
set(hpl2,'Outerposition',[0.5,0,0.5,1])
surf(xs,ys,zs,MLocPerp./MLoc);
axis tight; axis equal;axis off;
colormap gray; colorbar('eastOutside','fontsize',8);
set(hpl2,'CameraViewAngle',8.5);
hold on;
line([-1.6;1.6], [0;0],[0;0],'LineStyle','--','Color','k');
line([0;0],[-1.8;1.8], [0;0],'LineStyle','--','Color','k');
line([0;0],[0;0],[-1.4;1.4], 'LineStyle','--','Color','k');
quiver3(-1.7,0,0,0.5,0,0,'k');
text(-1.55,-0.1,-0.07,'\bf E_0');
quiver3(-1.7,0,0,0,0,0.5,'k');
text(-1.9,0,0.3,'\bf k');
text(-0.6,0,1.85,'\bf |E^{Perp}_{Loc}|^2/|E_{Loc}|^2');
hold off;
