function MakeFig6_10b()
% Function to reproduce Fig. 6.10(b)
% Wavelength dependence of the LFIEF at several points on the sphere
% surface for a 50 nm radius silver sphere in water.
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

%%%%%%%%%%%%%%%%%%%
% Computations
%%%%%%%%%%%%%%%%%%%

global noCheckSum;
noCheckSum=true; % no check for numerical problems (much faster)
% noCheckSum=false; % to check for numerical problems with Mie

% N_{max} for Mie series
nNmax=50; % same for all plots

% dielectric constant of outside medium (real positive)
epsilonM=1.77; % water (same for all plots)

% wavelenght in nm
%lambda=transpose(350:1:700); 
lambda=transpose(200:1:1000); 
% dielectric function of sphere material
% vector column, same size as lambda [L x 1]
epsilonIn=epsAg(lambda); % silver

% sphere radius in nm
a=50;

% Solve problem using Mie theory
stM=PweSolveSingleSphere(nNmax,a,lambda,epsilonM,epsilonIn,'noplot','coeff');
% all necessary results are in structure stM

% calculate field on the surface for exterior points
% % points can be defined in spherical coordinates as follows
% stPtA=struct('r',a,'theta',pi/2,'phi',0);
% stPtBC=struct('r',a,'theta',pi/4,'phi',pi/2);
% stPtAC=struct('r',a,'theta',pi/4,'phi',0);
% stPtACp=struct('r',a,'theta',3*pi/4,'phi',0);

% Note that points can also be defined in Cartesian as follows:
stPtA=struct('x',a,'y',0,'z',0);
stPtBC=struct('x',0,'y',a/sqrt(2),'z',a/sqrt(2));
stPtAC=struct('x',a/sqrt(2),'y',0,'z',a/sqrt(2));
stPtACp=struct('x',a/sqrt(2),'y',0,'z',-a/sqrt(2));

% Note that the plot for ptBC in incorrect in the book, it
% instead corresponds to point ABC defined as
% stPtABC=struct('r',a,'theta',pi/4,'phi',pi/4);

% outside points, stM already contains fields cn1 and dn1
stPtArray=[stPtA,stPtBC,stPtAC,stPtACp];
stEptsOut=PweEpts(lambda,epsilonM,stM,stPtArray,'Outside');

%%%%%%%%%%%%%%%%%%%
% Drawing
%%%%%%%%%%%%%%%%%%%

% create, position, and resize figure
scrsz = get(0,'ScreenSize'); % scrsz(4) contains screen height
figAspectRatio=1.5;
figWidth=3/4*scrsz(3);
figure('Name','Fig. 6.10(b)', ...
    'Position',[(scrsz(3)-figWidth)/2 scrsz(4)-150-figWidth/figAspectRatio figWidth figWidth/figAspectRatio]);

 
% plot results
hg=semilogy(lambda,stEptsOut(1).MLoc,'-', ...
        lambda,stEptsOut(2).MLoc,':', ...
        lambda,stEptsOut(3).MLoc,'-', ...
        lambda,stEptsOut(4).MLoc,'--');
set(hg(1),'LineWidth',1.5);
axis([350 700 2 300]);
title('Silver sphere (a=50nm) in water');
legend({'A','BC','AC','AC'''});
xlabel('Wavelength [nm]');
ylabel('M_{Loc}');
end