function MakeFig6_11()
% Function to reproduce Fig. 6.11
% Wavelength dependence of the average LFIEF and SERS EF on the sphere surface
% for several cases from Mie theory.
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

global noCheckSum;
noCheckSum=true; % no check for numerical problems (much faster)
% noCheckSum=false; % to check for numerical problems with Mie

% N_{max} for Mie series
nNmax=50; % same for all plots

% dielectric constant of outside medium (real positive)
epsilonM=1.77; % water (same for all plots)

% create, position, and resize figure
scrsz = get(0,'ScreenSize'); % scrsz(4) contains screen height
figAspectRatio=1.2;
figHeight=scrsz(4)-150;
figWidth=figAspectRatio*figHeight;
figure('Name','Fig. 6.11', ...
    'Position',[(scrsz(3)-figWidth)/2 50 figWidth figHeight]);

% radii (in nm)
aArray=[10,25,50,50];
sTitle={'Silver (a=10 nm) in water', ...
    'Silver (a=25 nm) in water', ...
    'Silver (a=50 nm) in water', ...
    'Gold (a=50 nm) in water'};
CYscale={[0.5 4000], [0.5 500], ...
    [0.5 300], [2 100]};

lambdamin=[300,300,300,300];
lambdamax=[600,600,800,800];


% loop through each of the four plots to create
for nn=1:4
    % wavelengths (column)
    lambda=transpose(lambdamin(nn):1:lambdamax(nn)); 
    
    if (nn<=3) % for silver
        % wavelength-dependent dielectric function of sphere material
        % vector column, same size as lambda [L x 1]
        epsilonIn=epsAg(lambda); % silver
    else % for gold
        % wavelength-dependent dielectric function of sphere material
        % vector column, same size as lambda [L x 1]
        epsilonIn=epsAu(lambda); % gold
    end

    % sphere radius in nm
    a=aArray(nn);

    % Solve problem using Mie theory
    stM=PweSolveSingleSphere(nNmax,a,lambda,epsilonM,epsilonIn,'noplot','coeff');
    % all necessary results are in structure stM
    
    % calculate field for all points on the surface (just outside) and averages 
    nNbTheta=721; % must be odd here to get MLoc(A)
    stEsurf=PweEsurf(lambda,epsilonM,stM,a,nNbTheta,'Outside');
    
    % MLoc(A) is obtained for theta=pi/2, phi=0, i.e.
    indtpiov2=(nNbTheta+1)/2;
    MLocA=abs(stEsurf.Ecr(:,indtpiov2)).^2+ ...
        abs(stEsurf.Ect(:,indtpiov2)).^2; % [L x 1]
    
    % plot results
    subplot(2,2,nn);
    hg=semilogy(lambda,MLocA,'--', ...
        lambda,stEsurf.MLocAve,'-', ...
        lambda,sqrt(stEsurf.F0E4Ave),'-');
    set(hg(3),'LineWidth',1.5);
    axis([[lambdamin(nn) lambdamax(nn)] CYscale{nn}]);
	title(sTitle{nn});
    legend({'M_{Loc}(A)','<M_{Loc}>','(<F^0_{E4}>)^{1/2}'},'Location','SouthEast');
    xlabel('Wavelength [nm]');
    ylabel('Enhancement Factor');
end