function MakeFig6_12()
% Function to reproduce Fig. 6.12
% Distance dependence of punctual and  average SERS EF on the sphere surface
% for several cases from the ES approximation and Mie theory.
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

global noCheckSum;
noCheckSum=true; % no check for numerical problems (much faster)
% noCheckSum=false; % to check for numerical problems with Mie

% N_{max} for Mie series
nNmax=50; % same for all plots

% dielectric constant of outside medium (real positive)
epsilonM=1.77; % water (same for all plots)

% create, position, and resize figure
scrsz = get(0,'ScreenSize'); % scrsz(4) contains screen height
figAspectRatio=1.2;
figHeight=scrsz(4)-150;
figWidth=figAspectRatio*figHeight;
figure('Name','Fig. 6.12', ...
    'Position',[(scrsz(3)-figWidth)/2 50 figWidth figHeight]);

% radii (in nm)
aArray=[30,25,50,50];
sTitle={'Silver (a=30) in water - ESA', ...
    'Silver (a=25 nm) in water - \lambda=418nm (dipolar LSP)', ...
    'Silver (a=50 nm) in water - \lambda=492nm (dipolar LSP)', ...
    'Silver (a=50 nm) in water - \lambda=393nm (quadrupolar LSP)'};

% fist lambda (ESA) is irrelevant
lambdaArray=[0, 418, 492, 393];

% start with first plot (ESA)
a=30;
dVec=transpose(0:0.5:10); % [D x 1]
FESA=1./(1+dVec/a).^12;
% coverage dependence
covVec=transpose(1:1:21);
FintESA=0*covVec;
FintESA(1)=FESA(1);
for nn=2:length(covVec)
    FintESA(nn)=FintESA(nn-1)+FESA(nn);
end;

% plot results
axtmp=subplot(2,2,1);
postmp=get(axtmp,'Position');
delete(axtmp);
ax1=axes('Position',postmp, ...
       'XAxisLocation','bottom','Xcolor','b', ...
       'YAxisLocation','left','Ycolor','b', ...
       'XLim',[0 10],'YLim',[0 1.1]);
set(get(ax1,'XLabel'),'String','Distance, d [nm]');
set(get(ax1,'YLabel'),'String','SERS EF (normalized to d=0)');

line(dVec,FESA,'Color','b','LineStyle','-');

ax2=axes('Position',get(ax1,'Position'),...
       'XAxisLocation','top','XColor','r', ...
       'YAxisLocation','right','Ycolor','r', ...
       'Color','none', ...
       'YScale','linear', ...
       'YLim',[0 7.8],'XLim',[1 21]);
set(get(ax2,'XLabel'),'String','Coverage [monolayer], for d_L=0.5 nm');
set(get(ax2,'YLabel'),'String','SERS intensity [=1 for first layer]');

line(covVec,FintESA,'Color','r','LineStyle','-');
title(sTitle{1});

nNbTheta=721; % must be 4n+1 here to get MLoc(AC)
% distance from surface (in nm)
dVec=transpose(linspace(0,10,11)); % [D x 1]

% loop through each of the three other plots to create
for nn=2:4
    % wavelength (scalar here)
    lambda=lambdaArray(nn); 
    
    % wavelength-dependent dielectric function of sphere material
    % vector column, same size as lambda, scalar [1 x 1] here
    epsilonIn=epsAg(lambda); % silver

    % sphere radius in nm
    a=aArray(nn);

    % Solve problem using Mie theory
    stM=PweSolveSingleSphere(nNmax,a,lambda,epsilonM,epsilonIn,'noplot','coeff');
    % all necessary results are in structure stM
    
    % calculate distance-dependence field and surface averages for all points
    % on a r=a+d surface
    rVec=a+dVec; %[D x 1]
    stEmap=PweEmap(lambda,epsilonM,stM,rVec,nNbTheta,'Outside');
    
    % F(A) is obtained for theta=pi/2, phi=0, i.e.
    indtpiov2=(nNbTheta+1)/2;
    FA=(abs(stEmap.Ecr(:,indtpiov2)).^2+ ...
        abs(stEmap.Ect(:,indtpiov2)).^2).^2; % [D x 1]
    % F(C) is obtained for theta=0, phi=0, i.e.
    FC1=(abs(stEmap.Ecr(:,1)).^2+ ...
        abs(stEmap.Ect(:,1)).^2).^2; % [D x 1]
    % F(AC) is obtained for theta=pi/4, phi=0, i.e.
    indtpiov4=(nNbTheta+3)/4;
    FAC=(abs(stEmap.Ecr(:,indtpiov4)).^2+ ...
        abs(stEmap.Ect(:,indtpiov4)).^2).^2; % [D x 1]
    
    % plot results
    subplot(2,2,nn);
    if (nn==4) % plot F(AC) instead of F(C)
        hg=plot(dVec,FA./FA(1),'-^', ...
            dVec,FAC./FAC(1),'-s', ...
            dVec,stEmap.F0E4Ave./stEmap.F0E4Ave(1),'-o');
        legend({'F^0_{E4}(A)','F^0_{E4}(AC)','<F^0_{E4}>'},'Location','NorthEast');
    else
        hg=plot(dVec,FA./FA(1),'-^', ...
            dVec,FC1./FC1(1),'-s', ...
            dVec,stEmap.F0E4Ave./stEmap.F0E4Ave(1),'-o');
        legend({'F^0_{E4}(A)','F^0_{E4}(C)','<F^0_{E4}>'},'Location','NorthEast');
    end
    set(hg(3),'MarkerFaceColor',get(hg(3),'Color'));
    axis([0 10 0 1.1]);
	title(sTitle{nn});
    xlabel('Distance, d [nm]');
    ylabel('SERS EF (normalized to d=0)');
end