function MakeFig6_13()
% Function to reproduce Fig. 6.13
% (a) Modification of dipole emission for a perpendicular
% dipole at a distance d=1nm from a silver sphere
% of radius a=10, 25, or 50 nm in water.
% (b)Same for a=25 nm, for both perpendicular and parallel dipoles
% at a distance d=1, 2, or 5 nm.
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

%%%%%%%%%%%%%%%%%%
% Computations
%%%%%%%%%%%%%%%%%%

global noCheckSum;
noCheckSum=true; % no check for numerical problems (much faster)
% noCheckSum=false; % to check for numerical problems with Mie

% N_{max} for Mie series
nNmax=50; 
% N_{max} for Mtot in the ESA (necessary fo good convergence of M_{Tot}
nNmaxESA=500; 

% wavelengths (column)
lambda=transpose(250:1:650);

% dielectric constant of outside medium (real positive)
epsilonM=1.77; % water

% wavelength-dependent dielectric function of sphere material
% vector column, same size as lambda [L x 1]
epsilonIn=epsAg(lambda); % silver

% Solve problems for all wavelength using Mie theory
% for a=10nm, 25nm, and 50nm for d=1, d=2, and d=5 nm
stMdipA10d1=DipSolveSingleSphere(nNmax,10,lambda,epsilonM,epsilonIn,1,nNmaxESA,'noplot','nocoeff');
stMdipA25d1=DipSolveSingleSphere(nNmax,25,lambda,epsilonM,epsilonIn,1,nNmaxESA,'noplot','nocoeff');
stMdipA25d2=DipSolveSingleSphere(nNmax,25,lambda,epsilonM,epsilonIn,2,nNmaxESA,'noplot','nocoeff');
stMdipA25d5=DipSolveSingleSphere(nNmax,25,lambda,epsilonM,epsilonIn,5,nNmaxESA,'noplot','nocoeff');
stMdipA50d1=DipSolveSingleSphere(nNmax,50,lambda,epsilonM,epsilonIn,1,nNmaxESA,'noplot','nocoeff');
% all necessary results are in structures stMdip

%%%%%%%%%%%%%%%%%%
% Drawing
%%%%%%%%%%%%%%%%%%

% create, position, and resize figure
scrsz = get(0,'ScreenSize'); % scrsz(4) contains screen height
figAspectRatio=1;
figHeight=scrsz(4)-150;
figWidth=figAspectRatio*figHeight;
figure('Name','Fig. 6.13', ...
    'Position',[(scrsz(3)-figWidth)/2 50 figWidth figHeight]);

% plot Eta_{Rad}^{EM} for perp dipole (d=1nm)
subplot(2,2,1);
semilogy(lambda,stMdipA10d1.MRadPerp./stMdipA10d1.MTotPerp, '-', ...
    lambda,stMdipA25d1.MRadPerp./stMdipA25d1.MTotPerp, '-', ...
    lambda,stMdipA50d1.MRadPerp./stMdipA50d1.MTotPerp, '-');
axis([250 650 2e-4 0.2]);
title('Modified quantum yield \eta_{Rad}^{Perp} for d=1 nm');
legend({'a=10nm','a=25nm','a=50nm'},'Location','NorthEast');
xlabel('Wavelength [nm]');
ylabel('\eta_{Rad}^{Perp}');

% plot M_{Rad} and M_{Tot} for perp dipole (d=1nm)
subplot(2,2,3);
h=semilogy(lambda,stMdipA10d1.MTotPerp, '-', ...
    lambda,stMdipA25d1.MTotPerp, '-', ...
    lambda,stMdipA50d1.MTotPerp, '-');
axis([250 650 0.1 1e6]);
title('Decay rate EFs for d=1 nm (Perp dipole)');
xlabel('Wavelength [nm]');
ylabel('Decay Rate EFs');
legend({'a=10nm','a=25nm','a=50nm'},'Location','NorthEast');
line(lambda,stMdipA10d1.MRadPerp, 'LineStyle','-','Color',get(h(1),'Color'));
line(lambda,stMdipA25d1.MRadPerp, 'LineStyle','-','Color',get(h(2),'Color'));
line(lambda,stMdipA50d1.MRadPerp, 'LineStyle','-','Color',get(h(3),'Color'));
text(280,1e5,0,'M_{Tot}^{Perp}');
text(280,10,0,'M_{Rad}^{Perp}');

% plot for a=25nm, Eta_{Rad}^{EM} for perp and para dipole (d=1,2,5 nm)
subplot(2,2,2);
h=semilogy(lambda,stMdipA25d1.MRadPerp./stMdipA25d1.MTotPerp, '-', ...
    lambda,stMdipA25d2.MRadPerp./stMdipA25d2.MTotPerp, '-', ...
    lambda,stMdipA25d5.MRadPerp./stMdipA25d5.MTotPerp, '-');
line(lambda,stMdipA25d1.MRadPara./stMdipA25d1.MTotPara, 'LineStyle','--','Color',get(h(1),'Color'));
line(lambda,stMdipA25d2.MRadPara./stMdipA25d2.MTotPara, 'LineStyle','--','Color',get(h(2),'Color'));
line(lambda,stMdipA25d5.MRadPara./stMdipA25d5.MTotPara, 'LineStyle','--','Color',get(h(3),'Color'));
axis([250 650 2e-4 0.99]);
title('Modified quantum yield for a=25 nm');
legend({'d=1nm - Perp','d=2nm - Perp','d=5nm - Perp', ...
    'd=1nm - Para','d=2nm - Para','d=5nm - Para'},'Location','South');
xlabel('Wavelength [nm]');
ylabel('\eta_{Rad}^{Perp}');



% plot M_{Rad} and M_{Tot} for perp dipole (d=1nm)
subplot(2,2,4);
h=semilogy(lambda,stMdipA25d1.MTotPerp, '-', ...
    lambda,stMdipA25d2.MTotPerp, '-');
line(lambda,stMdipA25d1.MTotPara, 'LineStyle','--','Color',get(h(1),'Color'));
line(lambda,stMdipA25d2.MTotPara, 'LineStyle','--','Color',get(h(2),'Color'));
line(lambda,stMdipA25d1.MRadPerp, 'LineStyle','-','Color',get(h(1),'Color'));
line(lambda,stMdipA25d2.MRadPerp, 'LineStyle','-','Color',get(h(2),'Color'));
line(lambda,stMdipA25d1.MRadPara, 'LineStyle','--','Color',get(h(1),'Color'));
line(lambda,stMdipA25d2.MRadPara, 'LineStyle','--','Color',get(h(2),'Color'));
axis([250 650 0.1 1e6]);
title('Decay rate EFs for a=25 nm');
xlabel('Wavelength [nm]');
ylabel('Decay Rate EFs');
legend({'d=1nm - Perp','d=2nm - Perp','d=1nm - Para','d=2nm - Para'}, ...
    'Location','NorthEast');
text(280,1e5,0,'M_{Tot}');
text(280,10,0,'M_{Rad}');
