function MakeFig6_14()
% Function to reproduce Fig. 6.14
% (a) distance dependence of various EFs relevant to SEF near a silver
% sphere in water at the dipolar LSP resonance (418 nm)
% (b) wavelength dependence of the average approximate fluorescence
% EF for a perpendicular or parallel dipole at a distance d=1,2, and 5nm
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

%%%%%%%%%%%%%%%%%
% Computations
%%%%%%%%%%%%%%%%%

global noCheckSum;
noCheckSum=true; % no check for numerical problems (much faster)
% noCheckSum=false; % to check for numerical problems with Mie

% wavelengths (column)
lambda=418;

% N_{max} for Mie series
nNmax=50;
% N_{max} for Mtot in the ESA (necessary fo good convergence of M_{Tot}
nNmaxESA=500; 

% sphere radius in nm
a=25;

% dielectric constant of outside medium (real positive)
epsilonM=1.77; % water

% wavelength-dependent dielectric function of sphere material
% vector column, same size as lambda [L x 1]
epsilonIn=epsAg(lambda); % silver

dArray=[0.1 0.2 0.25:0.25:15];
nNbD=length(dArray);
etaRadPerp=zeros(1,nNbD);
etaRadPara=zeros(1,nNbD);
stPtArray=[];
% Solve dipole emission problems for each distance using Mie theory
% at lambda=418
for indd=1:nNbD
    d=dArray(indd);
    stMdip=DipSolveSingleSphere(nNmax,a,lambda,epsilonM,epsilonIn,d,nNmaxESA,'noplot','nocoeff');

    etaRadPerp(indd)=stMdip.MRadPerp./stMdip.MTotPerp;
    etaRadPara(indd)=stMdip.MRadPara./stMdip.MTotPara;
    % create point array for PWE calculations in the same loop
    stPtArray=[stPtArray, struct('x',a+d,'y',0,'z',0), struct('x',0,'y',0,'z',a+d)];
end
% Solve PWE excitation problem at lambda=418 mn
stM=PweSolveSingleSphere(nNmax,a,lambda,epsilonM,epsilonIn,'noplot','coeff');
% Calculate LFIEF at all relevant points
stEpts=PweEpts(lambda,epsilonM,stM,stPtArray,'Outside');

MLocPerpA=zeros(1,nNbD);
MLocParaC=zeros(1,nNbD);
for indd=1:nNbD
    MLocPerpA(indd)=abs(stEpts(2*indd-1).Er).^2;
    MLocParaC(indd)=abs(stEpts(2*indd).Etheta).^2+abs(stEpts(2*indd).Ephi).^2;
end
MFluoPerpA=MLocPerpA.*etaRadPerp;
MFluoParaC=MLocParaC.*etaRadPara;


% Solve dipole emission problem for all wavelength for d=1, 2, and 5 nm
lambda=transpose(300:1:650); 
epsilonIn=epsAg(lambda); % silver

stMdipD1=DipSolveSingleSphere(nNmax,a,lambda,epsilonM,epsilonIn,1,nNmaxESA,'noplot','nocoeff');
stMdipD2=DipSolveSingleSphere(nNmax,a,lambda,epsilonM,epsilonIn,2,nNmaxESA,'noplot','nocoeff');
stMdipD5=DipSolveSingleSphere(nNmax,a,lambda,epsilonM,epsilonIn,5,nNmaxESA,'noplot','nocoeff');

% Solve PWE problem for all wavelength 
stM=PweSolveSingleSphere(nNmax,a,lambda,epsilonM,epsilonIn,'noplot','coeff');
% computes surface averaged properties (in particular <F>)
% at various distances
nNbTheta=721; % nb of theta for averages
stEsurf=PweSurfProperties(stM,a+1,nNbTheta);
F0E4PerpAveD1=stEsurf.F0E4PerpAve;
F0E4ParaAveD1=stEsurf.F0E4ParaAve;
stEsurf=PweSurfProperties(stM,a+2,nNbTheta);
F0E4PerpAveD2=stEsurf.F0E4PerpAve;
F0E4ParaAveD2=stEsurf.F0E4ParaAve;
stEsurf=PweSurfProperties(stM,a+5,nNbTheta);
F0E4PerpAveD5=stEsurf.F0E4PerpAve;
F0E4ParaAveD5=stEsurf.F0E4ParaAve;
clear stEsurf stM;

% computes average Fluo EF for relevant cases
MFluoPerpD1=F0E4PerpAveD1./stMdipD1.MTotPerp;
MFluoParaD1=F0E4ParaAveD1./stMdipD1.MTotPara;
MFluoPerpD2=F0E4PerpAveD2./stMdipD2.MTotPerp;
MFluoParaD2=F0E4ParaAveD2./stMdipD2.MTotPara;
MFluoPerpD5=F0E4PerpAveD5./stMdipD5.MTotPerp;
MFluoParaD5=F0E4ParaAveD5./stMdipD5.MTotPara;

%%%%%%%%%%%%%%%%%
% Drawing
%%%%%%%%%%%%%%%%%

% create, position, and resize figure
scrsz = get(0,'ScreenSize'); % scrsz(3) contains screen width
figAspectRatio=2.5;
figWidth=7/8*scrsz(3);
figure('Name','Fig. 6.14', ...
    'Position',[(scrsz(3)-figWidth)/2 scrsz(4)-150-figWidth/figAspectRatio figWidth figWidth/figAspectRatio]);

% plot distance dependence
axtmp=subplot(1,2,1);
postmp=get(axtmp,'Position');
delete(axtmp);
    
ax1=axes('Position',postmp,...
       'XAxisLocation','bottom','Xcolor','k', ...
       'YAxisLocation','left','Ycolor','b', ...
       'XLim',[-0.5 14.9],'YLim',[1 1000], ...
       'YScale','log');
set(get(ax1,'XLabel'),'String','Distance from surface, d [nm]');
set(get(ax1,'YLabel'),'String','Enhancement Factor');

line(dArray,MLocPerpA,'Color','c','LineStyle','-');
line(dArray,MFluoPerpA,'Color','b','LineStyle','-');
line(dArray,MLocParaC,'Color','c','LineStyle',':');
line(dArray,MFluoParaC,'Color','b','LineStyle',':');

legend({'M_{Loc}^{Perp}(A)','M_{Fluo}^{Perp}(A)', ...
    'M_{Loc}^{Para}(C)','M_{Fluo}^{Para}(C)'},'Location','SouthEast');

title('EFs and modified quatum yield for a silver sphere (a=25nm) in water');

axes('Position',get(ax1,'Position'),...
       'XAxisLocation','top','XColor','k', ...
       'YAxisLocation','right','Ycolor','r', ...
       'Color','none', ...
       'YScale','log', ...
       'YLim',[2e-4 1],'XLim',[-0.5 14.9], ...
       'XTickLabel',[]);
line(dArray,etaRadPerp,'Color','r','LineStyle','-');
line(dArray,etaRadPara,'Color','r','LineStyle',':');

legend({'\eta_{Rad}^{Perp}','\eta_{Rad}^{Para}'},'Location','NorthEast','Color','w');

% plot lambda dependence
subplot(1,2,2);
semilogy(lambda,MFluoPerpD1,'b-', lambda,MFluoParaD1,'b:', ...
    lambda,MFluoPerpD2,'g-', lambda,MFluoParaD2,'g:', ...
    lambda,MFluoPerpD5,'r-', lambda,MFluoParaD5,'r:');
axis([300 650 0.02 25]);
xlabel('Wavelength [nm]');
ylabel('Average Fluorescence EF');
legend({'d=1nm - Perp','d=1nm - Para', ...
    'd=2nm - Perp','d=2nm - Para', ...
    'd=5nm - Perp','d=5nm - Para'}, ...
    'Location','NorthEast');
title('Average Fluorescence EFs for a silver sphere (a=25nm) in water');

