function MakeFig6_15()
% Function to reproduce Fig. 6.15
% Spheroid's aspect ratio dependence of the geometrical factors
% and of the dipolar resonance wavelength in the ES approximation
% for gold and silver spheroids in air or water.
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

% aspect ratios [1 x G]
hArray=[1.01 1.1:0.1:10];
zeroh=0*hArray;
oneArray=1+zeroh; % [1 x G]

% get geometrical factors for oblate and prolate spheroids
stEllGobl=EllOblateGeomFact(hArray,oneArray,'L');
stEllGpro=EllProlateGeomFact(hArray,oneArray,'L');

% create, position, and resize figure
scrsz = get(0,'ScreenSize'); % scrsz(4) contains screen height
figAspectRatio=1.3;
figHeight=scrsz(4)-150;
figWidth=figAspectRatio*figHeight;
figure('Name','Fig. 6.15', ...
    'Position',[(scrsz(3)-figWidth)/2 50 figWidth figHeight]);

% plot results
% (a) simple ellipsoid plots
subplot(2,2,1);
ellipsoid(-2,0,0,1,1,3)
hold on;
ellipsoid(1,-3,-2,3,3,1)
ellipsoid(5,0,0,1,1,1)
hold off;
text(-1.5,2,2.5,'(a)');
text(-1,0,2.5,{'Prolate','spheroid','(h=3)'});
text(2.5,0,1.8,{'Sphere','(h=1)'});
text(-0.2,0,-0.75,{'Oblate spheroid','(h=3)'});
axis([-3 3 -3 3 -2.5 2.5]);
axis equal;axis off;
colormap gray;

% (b) aspect ratio dependence of geometrical factors L's
subplot(2,2,2);
h=plot(hArray,stEllGobl.L3, ':', ...
     hArray,stEllGpro.L3, '-', ...
     hArray,stEllGobl.L1, ':', ...
     hArray,stEllGpro.L1, '-', ...
     hArray,oneArray*1/3, '-');
set(h,'LineWidth',1.5);
axis([1 10 -0.03 0.93]);
title('(b) Geometrical factors, L');
xlabel('Aspect ratio, h');
ylabel('Geometrical factor, L_i');
legend({'L_{3o}', 'L_{3p}=L_{2p}', 'L_{1o}=L_{2o}', 'L_{1p}'},'Location','NorthWest');
 
 
% (c-d) LSP resonance wavelength for silver and gold
% in air (c) and water (d)

% lambda in reverse order since we want to find the largest
% lambda meeting the resonance condition
lambda=transpose(1500:-0.2:200);
% -real(epsilon) for silver and gold
emrAg=-(real(epsAg(lambda)));
emrAu=-(real(epsAu(lambda)));
ind=find(emrAg<0); % remove negative values
emrAg(ind)=ind*0;
ind=find(emrAu<0);
emrAu(ind)=ind*0;

nNbH=length(hArray);

ResAgL1o=zeroh; ResAgL3o=zeroh;
ResAgL1p=zeroh; ResAgL3p=zeroh;
ResAuL1o=zeroh; ResAuL3o=zeroh;
ResAuL1p=zeroh; ResAuL3p=zeroh;

% loop twice for each plot
for nn=1:2
    if nn==1 % in air
        epsilonM=1.0;
        sTitle='(c) Ellipsoid in air';
        lambdaMax=1050;
    else % in water
        epsilonM=1.77;
        sTitle='(c) Ellipsoid in water';
        lambdaMax=1350;
    end

    for nh=1:nNbH
        % find resonance conditions for Ag
        ind=find(emrAg < (epsilonM*(1/stEllGobl.L1(nh)-1)),1);
        if (ind), ResAgL1o(nh)=lambda(ind); end % will be zero if not found
        ind=find(emrAg < (epsilonM*(1/stEllGobl.L3(nh)-1)),1);
        if (ind), ResAgL3o(nh)=lambda(ind); end
        ind=find(emrAg < (epsilonM*(1/stEllGpro.L1(nh)-1)),1);
        if (ind), ResAgL1p(nh)=lambda(ind); end
        ind=find(emrAg < (epsilonM*(1/stEllGpro.L3(nh)-1)),1);
        if (ind), ResAgL3p(nh)=lambda(ind); end
        % find resonance conditions for Au
        ind=find(emrAu < (epsilonM*(1/stEllGobl.L1(nh)-1)),1);
        if (ind), ResAuL1o(nh)=lambda(ind); end
        ind=find(emrAu < (epsilonM*(1/stEllGobl.L3(nh)-1)),1);
        if (ind), ResAuL3o(nh)=lambda(ind); end
        ind=find(emrAu < (epsilonM*(1/stEllGpro.L1(nh)-1)),1);
        if (ind), ResAuL1p(nh)=lambda(ind); end
        ind=find(emrAu < (epsilonM*(1/stEllGpro.L3(nh)-1)),1);
        if (ind), ResAuL3p(nh)=lambda(ind); end
    end

    % plot results
    subplot(2,2,nn+2);

    h=plot(hArray,ResAgL3o, '-', ...
        hArray,ResAgL3p, '-', ...
        hArray,ResAgL1o, '-', ...
        hArray,ResAgL1p,'-');
    set(h,'LineWidth',1.5);
    line(hArray,ResAuL3o,'LineStyle','--', ...
        'LineWidth',1.5,'Color',get(h(1),'Color'));
    line(hArray,ResAuL3p,'LineStyle','--', ...
        'LineWidth',1.5,'Color',get(h(2),'Color'));
    line(hArray,ResAuL1o,'LineStyle','--', ...
        'LineWidth',1.5,'Color',get(h(3),'Color'));
    line(hArray,ResAuL1p,'LineStyle','--', ...
        'LineWidth',1.5,'Color',get(h(4),'Color'));
    axis([1.01 10 250 lambdaMax]);
    set(gca,'YGrid','on','YMinorGrid','off');
    title(sTitle);
    xlabel('Aspect ratio, h');
    ylabel('Resonance wavelength [nm]');
    legend({'L_{3o} (Ag)', 'L_{3p}=L_{2p}', 'L_{1o}=L_{2o}', ...
        'L_{1p}', 'L_{3o} (Au)'},'Location','NorthWest');
end