function MakeFig6_18()
% Function to reproduce Fig. 6.18
% Spheroid's aspect ratio dependence of the SERS EFs (average
% and maximum) at the dipolar resonance wavelength in the ES approximation
% for excitation along the long axis (x-axis)
% for gold and silver spheroids in water (a) or air (b).
% the resonance wavelength are also shown with scale on the right axis.
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

% aspect ratios [1 x G]
hArray=[1.01 1.1:0.1:10];
zeroh=0*hArray;
oneArray=1+zeroh; % [1 x G]

% get geometrical factors for oblate and prolate spheroids
stEllGobl=EllOblateGeomFact(hArray,oneArray,'x');
stEllGpro=EllProlateGeomFact(hArray,oneArray,'x');

% create, position, and resize figure
scrsz = get(0,'ScreenSize'); % scrsz(4) contains screen height
figAspectRatio=1;
figHeight=scrsz(4)-100;
figWidth=figAspectRatio*figHeight;
figure('Name','Fig. 6.18', ...
    'Position',[(scrsz(3)-figWidth)/2 0 figWidth figHeight]);

% lambda in reverse order since we want to find the largest
% lambda meeting the resonance condition
lambda=transpose(1500:-0.2:200);
eAg=epsAg(lambda);
eAu=epsAu(lambda);
% -real(epsilon) for silver and gold
emrAg=-(real(eAg));
emrAu=-(real(eAu));
ind=find(emrAg<0); % remove negative values
emrAg(ind)=ind*0;
ind=find(emrAu<0);
emrAu(ind)=ind*0;

nNbH=length(hArray);

indResAgObl=zeroh; indResAgPro=zeroh;
indResAuObl=zeroh; indResAuPro=zeroh;
% FMaxAgObl=zeroh; FMaxAgPro=zeroh;
% FAveAgObl=zeroh; FAveAgPro=zeroh;
% FMaxAuObl=zeroh; FMaxAuPro=zeroh;
% FAveAuObl=zeroh; FAveAuPro=zeroh;

% loop twice for each plot
for nn=1:2
    if nn==1 % in water
        epsilonM=1.77;
        sTitle='(a) Spheroids in water';
    else % in air
        epsilonM=1.0;
        sTitle='(b) Spheroids in air';
    end

    for nh=1:nNbH
        % find resonance conditions for Ag
        ind=find(emrAg < (epsilonM*(1/stEllGobl.L1(nh)-1)),1);
        if (ind), indResAgObl(nh)=ind; end % will be zero if not found
        ind=find(emrAg < (epsilonM*(1/stEllGpro.L1(nh)-1)),1);
        if (ind), indResAgPro(nh)=ind; end % will be zero if not found
        % find resonance conditions for Au
        ind=find(emrAu < (epsilonM*(1/stEllGobl.L1(nh)-1)),1);
        if (ind), indResAuObl(nh)=ind; end % will be zero if not found
        ind=find(emrAu < (epsilonM*(1/stEllGpro.L1(nh)-1)),1);
        if (ind), indResAuPro(nh)=ind; end % will be zero if not found
    end

    % note that an error will occur if no resonance condition is found
    % For this figure, the resonance condition is always found, so we do not
    % check for such problems
    
    % calculate EM properties for each of the 4 cases
    % oblate Ag
    stEllEM=EllEMproperties(stEllGobl,lambda(indResAgObl),epsilonM,eAg(indResAgObl),'x');
    % fields in stEllEM are [H x H]
    % only the diagonal terms are of interest, they correspond to the
    % values at the resonance condition
    % note that the code could be much faster if only what was needed was
    % computed
    FMaxAgObl=(diag(stEllEM.Aperp1)).^2; % [H x 1]
    FAveAgObl=diag(stEllEM.F0E4Ave1); % [H x 1]

    % prolate Ag
    stEllEM=EllEMproperties(stEllGpro,lambda(indResAgPro),epsilonM,eAg(indResAgPro),'x');
    FMaxAgPro=(diag(stEllEM.Aperp1)).^2; % [H x 1]
    FAveAgPro=diag(stEllEM.F0E4Ave1); % [H x 1]

    % obolate Au
    stEllEM=EllEMproperties(stEllGobl,lambda(indResAuObl),epsilonM,eAu(indResAuObl),'x');
    FMaxAuObl=(diag(stEllEM.Aperp1)).^2; % [H x 1]
    FAveAuObl=diag(stEllEM.F0E4Ave1); % [H x 1]

    % prolate Ag
    stEllEM=EllEMproperties(stEllGpro,lambda(indResAuPro),epsilonM,eAu(indResAuPro),'x');
    FMaxAuPro=(diag(stEllEM.Aperp1)).^2; % [H x 1]
    FAveAuPro=diag(stEllEM.F0E4Ave1); % [H x 1]
    
    % plot results
    axtmp=subplot(2,1,nn);
    postmp=get(axtmp,'Position');
    delete(axtmp);
    ax1=axes('Position',postmp.*[1,1,0.7,1],...
        'XAxisLocation','bottom','XColor','k', ...
        'YAxisLocation','left','Ycolor','k', ...
        'YScale','Log', ...
        'XLim', [1.01 10], 'YLim', [10 1e12]);
    set(get(ax1,'XLabel'),'String','Aspect ratio, h');
    set(get(ax1,'YLabel'),'String','SERS EF at resonance');
    set(ax1,'YGrid','on','YMinorGrid','off');
    
    line(hArray,FMaxAgPro,'Color','r','LineStyle','-','LineWidth',0.5);
    line(hArray,FMaxAgObl,'Color','b','LineStyle','-','LineWidth',0.5);
    line(hArray,FAveAgPro,'Color','r','LineStyle','-','LineWidth',1.5);
    line(hArray,FAveAgObl,'Color','b','LineStyle','-','LineWidth',1.5);
    line(hArray,FMaxAuPro,'Color','r','LineStyle','--','LineWidth',0.5);
    line(hArray,FMaxAuObl,'Color','b','LineStyle','--','LineWidth',0.5);
    line(hArray,FAveAuPro,'Color','r','LineStyle','--','LineWidth',1.5);
    line(hArray,FAveAuObl,'Color','b','LineStyle','--','LineWidth',1.5);
    h=legend({'F_{Max} (prolate)', 'F_{Max} (oblate)',...
        '<F_0^{E4}> (prolate)', '<F_0^{E4}> (oblate)'},'Location','NorthEast');
    % move legend
    tmploc=get(h,'Position');
    tmploc(1)=0.95-tmploc(3);
    set(h,'Position',tmploc);
    title(sTitle);
    text(1.2,1e11,0,{'Ag (solid lines)','Au (dashed lines)'});

    
    ax2=axes('Position',get(gca,'Position'),...
        'XAxisLocation','top','XColor','k', ...
        'XTickLabel',[], ...
        'YAxisLocation','right','Ycolor','k', ...
        'Color','none', ...
        'YScale','Linear', ...
        'YLim',[300 1990],'XLim',[1.01 10]);
    set(get(ax2,'Ylabel'),'String','Resonance wavelength, \lambda_{Res} [nm]');

    line(hArray,lambda(indResAgPro),'Color','c','LineStyle','-');
    line(hArray,lambda(indResAgObl),'Color','m','LineStyle','-');
    line(hArray,lambda(indResAuPro),'Color','c','LineStyle','--');
    line(hArray,lambda(indResAuObl),'Color','m','LineStyle','--');
    h=legend({'\lambda_{Res} (prolate)','\lambda_{Res} (oblate)'}, ...
        'Location','SouthEastOutside','Color','w');
    tmploc=get(h,'Position');
    tmploc(1)=0.95-tmploc(3);
    set(h,'Position',tmploc);

end
