function MakeFig6_2()
% Function to reproduce Fig. 6.2
% Distance-dependence of decay rate EFs and EM radiative efficiency
% for selected cases of a dipole in air emitting
% close to a planar silver or gold surface.
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

%%%%%%%%%%%%%%%%%%
% Computations
%%%%%%%%%%%%%%%%%%

% dielectric constant of outside medium (real positive)
epsilonM=1.0; % air

% distance of dipole from interface (in nm)
dArray=[1 2 3 4 5 7 10 15 20 30 40 50]; % [1 x D]
nNbD=length(dArray);
zerod=0*dArray; % [1 x D]
% initialize arrays
MTotPerpAg633=zerod;
MTotParaAg633=zerod;
MTotPerpAu633=zerod;
MTotPerpAu514=zerod;
MRadPerpAg633=zerod;
MRadParaAg633=zerod;
MRadPerpAu633=zerod;
MRadPerpAu514=zerod;

% loop through each distance
for indd=1:nNbD
    d=dArray(indd);
    
    % Solve dipole emission problem for selected cases
    nNbStep=5000; % for integrals
    % Ag/air interface at 633nm
    stAllM=PlnSinglePlaneDecayRateEFs(epsilonM,633,epsAg(633),d,nNbStep);
    MTotPerpAg633(indd)=stAllM.MTotPerp;
    MTotParaAg633(indd)=stAllM.MTotPara;
    MRadPerpAg633(indd)=stAllM.MRadPerp;
    MRadParaAg633(indd)=stAllM.MRadPara;
    
    % Au/air interface at 633nm
    stAllM=PlnSinglePlaneDecayRateEFs(epsilonM,633,epsAu(633),d,nNbStep);
    MTotPerpAu633(indd)=stAllM.MTotPerp;
    MRadPerpAu633(indd)=stAllM.MRadPerp;

    % Au/air interface at 514nm
    stAllM=PlnSinglePlaneDecayRateEFs(epsilonM,514,epsAu(514),d,nNbStep);
    MTotPerpAu514(indd)=stAllM.MTotPerp;
    MRadPerpAu514(indd)=stAllM.MRadPerp;
end

%%%%%%%%%%%%%%%%%%
% Drawing
%%%%%%%%%%%%%%%%%%

% create, position, and resize figure
scrsz = get(0,'ScreenSize'); % scrsz(4) contains screen height
figAspectRatio=1.3;
figHeight=scrsz(4)-150;
figWidth=figAspectRatio*figHeight;
figure('Name','Fig. 6.2', ...
    'Position',[(scrsz(3)-figWidth)/2 50 figWidth figHeight]);

% plot results
% (a) MTot
subplot(2,2,1);
loglog(dArray,MTotPerpAg633, 's-', ...
    dArray,MTotParaAg633, 'o-', ...
    dArray,MTotPerpAu633, '^-', ...
    dArray,MTotPerpAu514, 'd-');
axis([0.5 55 0.1 1e5]);
set(gca,'YGrid','on','YMinorGrid','off');
title('(a) Total decay rate EFs in air');
xlabel('Distance, d [nm]');
ylabel('M_{Tot}');
legend({'Ag, Perp, \lambda=633nm','Ag, Para, \lambda=633nm', ...
    'Au, Perp, \lambda=633nm','Au, Perp, \lambda=514nm'},'Location','NorthEast');


% (b) MRad
h=subplot(2,2,2);
axpos2=get(h,'Position');
loglog(dArray,MRadPerpAg633, 's-', ...
    dArray,MRadParaAg633, 'o-', ...
    dArray,MRadPerpAu633, '^-', ...
    dArray,MRadPerpAu514, 'd-');
axis([0.5 55 0.08 2]);
set(gca,'YGrid','on','YMinorGrid','off');
title('(b) Radiative decay rate EFs in air');
xlabel('Distance, d [nm]');
ylabel('M_{Rad}');
h=legend({'Ag, Perp, \lambda=633nm','Ag, Para, \lambda=633nm', ...
    'Au, Perp, \lambda=633nm','Au, Perp, \lambda=514nm'},'Location','West');
% reposition legend
set(h,'Position',get(h,'Position')+[0 -0.05 0 0]);


% (c) etaRad
h=subplot(2,2,[3;4]);
% change width and recenter:
axpos3=get(h,'Position');
axpos3(1)=axpos3(1)+(axpos3(3)-axpos2(3))/2; % recenter
axpos3(3)=axpos2(3); % change width
set(h,'Position',axpos3);

loglog(dArray,MRadPerpAg633./MTotPerpAg633, 's-', ...
    dArray,MRadParaAg633./MTotParaAg633, 'o-', ...
    dArray,MRadPerpAu633./MTotPerpAu633, '^-', ...
    dArray,MRadPerpAu514./MTotPerpAu514, 'd-');
axis([0.5 55 5e-6 2]);
set(gca,'YGrid','on','YMinorGrid','off');
title('(c) EM Radiative efficiency in air');
xlabel('Distance, d [nm]');
ylabel('\eta^{EM}_{Rad}');
legend({'Ag, Perp, \lambda=633nm','Ag, Para, \lambda=633nm', ...
    'Au, Perp, \lambda=633nm','Au, Perp, \lambda=514nm'},'Location','SouthEast');
