function MakeFig6_4()
% Function to reproduce Fig. 6.4
% Extinction, scattering, and absorption coefficients from Mie theory
% for silver spheres of radii 10, 25, and 50 nm in air or water.
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information


global noCheckSum;
noCheckSum=true; % no check for numerical problems (much faster)
% noCheckSum=false; % to check for numerical problems with Mie

% wavelengths (column)
lambda=transpose(200:1:600); 

% N_{max} for Mie series
nNmax=50;

% wavelength-dependent dielectric function of sphere material
% vector column, same size as lambda [L x 1]
epsilonIn=epsAg(lambda); % silver


% create, position, and resize figure
scrsz = get(0,'ScreenSize'); % scrsz(4) contains screen height
figAspectRatio=1;
figHeight=scrsz(4)-150;
figWidth=figAspectRatio*figHeight;
figure('Name','Fig. 6.4', ...
    'Position',[(scrsz(3)-figWidth)/2 50 figWidth figHeight]);

% dielectric constant of outside medium (real positive)
epsilonMArray=[1.0, 1.77, 1.0, 1.77, 1.0, 1.77]; % air or water

% sphere radius in nm 
aArray=[10, 10, 25, 25, 50, 50];

sLegendCell={'air', 'water', 'air', 'water', 'air', 'water'};

% loop through each of the six plots to create
for nn=1:6
    
    epsilonM=epsilonMArray(nn);
    a=aArray(nn);
    
    % Solve problem using Mie theory
    stM=PweSolveSingleSphere(nNmax,a,lambda,epsilonM,epsilonIn,'noplot');
    % all necessary results are in structure stM

    % plot results
    axtmp=subplot(3,2,nn);
    postmp=get(axtmp,'Position');
    delete(axtmp);
    
    ax1=axes('Position',postmp,...
        'XAxisLocation','bottom','XColor','k', ...
       'YAxisLocation','left','Ycolor','b');

    if mod(nn,2)==0
        xlim1=[200 600];
        set(ax1,'XLim',xlim1,'YLim',[0 24]);
    else
        xlim1=[200 500];
        set(ax1,'XLim',xlim1,'YLim',[0 20]);
    end

    if mod(nn,3)==0
        set(get(ax1,'XLabel'),'String','Wavelength [nm]');
    end
    set(get(ax1,'YLabel'),'String','Q_{ext},Q_{sca},Q_{abs}');
    
    line(lambda,stM.Qext,'Color','b','LineWidth',1.5);
    line(lambda,stM.Qsca,'Color',[0 0.5 0]); % darker green
    line(lambda,stM.Qabs,'Color','k','LineStyle','--');

    if nn==1
        legend({'Q_{ext}','Q_{sca}','Q_{abs}'});
    end
    title(['Ag in ' sLegendCell{nn} '  - a=' num2str(stM.a) 'nm']);
    
    ax2=axes('Position',get(ax1,'Position'),...
       'XAxisLocation','top','XColor','k', ...
       'XTickLabel',[], ...
       'YAxisLocation','right','Ycolor','r', ...
       'Color','none', ...
       'YScale','linear', ...
       'YLim',[0 1],'XLim',xlim1);
    set(get(ax2,'Ylabel'),'String','Q_{abs}/Q_{ext}');

    line(lambda,stM.Qabs./stM.Qext,'Color','r','LineStyle',':');
end