function MakeFig6_8()
% Function to reproduce Fig. 6.8
% Wavelength dependence of the LFIEF at several points on the sphere surface
% for several cases from Mie theory and in the ES approximation.
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information


global noCheckSum;
noCheckSum=true; % no check for numerical problems (much faster)
% noCheckSum=false; % to check for numerical problems with Mie

% N_{max} for Mie series
nNmax=50; % same for all plots

% dielectric constant of outside medium (real positive)
epsilonM=1.77; % water (same for all plots)


% create, position, and resize figure
scrsz = get(0,'ScreenSize'); % scrsz(4) contains screen height
figAspectRatio=1;
figHeight=scrsz(4)-150;
figWidth=figAspectRatio*figHeight;
figure('Name','Fig. 6.8', ...
    'Position',[(scrsz(3)-figWidth)/2 50 figWidth figHeight]);

% note that ESA results are here obtained for convenience
% from Mie theory with a=0.1 nm
aArray=[10,0.1,25,50,50,0.1];
sTitle={'Silver (a=10 nm) in water', ...
    'Silver (ESA) in water', ...
    'Silver (a=25 nm) in water', ...
    'Silver (a=50 nm) in water', ...
    'Gold (a=50 nm) in water', ...
    'Gold (ESA) in water'};
CYscale={[0.5 4000], [0.5 4000], [0.5 500], ...
    [0.1 80], [0.06 100], [0.06 100]};
   
% loop through each of the six plots to create
for nn=1:6
    
    if (nn<=4) % for silver
        lambdamin=200;
        lambdamax=600;
        % wavelengths (column)
        lambda=transpose(lambdamin:1:lambdamax); 
        % wavelength-dependent dielectric function of sphere material
        % vector column, same size as lambda [L x 1]
        epsilonIn=epsAg(lambda); % silver
    else % for gold
        lambdamin=300;
        lambdamax=800;
        % wavelengths (column)
        lambda=transpose(lambdamin:1:lambdamax); 
        % wavelength-dependent dielectric function of sphere material
        % vector column, same size as lambda [L x 1]
        epsilonIn=epsAu(lambda); % gold
    end

    % sphere radius in nm
    a=aArray(nn);

    % Solve problem using Mie theory
    stM=PweSolveSingleSphere(nNmax,a,lambda,epsilonM,epsilonIn,'noplot','coeff');
    % all necessary results are in structure stM

%     % points can be defined in spherical coordinates as follows
%     stPtO=struct('r',0,'theta',0,'phi',0);
%     stPtA=struct('r',a,'theta',pi/2,'phi',0);
%     stPtB=struct('r',a,'theta',pi/2,'phi',pi/2);
%     stPtC=struct('r',a,'theta',0,'phi',0);
%     stPtCp=struct('r',a,'theta',pi,'phi',0);

    % Note that points can also be defined in Cartesian as follows:
    stPtO=struct('x',0,'y',0,'z',0);
    stPtA=struct('x',a,'y',0,'z',0);
    stPtB=struct('x',0,'y',a,'z',0);
    stPtC=struct('x',0,'y',0,'z',a);
    stPtCp=struct('x',0,'y',0,'z',-a);
    
    
    % inside points
    stAbn1.an1=stM.alphan1;
    stAbn1.bn1=stM.betan1;
    stEptO=PweEpts(lambda,epsilonIn,stAbn1,stPtO,'Inside');
    
    % outside points, stM already contains fields cn1 and dn1
    stPtArray=[stPtA,stPtB,stPtC,stPtCp];
    stEptsOut=PweEpts(lambda,epsilonM,stM,stPtArray,'Outside');
 
    % plot results
    subplot(3,2,nn);
    hg=semilogy(lambda,stEptO.MLoc,'-', lambda,stEptsOut(1).MLoc,'-', ...
        lambda,stEptsOut(2).MLoc,'--', lambda,stEptsOut(3).MLoc,':', ...
        lambda,stEptsOut(4).MLoc,'-.');
    set(hg(2),'LineWidth',1.5);
    axis([[lambdamin lambdamax] CYscale{nn}]);
	title(sTitle{nn});
    legend({'O','A','B','C','C'''});
    xlabel('Wavelength [nm]');
    ylabel('M_{Loc}');
end