function MakeFig6_9()
% Function to reproduce Fig. 6.9
% Spatial distribution of the local field,
% characterized by the enhancement factor log10(MLoc) (left),
% and the proportion of the normal component |Eperp|2/|ELoc|2 (right),
% both computed at the main dipolar LSP resonance: (top) for a 10 nm radius silver sphere in water
% at 392 nm, and (bottom) for a 50 nm radius silver sphere in water at 492 nm.
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

global noCheckSum;
noCheckSum=true; % no check for numerical problems (much faster)
% noCheckSum=false; % to check for numerical problems with Mie

% N_{max} for Mie series
nNmax=50; % same for all plots

% dielectric constant of outside medium (real positive)
epsilonM=1.77; % water (same for all plots)



% create, position, and resize figure
scrsz = get(0,'ScreenSize'); % scrsz(4) contains screen height
figAspectRatio=1;
figHeight=scrsz(4)-150;
figWidth=figAspectRatio*figHeight;
figure('Name','Fig. 6.9', ...
    'Position',[(scrsz(3)-figWidth)/2 50 figWidth figHeight]);

nNbTheta=31; % = T
theta=transpose(linspace(0,pi,nNbTheta)); % col [T x 1]
nNbPhi=nNbTheta;
phi=linspace(-pi,pi,nNbPhi); % row [1 x F]
% point coordinates on sphere, matrices [T x F]
xs=sin(theta) * cos(phi); 
ys=sin(theta) * sin(phi); 
zs=repmat(cos(theta),1,nNbPhi); 

% radii (nm)
aArray=[10,50];
% wavelengths (nm)
lambdaArray=[392, 492]; 

sTitle={'Silver sphere in water - a=10 nm - \lambda=392 nm', ...
    'Silver sphere in water - a=50nm - \lambda=492 nm'};

% loop through each of the two plots to create
for nn=1:2
    lambda=lambdaArray(nn); 
    % dielectric function of sphere material
    % vector column, same size as lambda [1 x 1] here
    epsilonIn=epsAg(lambda); % silver
    
    % sphere radius in nm
    a=aArray(nn);

    % Solve problem using Mie theory
    stM=PweSolveSingleSphere(nNmax,a,lambda,epsilonM,epsilonIn,'noplot','coeff');
    % all necessary results are in structure stM
    % stM contains fields cn1 and dn1
    % calculate field for all points on the surface (just outside)
    stEsurf=PweEsurf(lambda,epsilonM,stM,a,nNbTheta,'Outside');
    
    % theta dependence
    Ecr2=transpose(abs(stEsurf.Ecr).^2); % col [T x 1]
    Ec2=Ecr2+transpose(abs(stEsurf.Ect).^2); % col [T x 1]
    Es2=transpose(abs(stEsurf.Esf).^2); % col [T x 1]

    % phi-and-theta dependence
    % these are matrices [T x F]
    MLoc=Ec2 * (cos(phi).^2) + Es2 * (sin(phi).^2); 
    MLocPerp=Ecr2 * (cos(phi).^2);
    
    % plot results
    
    hpl1=subplot(2,2,2*nn-1);
    set(hpl1,'Outerposition',[0,0.5*(2-nn),0.5,0.5]);
    % main surface plot
    surf(xs,ys,zs,log10(MLoc));
    axis tight; axis equal; axis off;
    colormap gray; colorbar('eastOutside','fontsize',8);
    set(hpl1,'CameraViewAngle',8.5);
    hold on;
    line([-1.6;1.6], [0;0],[0;0],'LineStyle','--','Color','k');
    line([0;0],[-1.8;1.8], [0;0],'LineStyle','--','Color','k');
    line([0;0],[0;0],[-1.4;1.4], 'LineStyle','--','Color','k');
    quiver3(-1.7,0,0,0.5,0,0,'k');
    text(-1.55,-0.1,-0.07,'\bf E_0');
    quiver3(-1.7,0,0,0,0,0.5,'k');
    text(-1.9,0,0.3,'\bf k');
    text(-0.9,0,1.85,'\bf log_{10}( M_{Loc}=|E_{Loc}|^2/|E_{Inc}|^2 )');
    ht=title(sTitle{nn});
    set(ht,'Position',get(ht,'Position')+[1.4 -1.1 0]);
    hold off;
    
    hpl2=subplot(2,2,2*nn);
    set(hpl2,'Outerposition',[0.5,0.5*(2-nn),0.5,0.5])
    % main surface plot
    surf(xs,ys,zs,MLocPerp./MLoc);
    axis tight; axis equal;axis off;
    colormap gray; colorbar('eastOutside','fontsize',8);
    set(hpl2,'CameraViewAngle',8.5);
    hold on;
    line([-1.6;1.6], [0;0],[0;0],'LineStyle','--','Color','k');
    line([0;0],[-1.8;1.8], [0;0],'LineStyle','--','Color','k');
    line([0;0],[0;0],[-1.4;1.4], 'LineStyle','--','Color','k');
    quiver3(-1.7,0,0,0.5,0,0,'k');
    text(-1.55,-0.1,-0.07,'\bf E_0');
    quiver3(-1.7,0,0,0,0,0.5,'k');
    text(-1.9,0,0.3,'\bf k');
    text(-0.6,0,1.85,'\bf |E^{Perp}_{Loc}|^2/|E_{Loc}|^2');
    hold off;
end