function MakeFigH_1()
% Function to reproduce Fig. H.1
% Convergence of Mie series for decay rate EF of dipoles
% Note that the first few terms for M_{Rad}^{Perp} in the
% original figure in (a) and (b) were slightly wrong.
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

%%%%%%%%%%%%%%%%%%
% Computations
%%%%%%%%%%%%%%%%%%

global noCheckSum;
noCheckSum=true; % no check for numerical problems (much faster)
% noCheckSum=false; % to check for numerical problems with Mie

% N_{max}
nNmax=50;
nNmaxESA=500;

% sphere radius in nm (scalar [1 x 1])
a=50;

% dielectric constant of outside medium (real positive scalar)
epsilonM=1.77; % water

% distance of dipole from surface (in nm)
d=1;

% solve decay rate EFs for perp and para dipoles
% and return coeffs in the sum of Mie series
% lambda=340, Mie only (nNMaxESA=nNmax);
stMdip340Mie=DipSolveSingleSphere(nNmax,a,340,epsilonM,epsAg(340),d,nNmax,'noplot','coeffSum');
% lambda=340, ESA (nNmax=0);
stMdip340ESA=DipSolveSingleSphere(0,a,340,epsilonM,epsAg(340),d,nNmaxESA,'noplot','coeffSum');
% lambda=340, Mie only (nNMaxESA=nNmax);
stMdip394Mie=DipSolveSingleSphere(nNmax,a,394,epsilonM,epsAg(394),d,nNmax,'noplot','coeffSum');
% lambda=340, ESA (nNmax=0);
stMdip394ESA=DipSolveSingleSphere(0,a,394,epsilonM,epsAg(394),d,nNmaxESA,'noplot','coeffSum');

% solve decay rate EFs for perp and para dipoles
% for all wavelengths (lambda in nm)
lambda=transpose(300:1:650);
% wavelength-dependent dielectric function of sphere material
% vector column, same size as lambda [1 x 1]
epsilonIn=epsAg(lambda); % silver
% nNmax = 50, no ESA (nNmaxESA=nNmax)
stMdipN50=DipSolveSingleSphere(nNmax,a,lambda,epsilonM,epsilonIn,d,nNmax,'noplot','nocoeff');
% nNmax = 50, with ESA up to nNmaxESA=500
stMdipN500=DipSolveSingleSphere(nNmax,a,lambda,epsilonM,epsilonIn,d,nNmaxESA,'noplot','nocoeff');



%%%%%%%%%%%%%%%%%%
% Drawing
%%%%%%%%%%%%%%%%%%

% create, position, and resize figure
scrsz = get(0,'ScreenSize'); % scrsz(4) contains screen height
figAspectRatio=1.3;
figHeight=scrsz(4)-150;
figWidth=figAspectRatio*figHeight;
figure('Name','Fig. H.1', ...
    'Position',[(scrsz(3)-figWidth)/2 50 figWidth figHeight]);


% plot results for lambda=340 nm (Fig. H.1(a))
subplot(2,2,1);
loglog(1:nNmax,stMdip340Mie.MRadPerpCoeffs,'c-',1:nNmax,stMdip340Mie.MRadParaCoeffs,'m-');
axis([0.8 550 1e-3 9900]);
xlabel('Angular momentum order l');
ylabel('Series Term in EF');
line(1:nNmax,stMdip340Mie.MTotPerpCoeffs,'LineStyle','-','Color','b');
line(1:nNmax,stMdip340Mie.MTotParaCoeffs,'LineStyle','-','Color','r');
line(1:nNmaxESA,stMdip340ESA.MTotPerpCoeffs,'LineStyle',':','Color','b');
line(1:nNmaxESA,stMdip340ESA.MTotParaCoeffs,'LineStyle',':','Color','r');
legend({'M_{Rad}^{Perp} (Mie)','M_{Rad}^{Para} (Mie)', ...
        'M_{Tot}^{Perp} (Mie)','M_{Tot}^{Para} (Mie)', ...
        'M_{Tot}^{Perp} (ESA)','M_{Tot}^{Para} (ESA)'},'Location','South');
title('(a) Silver sphere in water, a=50nm, d=1nm, \lambda=340nm');

% plot results for lambda=394 nm (Fig. H.1(b))
subplot(2,2,3);
loglog(1:nNmax,stMdip394Mie.MRadPerpCoeffs,'c-',1:nNmax,stMdip394Mie.MRadParaCoeffs,'m-');
axis([0.8 550 1e-3 600]);
xlabel('Angular momentum order l');
ylabel('Series Term in EF');
line(1:nNmax,stMdip394Mie.MTotPerpCoeffs,'LineStyle','-','Color','b');
line(1:nNmax,stMdip394Mie.MTotParaCoeffs,'LineStyle','-','Color','r');
line(1:nNmaxESA,stMdip394ESA.MTotPerpCoeffs,'LineStyle',':','Color','b');
line(1:nNmaxESA,stMdip394ESA.MTotParaCoeffs,'LineStyle',':','Color','r');
legend({'M_{Rad}^{Perp} (Mie)','M_{Rad}^{Para} (Mie)', ...
        'M_{Tot}^{Perp} (Mie)','M_{Tot}^{Para} (Mie)', ...
        'M_{Tot}^{Perp} (ESA)','M_{Tot}^{Para} (ESA)'},'Location','South');
title('(b) Silver sphere in water, a=50nm, d=1nm, \lambda=394nm');

% plot lambda dependence (Fig. H.1(c))
axtmp=subplot(2,2,[2,4]);
postmp=get(axtmp,'Position');
delete(axtmp);
ax1=axes('Position',postmp,...
    'XAxisLocation','bottom','XColor','k', ...
    'YAxisLocation','left','Ycolor','b', ...
    'YScale','Log', ...
    'XLim', [300 650], 'YLim', [1e-3 1e6]);
set(get(ax1,'XLabel'),'String','Wavelength [nm]');
set(get(ax1,'YLabel'),'String','Decay rate EF');

line(lambda,stMdipN500.MTotPerp,'Color','b','LineStyle','-');
line(lambda,stMdipN50.MTotPerp,'Color','b','LineStyle',':');
line(lambda,stMdipN50.MRadPerp,'Color','c','LineStyle','-');
legend({'M_{Tot}^{Perp} (L_{Max}=500)','M_{Tot}^{Perp} (L_{Max}=50)', ...
    'M_{Rad}^{Perp}'},'Location','NorthEast');
title('(c) Silver sphere in water, a=50nm, d=1nm');

ax2=axes('Position',get(ax1,'Position'),...
    'XAxisLocation','top','XColor','k', ...
    'XTickLabel',[], ...
    'YAxisLocation','right','Ycolor',[0,0.5,0], ...
    'Color','none', ...
    'YScale','Log', ...
    'YLim',[1e-3 10],'XLim',[300 650]);
set(get(ax2,'Ylabel'),'String','Modified Quantum Yield');

line(lambda,stMdipN50.MRadPerp./stMdipN500.MTotPerp,'Color',[0,0.5,0],'LineStyle','-');
line(lambda,stMdipN50.MRadPerp./stMdipN50.MTotPerp,'Color',[0,0.5,0],'LineStyle',':');
legend({'\eta_{Rad}^{Perp} (L_{Max}=500)','\eta_{Rad}^{Perp} (L_{Max}=50)'}, ...
    'Location','SouthEast','Color','w');





