function stEllEM = EllEMproperties(stEllGeom,lambda,epsilonM,epsilonIn,sOption)
% Returns the most important EM properties of an ellipsoid
%
% Parameters:
% - stEllGeom: structure containing geometric properties of the ellipsoid
%              can be obtained from calling EllGeomFact, EllOblateGeomFact,
%              EllProlateGeomFact, or EllSphereGeomFact
%              The fields of stEllGeom are all same size, either scalars or
%              row vector [1 x G]
% - epsilonM:  scalar or column [L x 1]
%              constant or wavelength-dependent epsilon of outside medium
% - epsilon:  scalar or column [L x 1]
%              constant or wavelength-dependent epsilon of ellipsoid
% - sOption:  string (optional)
%             if sOption='L' then only the L's are used in stEllGeom
%             and the average surface properties are not computed
%             if 'x','y', 'z', or 'xz', only properties related to corresponding
%             axis are computed. 'xz' should be used for oblate or prolate
%             cases instead of 'All', 'x' should be used for spheres instead of 'All'.
%             if sOption='All' (default), everything is computed
%
% Returns:
% - stEllEM: structure with fields, all of dimensions [L x G] with
%            wavelength-dependent EM properties
% stEllEM.beta1, 2, and 3: non-dimensional dipolar polarizabilities along
%                          each axis (beta_i)
% stEllEM.SigmaExt1, 2, and 3: extinction cross-section (in squared units of a,b,c) for
%                           excitation along  each axis
% stEllEM.SigmaSca1, 2, and 3: scattering cross-section (in squared units of a,b,c) for
%                           excitation along  each axis
% stEllEM.Aperp1, 2, and 3: maximum (at tip) LFIEF for excitation along each axis (beta_i)
% stEllEM.Apara1, 2, and 3: minimum LFIEF for excitation along each axis (beta_i)
% stEllEM.MLocPerpAve1, 2, and 3: <M_Loc^Perp> for excitation along each axis
% stEllEM.MLocParaAve1, 2, and 3: <M_Loc^Para> for excitation along each axis
% stEllEM.MLocAve1, 2, and 3: <M_Loc> for excitation along each axis
% stEllEM.F0E4Ave1, 2, and 3: <F^0_E4> for excitation along each axis
% stEllEM.F0E4PerpAve1, 2, and 3: <(M_Loc^Perp)^2> for excitation along each axis
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

if nargin<5, sOption='All'; end


bxaxis=true; byaxis=true; bzaxis=true;
if strcmpi(sOption,'x'), byaxis=false; bzaxis=false; end
if strcmpi(sOption,'y'), bxaxis=false; bzaxis=false; end
if strcmpi(sOption,'z'), bxaxis=false; byaxis=false; end
if strcmpi(sOption,'xz'), byaxis=false; end

% change options for special cases
if strcmpi(stEllGeom.type,'Oblate'), byaxis=false; end
if strcmpi(stEllGeom.type,'Prolate'), byaxis=false; end
if strcmpi(stEllGeom.type,'Sphere'), byaxis=false; bzaxis=false; end


% Make epsilonIn and epsilonM vectors of same size (in case one is scalar)
eInVec=0*epsilonIn+0*epsilonM+epsilonIn;
eMVec=0*epsilonIn+0*epsilonM+epsilonM;
nNbLambda=length(eInVec);
kMVec=2*pi*sqrt(eMVec)./lambda;
% note that if both stEllGeom fields are row vectors [1 x G]
% and epsilons are column vectors [L x 1]
% all products of [L x 1] by [1 x G] will result in [L x G]
% the products are then matrix products
kMVmat = kMVec * stEllGeom.V; % [L x G]
kM4V2mat = (kMVec.^4) * (stEllGeom.V.^2); % [L x G]

if (bxaxis)
    L1=stEllGeom.L1; % [1 x G]
    nNbL=length(L1);
    % non-dimensional dipolar polarizabilities along each axis
    % Eq. G.7 and permutations
    stEllEM.beta1 = repmat(eInVec-eMVec,1,nNbL)./(3*eInVec*L1+eMVec*(3-3*L1));
    % scattering properties [L x G]
    % See Eqs. G.18 and G.19
    stEllEM.SigmaExt1 = 3* kMVmat .* imag(stEllEM.beta1);
    stEllEM.SigmaSca1 = 3/(2*pi) * kM4V2mat .* abs(stEllEM.beta1).^2;
    % Maximum and minimum local field EF on the surface for excitation on a
    % principal axis
    % Eqs. G.21 and G.22 and permutations
    L1mat=repmat(L1,nNbLambda,1);
    stEllEM.Aperp1= abs(1 + stEllEM.beta1 .* (3-3*L1mat)).^2;
    stEllEM.Apara1= abs(1 - 3*L1mat .* stEllEM.beta1).^2;
    % local field at any points on the surface derives from Eq. G.23
end
% now same for the other two axes
if (byaxis)
    L2=stEllGeom.L2;
    nNbL=length(L2);
    stEllEM.beta2 = repmat(eInVec-eMVec,1,nNbL)./(3*eInVec*L2+eMVec*(3-3*L2));
    stEllEM.SigmaExt2 = 3* kMVmat .* imag(stEllEM.beta2);
    stEllEM.SigmaSca2 = 3/(2*pi) * kM4V2mat .* abs(stEllEM.beta2).^2;
    L2mat=repmat(L2,nNbLambda,1);
    stEllEM.Aperp2= abs(1 + stEllEM.beta2 .* (3-3*L2mat)).^2;
    stEllEM.Apara2= abs(1 - 3*L2mat .* stEllEM.beta2).^2;
end
    
if (bzaxis)
    L3=stEllGeom.L3;
    nNbL=length(L3);
    stEllEM.beta3 = repmat(eInVec-eMVec,1,nNbL)./(3*eInVec*L3+eMVec*(3-3*L3));
    stEllEM.SigmaExt3 = 3* kMVmat .* imag(stEllEM.beta3);
    stEllEM.SigmaSca3 = 3/(2*pi) * kM4V2mat .* abs(stEllEM.beta3).^2;
    L3mat=repmat(L3,nNbLambda,1);
    stEllEM.Aperp3= abs(1 + stEllEM.beta3 .* (3-3*L3mat)).^2;
    stEllEM.Apara3= abs(1 - 3*L3mat .* stEllEM.beta3).^2;
end
    

if ~strcmpi(sOption,'L')

    if (bxaxis)
        % Average EFs
        % <MLocPerp> from Eq. G.27 
        stEllEM.MLocPerpAve1 = stEllEM.Aperp1.*repmat(stEllGeom.exix2ave,nNbLambda,1);
        % <MLocPara> (Eq. G.28 - Eq. G.27)
        stEllEM.MLocParaAve1 = stEllEM.Apara1.*repmat(1-stEllGeom.exix2ave,nNbLambda,1);
        % <MLoc> from Eq. G.28 
        stEllEM.MLocAve1 = stEllEM.MLocParaAve1+stEllEM.MLocPerpAve1;
        % average SERS EF <F^0_{E4}> from Eq. G.29 (adapted to use the already
        % computed <MLoc> from Eq. G.28
        stEllEM.F0E4Ave1 = stEllEM.Apara1 .* (2*stEllEM.MLocAve1 - stEllEM.Apara1) ...
            + (stEllEM.Aperp1 - stEllEM.Apara1).^2 .* repmat(stEllGeom.exix4ave,nNbLambda,1);
        % average SERS EF <F^{0-Perp}_{E4}> for perpendicular orientation
        % <F^{0-Perp}_{E4}>=<(M_Loc^Perp)^2>
        stEllEM.F0E4PerpAve1 = (stEllEM.Aperp1).^2 .* repmat(stEllGeom.exix4ave,nNbLambda,1);
    end
    % now same for the other two axes
    if (byaxis)
        stEllEM.MLocPerpAve2 = stEllEM.Aperp2 .* repmat(stEllGeom.exiy2ave,nNbLambda,1);
        stEllEM.MLocParaAve2 = stEllEM.Apara2.*repmat(1-stEllGeom.exiy2ave,nNbLambda,1);
        stEllEM.MLocAve2 = stEllEM.MLocParaAve2+stEllEM.MLocPerpAve2;
        stEllEM.F0E4Ave2 = stEllEM.Apara2.*(2*stEllEM.MLocAve2 - stEllEM.Apara2) ...
            + (stEllEM.Aperp2 - stEllEM.Apara2).^2 .* repmat(stEllGeom.exiy4ave,nNbLambda,1);
        stEllEM.F0E4PerpAve2 = (stEllEM.Aperp2).^2 .* repmat(stEllGeom.exiy4ave,nNbLambda,1);
    end
    if (bzaxis)
        stEllEM.MLocPerpAve3 = stEllEM.Aperp3.*repmat(stEllGeom.exiz2ave,nNbLambda,1);
        stEllEM.MLocParaAve3 = stEllEM.Apara3.*repmat(1-stEllGeom.exiz2ave,nNbLambda,1);
        stEllEM.MLocAve3 = stEllEM.MLocParaAve3+stEllEM.MLocPerpAve3;
        stEllEM.F0E4Ave3 = stEllEM.Apara3.*(2*stEllEM.MLocAve3 - stEllEM.Apara3) ...
            + (stEllEM.Aperp3 - stEllEM.Apara3).^2 .* repmat(stEllGeom.exiz4ave,nNbLambda,1);
        stEllEM.F0E4PerpAve3 = (stEllEM.Aperp3).^2 .* repmat(stEllGeom.exiz4ave,nNbLambda,1);
    end
end