function stEllGeom = EllGeomFact(a,b,c,sOption)
% Returns geometrical factors associated with a given general ellipsoid
% All properties are computed using double integrals
% as explained in Sec. G.1.5
%
% Parameters:
% - a,b,c: scalars or row vectors [1 x G]
%          semi-axis length along x,y,z
% - sOptions: string (optional)
%           if 'L', only L_1, L_2, L_3 are returned
%           if 'x','y', or 'z', only properties related to corresponding
%           axis are computed
%           if 'All' (default), then all properties are returned
% Returns:
% - stEllGeom: structure with fields, all of size [1 x G]
% stEllGeom.a, b, c for future reference
% stEllGeom.S: surface area (in squared units of a, b, and c)
% stEllGeom.V: volume (in cube units of a, b, and c)
% stEllGeom.type: ='General' (type of ellipsoid)
% stEllGeom.L1, L2, L3: Geometrical factors (see Sec. G.1.5)
% stEllGeom.exix2ave: <|e_xi . e_x|^2>
% stEllGeom.exiy2ave: <|e_xi . e_y|^2>
% stEllGeom.exiz2ave: <|e_xi . e_z|^2>
% stEllGeom.exix4ave: <|e_xi . e_x|^4>
% stEllGeom.exiy4ave: <|e_xi . e_y|^4>
% stEllGeom.exiz4ave: <|e_xi . e_z|^4>
% stEllGeom.exix2y2ave: <|e_xi . e_x|^2 |e_xi . e_y|^2>
% stEllGeom.exix2z2ave: <|e_xi . e_x|^2 |e_xi . e_z|^2>
% stEllGeom.exiy2z2ave: <|e_xi . e_y|^2 |e_xi . e_z|^2>
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

if nargin<4, sOption='All'; end

bxaxis=true; byaxis=true; bzaxis=true;
if strcmpi(sOption,'x'), byaxis=false; bzaxis=false; end
if strcmpi(sOption,'y'), bxaxis=false; bzaxis=false; end
if strcmpi(sOption,'z'), bxaxis=false; byaxis=false; end

nNbG=length(a);

stEllGeom.a=a;
stEllGeom.b=b;
stEllGeom.c=c;
stEllGeom.type='General'; % for reference
stEllGeom.V = 4/3*pi*a.*b.*c;

% initialize all variables (in case they are arrays, i.e. if nNbG>1)
zeroa=0*a; % zeros same size as a
stEllGeom.S=zeroa;
if (bxaxis), stEllGeom.L1=zeroa;
stEllGeom.exix2ave=zeroa; stEllGeom.exix4ave=zeroa; end
if (byaxis), stEllGeom.L2=zeroa;
stEllGeom.exiy2ave=zeroa; stEllGeom.exiy4ave=zeroa; end
if (bzaxis), stEllGeom.L3=zeroa;
stEllGeom.exiz2ave=zeroa; stEllGeom.exiz4ave=zeroa; end
if strcmpi(sOption,'All')
    stEllGeom.exix2y2ave=zeroa;
    stEllGeom.exix2z2ave=zeroa;
    stEllGeom.exiy2z2ave=zeroa;
end
        
% loop through each set of geometrical parameters
for indg=1:nNbG

    abc=a(indg)*b(indg)*c(indg);
    % function for sqrt{s}
    fsqrts=@(t,f) (b(indg)^2*c(indg)^2*sin(t).^2.*cos(f).^2 ...
        +a(indg)^2*c(indg)^2*sin(t).^2.*sin(f).^2+a(indg)^2*b(indg)^2*cos(t).^2).^(1/2);

    % surface area
    dfint = @(t,f) sin(t).*fsqrts(t,f);
    S=dblquad(dfint,0,pi,0,2*pi);
    stEllGeom.S(indg)=S;
    % function for sin(t)/r^3
    fstovr3=@(t,f) sin(t)./(a(indg)^2*sin(t).^2.*cos(f).^2 + b(indg)^2*sin(t).^2.*sin(f).^2 ...
        + c(indg)^2*cos(t).^2).^(3/2);

    % geometrical factors (Eq. G.43 and permutations)
    if (bxaxis)
        % for x/a
        fxova= @(t,f) sin(t).*cos(f);
        % function to intergrate (function of theta=t and phi=f)
        dfint = @(t,f) abc/(4*pi)*fxova(t,f).^2 .* fstovr3(t,f);
        stEllGeom.L1(indg)=dblquad(dfint,0,pi,0,2*pi);
    end
    if (byaxis)
        % for y/b
        fyovb= @(t,f) sin(t).*sin(f);
        dfint = @(t,f) abc/(4*pi)*fyovb(t,f).^2 .* fstovr3(t,f);
        stEllGeom.L2(indg)=dblquad(dfint,0,pi,0,2*pi);
    end
    if (bzaxis)
        % for z/c
        fzovc= @(t,f) cos(t);
        dfint = @(t,f) abc/(4*pi)*fzovc(t,f).^2 .* fstovr3(t,f);
        stEllGeom.L3(indg)=dblquad(dfint,0,pi,0,2*pi);
    end

    if ~strcmpi(sOption,'L') % compute other geometrical averages

        if (bxaxis)
            dfint= @(t,f) (b(indg)*c(indg))^2 *fxova(t,f).^2 ./ fsqrts(t,f) .* sin(t);
            stEllGeom.exix2ave(indg)=dblquad(dfint,0,pi,0,2*pi)/S;
            dfint= @(t,f) (b(indg)*c(indg))^4 * fxova(t,f).^4 ./ fsqrts(t,f).^3 .* sin(t);
            stEllGeom.exix4ave(indg)=dblquad(dfint,0,pi,0,2*pi)/S;
        end
        if (byaxis)
            dfint= @(t,f) (a(indg)*c(indg))^2 *fyovb(t,f).^2 ./ fsqrts(t,f) .* sin(t);
            stEllGeom.exiy2ave(indg)=dblquad(dfint,0,pi,0,2*pi)/S;
            dfint= @(t,f) (a(indg)*c(indg))^4 * fyovb(t,f).^4 ./ fsqrts(t,f).^3 .* sin(t);
            stEllGeom.exiy4ave(indg)=dblquad(dfint,0,pi,0,2*pi)/S;
        end
        if (bzaxis)
            if (bxaxis && byaxis)
                stEllGeom.exiz2ave(indg)=1-stEllGeom.exix2ave(indg)-stEllGeom.exiy2ave(indg);
            else
                % alternative for direct calculation of exiz2ave
                dfint= @(t,f) (a(indg)*b(indg))^2 *fzovc(t,f).^2 ./ fsqrts(t,f) .* sin(t);
                stEllGeom.exiz2ave(indg)=dblquad(dfint,0,pi,0,2*pi)/S;
            end
            dfint= @(t,f) (a(indg)*b(indg))^4 * fzovc(t,f).^4 ./ fsqrts(t,f).^3 .* sin(t);
            stEllGeom.exiz4ave(indg)=dblquad(dfint,0,pi,0,2*pi)/S;
        end

        if strcmpi(sOption,'All')
            stEllGeom.exix2y2ave(indg)=(1-2*stEllGeom.exiz2ave(indg)+stEllGeom.exiz4ave(indg) ...
                -stEllGeom.exix4ave(indg)-stEllGeom.exiy4ave(indg))/2;
            stEllGeom.exix2z2ave(indg)=(1-2*stEllGeom.exiy2ave(indg)+stEllGeom.exiy4ave(indg) ...
                -stEllGeom.exix4ave(indg)-stEllGeom.exiz4ave(indg))/2;
            stEllGeom.exiy2z2ave(indg)=(1-2*stEllGeom.exix2ave(indg)+stEllGeom.exix4ave(indg) ...
                -stEllGeom.exiy4ave(indg)-stEllGeom.exiz4ave(indg))/2;
        end
        % alternative for direct calculation of cross-products
        % dfint= @(t,f) (abc*c(indg))^2 * fxova(t,f).^2 .* fyovb(t,f).^2 ./ fsqrts(t,f).^3 .* sin(t);
        % stEllGeom.exix2y2ave(indg)=dblquad(dfint,0,pi,0,2*pi)/S;
        % dfint= @(t,f) (abc*b(indg))^2 * fxova(t,f).^2 .* fzovc(t,f).^2 ./ fsqrts(t,f).^3 .* sin(t);
        % stEllGeom.exix2z2ave(indg)=dblquad(dfint,0,pi,0,2*pi)/S;
        % dfint= @(t,f) (abc*a(indg))^2 * fyovb(t,f).^2 .* fzovc(t,f).^2 ./ fsqrts(t,f).^3 .* sin(t);
        % stEllGeom.exiy2z2ave(indg)=dblquad(dfint,0,pi,0,2*pi)/S;

    end
end




