function stEllGeom = EllOblateGeomFact(a,c,sOption)
% Returns geometrical factors associated with a given oblate spheroid (for which a=b>c)
% The relevant formulae are given in Sec. G.2.
%
% Parameters:
% - a,c: scalars or row vectors [1 x G]
%          semi-axis length along x (same as y), and z
% - sOptions: string (optional)
%           if 'L', only L_1, L_3 are returned
%           if 'x', or 'z', only properties related to corresponding
%           axis are computed
%           if 'All' (default), then all properties are returned
% Returns:
% - stEllGeom: structure with fields, all of size [1 x G]
% stEllGeom.a, c for future reference
% stEllGeom.S: surface area (in squared units of a, b, and c)
% stEllGeom.V: volume (in cube units of a, b, and c)
% stEllGeom.type: ='Oblate' (type of ellipsoid)
% stEllGeom.L1, L3: Geometrical factors (see Sec. G.1.5)
% stEllGeom.exix2ave: <|e_xi . e_x|^2>
% stEllGeom.exiz2ave: <|e_xi . e_z|^2>
% stEllGeom.exix4ave: <|e_xi . e_x|^4>
% stEllGeom.exiz4ave: <|e_xi . e_z|^4>
% stEllGeom.exix2y2ave: <|e_xi . e_x|^2 |e_xi . e_y|^2>
% stEllGeom.exix2z2ave: <|e_xi . e_x|^2 |e_xi . e_z|^2>
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

if nargin<4, sOption='All'; end

bxaxis=true; bzaxis=true;
if strcmpi(sOption,'x'), bzaxis=false; end
if strcmpi(sOption,'z'), bxaxis=false; end

stEllGeom.a=a;
stEllGeom.c=c;
stEllGeom.type='Oblate'; % for reference
stEllGeom.V = 4/3*pi*a.^2.*c;

stEllGeom.h=a./c; % aspect ratio
eo=sqrt(1-(c./a).^2); % eccentricity (Eq. G.44, note that the sqrt is missing in the book)
stEllGeom.e=eo; 

fo=(1-eo.^2)./(2*eo) .* log( (1+eo)./(1-eo)); % Eq. G.46

% surface area
stEllGeom.S=2*pi*a.^2 .* (1+fo); % Eq. G.47

% geometrical factors
L1=0.5./(eo.^2).* ( sqrt(1-eo.^2)./eo .* asin(eo) - (1-eo.^2)); % Eq. G.45

if (bxaxis)
    stEllGeom.L1=L1;
end
if (bzaxis)
    stEllGeom.L3=1-2*L1; % Eq. G.45
end

if ~strcmpi(sOption,'L') % compute other geometrical averages

    exiz2ave=1./eo.^2 .*(1-fo)./(1+fo); % Eq. G.48
    exiz4ave=1./eo.^4 .*(3-2*eo.^2-3*fo)./(1+fo); % Eq. G.50
    if (bxaxis)
        stEllGeom.exix2ave=0.5*(1-exiz2ave); % Eq. G.49
        stEllGeom.exix4ave=3/8*(1-2*exiz2ave+exiz4ave); % Eq. G.51
        % alternative direct calculation
        % stEllGeom.exix4ave=3/8*(1-eo.^2)./eo.^4.*(3-eo.^2-(3+eo.^2).*fo)./(1+fo); % Eq. G.51
    end
    if (bzaxis)
        stEllGeom.exiz2ave=exiz2ave;
        stEllGeom.exiz4ave=exiz4ave;
    end
    if strcmpi(sOption,'All')
        stEllGeom.exix2y2ave= (1-2*exiz2ave+exiz4ave ...
                -2*stEllGeom.exix4ave)/2;
        stEllGeom.exix2z2ave=(1-2*stEllGeom.exix2ave-stEllGeom.exiz4ave)/2;
    end
end




