function stEllGeom = EllProlateGeomFact(a,c,sOption)
% Returns geometrical factors associated with a given prolate spheroid (for which a>b=c)
% The relevant formulae are given in Sec. G.3.
%
% Parameters:
% - a,c: scalars or row vectors [1 x G]
%        semi-axis length along x and and z (same as y) 
% - sOptions: string (optional)
%           if 'L', only L_1, L_3 are returned
%           if 'x', or 'z', only properties related to corresponding
%           axis are computed
%           if 'All' (default), then all properties are returned
% Returns:
% - stEllGeom: structure with fields, all of size [1 x G]
% stEllGeom.a, c for future reference
% stEllGeom.S: surface area (in squared units of a, b, and c)
% stEllGeom.V: volume (in cube units of a, b, and c)
% stEllGeom.type: ='Prolate' (type of ellipsoid)
% stEllGeom.L1, L3: Geometrical factors (see Sec. G.1.5)
% stEllGeom.exix2ave: <|e_xi . e_x|^2>
% stEllGeom.exiz2ave: <|e_xi . e_z|^2>
% stEllGeom.exix4ave: <|e_xi . e_x|^4>
% stEllGeom.exiz4ave: <|e_xi . e_z|^4>
% stEllGeom.exix2z2ave: <|e_xi . e_x|^2 |e_xi . e_z|^2>
% stEllGeom.exiy2z2ave: <|e_xi . e_y|^2 |e_xi . e_z|^2>
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

if nargin<4, sOption='All'; end

bxaxis=true; bzaxis=true;
if strcmpi(sOption,'x'), bzaxis=false; end
if strcmpi(sOption,'z'), bxaxis=false; end

stEllGeom.a=a;
stEllGeom.c=c;
stEllGeom.type='Prolate'; % for reference
stEllGeom.V = 4/3*pi*a.*c.^2;

stEllGeom.h=a./c; % aspect ratio
ep=sqrt(1-(c./a).^2); % eccentricity (Eq. G.60, note that the srqt is missing in the book)
stEllGeom.e=ep; 

fp=1./sqrt(1-ep.^2)./(ep) .* asin(ep); % Eq. G.62

% surface area
stEllGeom.S=2*pi*c.^2 .* (1+fp); % Eq. G. 63

% geometrical factors
L1=(1-ep.^2)./(ep.^2) .* ( -1 + 1./(2*ep) .* log((1+ep)./(1-ep)) ); % Eq. G.61

if (bxaxis)
    stEllGeom.L1=L1;
end
if (bzaxis)
    stEllGeom.L3=(1-L1)/2; % Eq. G.61
end

if ~strcmpi(sOption,'L') % compute other geometrical averages

    exiz2ave=1./(2*ep.^2) .*(1-(1-2*ep.^2).*fp)./(1+fp); % Eq. G.65
    exiz4ave=3/8./ep.^4 .*(3-2*ep.^2-(3-4*ep.^2).*fp)./(1+fp); % Eq. G.66
    if (bxaxis)
        stEllGeom.exix2ave=(1-2*exiz2ave); 
        stEllGeom.exix4ave=1-4*exiz2ave+8/3*exiz4ave; % Eq. G.67
        % alternative direct calculation
        % stEllGeom.exix4ave=(1-ep.^2)./ep.^4.*(3-ep.^2-3*(1-ep.^2).*fp)./(1+fp); 
    end
    if (bzaxis)
        stEllGeom.exiz2ave=exiz2ave;
        stEllGeom.exiz4ave=exiz4ave;
    end
    if strcmpi(sOption,'All')
        stEllGeom.exix2z2ave= (1-2*exiz2ave-stEllGeom.exix4ave)/2;
        stEllGeom.exiy2z2ave=(1-2*stEllGeom.exix2ave+stEllGeom.exix4ave ...
            -2*exiz4ave)/2;
    end
end




