function stEfarAllP=DipFarFieldAllP(stMdip,nNbTheta,stPinTaunPnTn)
% Calculates far-field properties (scattered field + dipole field) for dipole emission close to a sphere
%
% Parameters:
% - stMdip: structure with results of the Mie computation
%           can be obtained by calling DipSolveSingleSphere with
%           sCoeff='coeff'
% - nNbTheta: integer scalar
%             number of theta points used for computations
% - stPinTaunPnTn: structure (optional)
%              with functions of theta pi_n, tau_n, p_n, t_n
%              if omitted, then the functions are computed from scrath
%              it is faster to pass this structure as argument if these
%              functions have already been calculated 
% 
% Returns: structure stEfarAllP with parameters and far fields in the form
%          of Ecr, Ect, Esf, Em0r, Em0t [L x T].
%          See the supplementary information for more details.
%          The radiation profiles for special cases are also returned.
% - stEfarAllP.x: [L x 1]
% - stEfarAllP.theta: [1 x T]
% - stEfarAllP.lambda: [L x 1]
% - stEfarAllP.MdRadPerpAllPhi: [L x T] M^d_Rad for perp dipole (phi-independent)
% - stEfarAllP.MdRadParaPhi0: [L x T] M^d_Rad at phi=0 for para dipole
% - stEfarAllP.MdRadParaPhi90: [L x T] M^d_Rad at phi=pi/2 for para dipole
% - stEfarAllP.MRadPerp: [L x 1] MRadPerp obtained from averaging (Eq. 4.37)
% - stEfarAllP.MRadPara: [L x 1] MRadPara obtained from averaging (Eq. 4.37)
% The latter two should be consistent with the direct results of DipMcoeff.
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

global noCheckSum;
if (isempty(noCheckSum) || ~noCheckSum)
    disp 'DipFarFieldAllP: Radiation profiles for Mie dipole emission - CheckSum ON'
else
    disp 'DipFarFieldAppP: Radiation profiles for Mie dipole emission - CheckSum OFF'
end


% get theta dependence if not provided
theta=linspace(0,pi,nNbTheta); % row [1 x T]
if nargin < 3
    stPinTaunPnTn=DipPinTaunPnTn(stMdip.nNmax,transpose(theta)); % fields are [T x nNmax]
end

% stMdip already contains fields cn1, dn1, dn0
stEfarAllP=DipEgenThetaAllPhi(stMdip.lambda,stMdip.epsilonM,stMdip.dn0+stMdip.fn0,stMdip.cn1+stMdip.en1,stMdip.dn1+stMdip.fn1,Inf,theta,'h1',stPinTaunPnTn);
% stEfar contains Ecr, Ect, Esf, Em0r, Em0t

stEfarAllP.x=stMdip.x;
stEfarAllP.theta=theta;
stEfarAllP.lambda=stMdip.lambda;

% computes MdRad for special cases:
stEfarAllP.MdRadPerpAllPhi=8*pi/3*(abs(stEfarAllP.Em0r).^2+ ...
        abs(stEfarAllP.Em0t).^2);
stEfarAllP.MdRadParaPhi0=8*pi/3*(abs(stEfarAllP.Ecr).^2+ ...
        abs(stEfarAllP.Ect).^2);
stEfarAllP.MdRadParaPhi90=8*pi/3*(abs(stEfarAllP.Esf).^2);
    
% computes averages for MRadPara and MRadPerp (to check for consistency)
dtheta=pi/(nNbTheta-1);
sintcol=transpose(sin(theta)); % [T x 1]

% these results are [L x 1]
stEfarAllP.MRadPerp=3/4 * (dtheta)* stEfarAllP.MdRadPerpAllPhi * sintcol;
stEfarAllP.MRadPara=3/8 * (dtheta)* (stEfarAllP.MdRadParaPhi0 + ...
    stEfarAllP.MdRadParaPhi90) * sintcol;

disp 'DipFarFieldAllP: done...'
disp ' '


