function stMdip=DipMcoeff(xp,stGD,a,d,s,nNmaxESA,sCoeffSum)
% Calculates the radiative and total decay rate EFs for dipole emission from the Mie susceptibilities
% The relevant formulae are given in Eqs. H.95, H.96, H.102, H.103.
% The ESA approximation is used for large N between nNmax+1 and
% nNmaxESA for MTot to avoid slow convergence problems
% for absorbing particles when d is small (see Sec. H.5.1).
% If sCoeffSum='coeffSum', then the terms in the series are returned
% so that the actual convergence of the series can be checked.
%
% Parameters:
% - xp:     column vector [L x 1]
%           wavelength-dependent xp=kM*(a+d)
% - stGD:  structure with two fields, Gamma and Delta
%           each a matrix [L x nNmax]
%           with suceptibilities Gamma_n and Delta_n
%           can be obtained from function GenSuscepGDAB
% - a:      scalar [1 x 1]
%           radius of sphere
% - d:      scalar [1 x 1]
%           distance of dipole to surface
% - s:      column vector [L x 1]
%           wavelength-dependent relative refractive index
%           s^2=epsilonIn/epsilonM (Eq. H. 46)
% - nNmaxESA: optional integer [1x1]
%           maximum N for MTot in the ESA. Default is nNmaxESA=nNmax, i.e.
%           the ESA is not used
% - sCoeffSum: optional string
%           if sCoeffSum='coeffSum' then the coefficients for all sums
%           are also returned as [L x nNmax] (for MRad) or [L x nNmaxESA]
%           (for MTot)arrays.
%           if sCoeffSum='ESAonly' then only MTot is calculated with ALL
%           terms in the ES approximation (from n=1). Coeffs in the series
%           are also returned
%
% Returns: structure stMdip with four fields
%          each a matrix [L x 1] and four optional coeffs fields as [L x
%          nNmax] matrices
% - stMdip.MRadPerp: [L x 1] wavelength-dependent radiative decay rate EF
%                    for perpendicular dipole
% - stMdip.MTotPerp: [L x 1] wavelength-dependent total decay rate EF
%                    for perpendicular dipole
% - stMdip.MRadPara: [L x 1] wavelength-dependent radiative decay rate EF
%                    for parallel dipole
% - stMdip.MTotPara: [L x 1] wavelength-dependent total decay rate EF
%                    for parallel dipole
% - stMdip.MRadPerpCoeffs [L x nNmax]: coeffs of the sums over n
% - stMdip.MRadParaCoeffs [L x nNmax]: coeffs of the sums over n
% - stMdip.MTotPerpCoeffs [L x nNmaxESA]: coeffs of the sums over n
% - stMdip.MTotParaCoeffs [L x nNmaxESA]: coeffs of the sums over n
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

if (nargin<6), sCoeffSum='No'; end;

nNbLambda=length(xp);

if strcmpi(sCoeffSum,'ESAonly')
    sCoeffSum='coeffSum';
    nNmax=0;
    stMdip.MTotPerp=[];
    stMdip.MTotPara=[];
    stMdip.MTotPerpCoeffs=[];
    stMdip.MTotParaCoeffs=[];
% goto to ESA computations of MTot only (at the end)
else
    % normal procedure starts here
    nNmax=size(stGD.Gamma,2);

    if (nargin<5), nNmaxESA=nNmax; end;

    % get psi_n(xp), xi_n(xp) and derivatives
    stRBxp=GenRBall(nNmax,xp);
    
    n=transpose(1:nNmax); % [nNmax x 1]
    cc1 = (2.*n+1); % [nNmax x 1]
    cc2 = cc1 .*(n+1).*n; % [nNmax x 1]
    
    xp2inv=1./(xp.^2);
    
    % caculate M_{Rad}
    % From Eq. H.95
    tmp1=GenCheckSum2Mat(stRBxp.psi, stGD.Delta.*stRBxp.xi,'tmp1_1','DipMcoeff');
    tmpMat= abs(tmp1).^2; % [L x nNmax]
    stMdip.MRadPerp = 3/2* xp2inv.^2 .* (tmpMat * cc2); % [L x 1]
    % no checksum required since this is a sum of positive numbers
    
    if strcmpi(sCoeffSum,'coeffsum')
        xp2invmat=repmat(xp2inv,1,nNmax);
        stMdip.MRadPerpCoeffs=3/2*xp2invmat.^2 .* (tmpMat .* repmat(transpose(cc2),nNbLambda,1));
    end

    % From Eq. H.96
    tmp1=GenCheckSum2Mat(stRBxp.psi, stGD.Gamma.*stRBxp.xi,'tmp1_2','DipMcoeff');
    tmp2=GenCheckSum2Mat(stRBxp.Dpsi, stGD.Delta.*stRBxp.Dxi,'tmp2_2','DipMcoeff');
    tmpMat= abs(tmp1).^2 + abs(tmp2).^2; % [L x nNmax]
    stMdip.MRadPara = 3/4*xp2inv .* (tmpMat * cc1); % [L x 1]
    
    if strcmpi(sCoeffSum,'coeffsum')
        stMdip.MRadParaCoeffs=3/4*xp2invmat .* (tmpMat .* repmat(transpose(cc1),nNbLambda,1));
    end

    % calculate M_{Tot}
    % Note that this may produce loss-of-precision warnings
    % for non-absorbing spheres. In this case, M_{Tot}
    % should simply be derived from M_{Rad} (since M_{NR}=0).
    xi2=stRBxp.xi.^2;
    Dxi2=stRBxp.Dxi.^2;
    
    % Get MTot from Eq. H.102
    tmpMat=GenCheckSumReal(stGD.Delta .* xi2,'tmpMat_2','DipMcoeff'); % [L x nNmax]
    stMdip.MTotPerp = 1+3/2*xp2inv.^2 .* GenCheckSumMatVec(tmpMat,cc2,'MTotPerp','DipMcoeff'); % [L x 1]
    
    if strcmpi(sCoeffSum,'coeffsum')
        stMdip.MTotPerpCoeffs=3/2*xp2invmat.^2 .* (tmpMat .* repmat(transpose(cc2),nNbLambda,1));
    end

    % from Eq. H.103
    tmp1=GenCheckSumReal(stGD.Delta .* Dxi2,'tmp1_3','DipMcoeff');
    tmp2=GenCheckSumReal(stGD.Gamma .* xi2,'tmp2_3','DipMcoeff');
    tmpMat= GenCheckSum2Mat(tmp1,tmp2,'tmpMat_3','DipMcoeff'); % [L x nNmax]
    stMdip.MTotPara  = 1+3/4*xp2inv .* GenCheckSumMatVec(tmpMat,cc1,'MTotPara','DipMcoeff'); % [L x 1]
    
    if strcmpi(sCoeffSum,'coeffsum')
        stMdip.MTotParaCoeffs=3/4*xp2invmat .* (tmpMat .* repmat(transpose(cc1),nNbLambda,1));
    end
    clear tmp1 tmp2 tmpMat xi2 Dxi2;
end    

% Apply corrections to MTot using the ESA approx for larger n
if nNmaxESA>nNmax
    nES=(nNmax+1):nNmaxESA; % [1 x N2]
    nNbNES=length(nES);
    ccES = (nES+1).*(a/(a+d)).^(2*nES+1); 
    s2mat=repmat(s.^2,1,nNbNES); % [L x N2]
    imAlphaES=imag( (s2mat-1)./(s2mat+1+repmat(1./nES,nNbLambda,1))); % [L x N2]
    xp3inv=1./(xp.^3);
    MTotPerpES=3/2*xp3inv.* (imAlphaES * transpose(ccES.*(nES+1)));
    MTotParaES=3/4*xp3inv.* (imAlphaES * transpose(ccES.*(nES)));
    stMdip.MTotPerp =stMdip.MTotPerp + MTotPerpES;
    stMdip.MTotPara =stMdip.MTotPara + MTotParaES;
    if strcmpi(sCoeffSum,'coeffsum')
        xp3invmat=repmat(xp3inv,1,nNbNES);
        stMdip.MTotPerpCoeffs = [stMdip.MTotPerpCoeffs, 3/2*xp3invmat .* imAlphaES .* repmat(ccES.*(nES+1),nNbLambda,1)];
        stMdip.MTotParaCoeffs = [stMdip.MTotParaCoeffs, 3/4*xp3invmat .* imAlphaES .* repmat(ccES.*(nES),nNbLambda,1)];
    end
end

