function DipPlotEfarAllP(stEfarAllP, lambda0)
% Plots typical dipole radiation profiles for a few wavelengths
% These are plotted for typical cases (perpendicular,
% parrallel, and oblique dipoles)
% as theta dependent functions for a fixed phi (0 or pi/2).
% For phi=0 (i.e. plot in xOz),
% the dipole arrow is shown on the plot.
%
% Parameters:
% - stEfarScaAllP: obtained from DipFarFieldAllP
% - lambda0: scalar or vector (short vector otherwise plot would be messy)
%            wavelength(s) in nm for which the plots are done
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

lambda=stEfarAllP.lambda;
theta=stEfarAllP.theta;
nNbTheta=length(theta);
indNegTheta=length(theta):-1:2;
indAllTheta=[indNegTheta,1:length(theta)];
thetaAll=[-theta(indNegTheta), theta];

sLegend=cell(1,length(lambda0));
MdRadParaPhi0=zeros(length(lambda0),nNbTheta);
MdRadParaPhi90=zeros(length(lambda0),nNbTheta);
MdRadPerpAllPhi=zeros(length(lambda0),nNbTheta);
MdRadPxPzPhi0=zeros(length(lambda0),nNbTheta);
MdRadPxPzPhi180=zeros(length(lambda0),nNbTheta);
MdMaxParaPhi0=0;
MdMaxParaPhi90=0;
MdMaxPerpAllPhi=0;
MdMaxPxPzPhi0=0;

for ll=1:length(lambda0)
    ind=find(lambda==lambda0(ll),1);
    if isempty(ind)
        disp(['DipPlotEfarAllP: lambda=' num2str(lambda0(ll)) ...
            ' cannot be found. Using lambda=' num2str(lambda(1)) ' instead']);
        ind=1;
    end
    % theta-dependent MdRadPerp
    MdRadPerpAllPhi(ll,:)=stEfarAllP.MdRadPerpAllPhi(ind,:);
    MdMaxPerpAllPhi=max(MdMaxPerpAllPhi,max(MdRadPerpAllPhi(ll,:))); % find limits for axis scale
    % theta-dependent MdRadParaPhi0
    MdRadParaPhi0(ll,:)=stEfarAllP.MdRadParaPhi0(ind,:);
    MdMaxParaPhi0=max(MdMaxParaPhi0,max(MdRadParaPhi0(ll,:))); % find limits for axis scale
    % theta-dependent MdRadParaPhi90
    MdRadParaPhi90(ll,:)=stEfarAllP.MdRadParaPhi90(ind,:);;
    MdMaxParaPhi90=max(MdMaxParaPhi90,max(MdRadParaPhi90(ll,:))); % find limits for axis scale
    % theta-dependent MdRad at Phi=0 for px=pz
    % note that the symmetry around the z axis is lost in this case
    % For theta<0, the value must be obtained from |theta| and phi=pi, i.e.
    MdRadPxPzPhi0(ll,:)=8*pi/3*1/2*( ...
        abs(stEfarAllP.Ecr(ind,:)+stEfarAllP.Em0r(ind,:)).^2+ ...
        abs(stEfarAllP.Ect(ind,:)+stEfarAllP.Em0t(ind,:)).^2 );
    MdMaxPxPzPhi0=max(MdMaxPxPzPhi0,max(MdRadPxPzPhi0(ll,:))); % find limits for axis scale
    MdRadPxPzPhi180(ll,:)=8*pi/3*1/2*( ...
        abs(-stEfarAllP.Ecr(ind,:)+stEfarAllP.Em0r(ind,:)).^2+ ...
        abs(-stEfarAllP.Ect(ind,:)+stEfarAllP.Em0t(ind,:)).^2 );
    MdMaxPxPzPhi0=max(MdMaxPxPzPhi0,max(MdRadPxPzPhi180(ll,:))); % find limits for axis scale
    % prepare legend for figure
    sLegend{ll}=['\lambda=' num2str(lambda(ind)) 'nm'];
end

% define four colors
scol='brgm';

% create, position, and resize figure
scrsz = get(0,'ScreenSize'); % scrsz(4) contains screen height
figAspectRatio=1;
figHeight=scrsz(4)-150;
figWidth=figAspectRatio*figHeight;
figure('Name','Radiation profiles', ...
    'Position',[(scrsz(3)-figWidth)/2 50 figWidth figHeight]);

% length of dipole arrow in relative units
plength=0.6;

hpl1=subplot(2,2,1);
set(hpl1,'Outerposition',[0,0.5,0.5,0.5]);

h = polar([0 2*pi], [0 MdMaxParaPhi0]);
delete(h);
hold on;
for ll=1:length(lambda0)
    polar(thetaAll,MdRadParaPhi0(ll,indAllTheta),scol(1+mod(ll-1,4)));
end
quiver(0,-plength/2*MdMaxParaPhi0,0,plength*MdMaxParaPhi0,'Color',[0.5;0;0.5],'LineWidth',1.5,'MaxHeadSize',0.8);
rectangle('Position',MdMaxParaPhi0*[-0.5,-0.1,0.2,0.2],'Curvature',[1,1],...
          'FaceColor',[0.8 0.8 0.8]);
hold off;
title('M^{d-Para}_{Rad}(\theta, \phi=0)');
xlabel('Theta [degrees]'); ylabel('M^d_{Rad}');
legend(sLegend,'Location','NorthEastOutside');

hpl2=subplot(2,2,2);
set(hpl2,'Outerposition',[0.5,0.5,0.5,0.5]);
h = polar([0 2*pi], [0 MdMaxParaPhi90]);
delete(h);
hold on;
for ll=1:length(lambda0)
    polar(thetaAll,MdRadParaPhi90(ll,indAllTheta),scol(1+mod(ll-1,4)));
end
% dipole is perpendicular to plane of figure here
quiver(0,0,0,0,'Color',[0.5;0;0.5],'LineWidth',1.5,'MaxHeadSize',0.8);
rectangle('Position',MdMaxParaPhi90*[-0.5,-0.1,0.2,0.2],'Curvature',[1,1],...
          'FaceColor',[0.8 0.8 0.8]);
hold off;
title('M^{d-Para}_{Rad}(\theta, \phi=90^\circ)');
%xlabel('Theta [degrees]'); ylabel('M^d_{Rad}');
legend(sLegend,'Location','NorthEastOutside');

hpl3=subplot(2,2,3);
set(hpl3,'Outerposition',[0,0,0.5,0.5]);
h = polar([0 2*pi], [0 MdMaxPerpAllPhi]);
delete(h);
hold on;
for ll=1:length(lambda0)
    polar(thetaAll,MdRadPerpAllPhi(ll,indAllTheta),scol(1+mod(ll-1,4)));
end
quiver(-plength/2*MdMaxPerpAllPhi,0,plength*MdMaxPerpAllPhi,0,'Color',[0.5;0;0.5],'LineWidth',1.5,'MaxHeadSize',0.8);
rectangle('Position',MdMaxPerpAllPhi*[-0.5,-0.1,0.2,0.2],'Curvature',[1,1],...
          'FaceColor',[0.8 0.8 0.8]);
hold off;
title('M^{d-Perp}_{Rad}(\theta) (\phi-independent)');
%xlabel('Theta [degrees]'); ylabel('M^d_{Rad}');
legend(sLegend,'Location','NorthEastOutside');

hpl4=subplot(2,2,4);
set(hpl4,'Outerposition',[0.5,0,0.5,0.5]);
h = polar([0 2*pi], [0 MdMaxPxPzPhi0]);
delete(h);
hold on;
for ll=1:length(lambda0)
    % note that the symmetry around the z axis is lost in this case
    % For theta<0, the value must be obtained from |theta| and phi=pi, i.e.
    polar(thetaAll,[MdRadPxPzPhi180(ll,indNegTheta), MdRadPxPzPhi0(ll,1:length(theta))],scol(1+mod(ll-1,4)));
end
quiver(-plength/sqrt(8)*MdMaxPxPzPhi0,-plength/sqrt(8)*MdMaxPxPzPhi0, ...
    plength/sqrt(2)*MdMaxPxPzPhi0,plength/sqrt(2)*MdMaxPxPzPhi0,'Color',[0.5;0;0.5],'LineWidth',1.5,'MaxHeadSize',0.8);
rectangle('Position',MdMaxPxPzPhi0*[-0.5,-0.1,0.2,0.2],'Curvature',[1,1],...
          'FaceColor',[0.8 0.8 0.8]);
hold off;
title('M^{d-(p_x=p_z)}_{Rad}(\theta,\phi=0,180^\circ)');
%xlabel('Theta [degrees]'); ylabel('M^d_{Rad}');
legend(sLegend,'Location','NorthEastOutside');
