function DipPlotEfarForP(stEfarAllP, lambda0,px,pz,phi1,phi2)
% Plots the dipole radiation profiles at a few wavelengths for a given px,pz and for 2 phi's
% These are plotted as theta dependent functions for a fixed phi (0 or pi/2 as default).
% For phi=0 (i.e. plot in xOz),
% the dipole arrow is shown on the plot.

% Parameters:
% - stEfarScaForP: obtained from DipFarFieldForP
% - lambda0: scalar or vector (short vector otherwise plot would be messy)
%            wavelength(s) in nm for which the plots are done
% - px,pz: scalars [1 x 1]
%          component of dipole
% - phi1,phi2: scalars [1 x 1]
%            phi's (IN RADIAN) for which the two plots are produced (default is 0 and
%            pi/2)
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

if nargin<5, phiarray=[0,pi/2]; end;
if nargin==5, phiarray=[0,phi1]; end;
if nargin==6, phiarray=[phi1,phi2]; end;

lambda=stEfarAllP.lambda;
theta=stEfarAllP.theta;
nNbTheta=length(theta);
indPosTheta=1:length(theta);
indNegTheta=length(theta):-1:2;
%indAllTheta=[indNegTheta,indPosTheta];
thetaAll=[-theta(indNegTheta), theta];

sLegend=cell(1,length(lambda0));
MdRadPhi=zeros(length(lambda0),nNbTheta);
MdRadPhippi=zeros(length(lambda0),nNbTheta);

pnorm=sqrt(px^2+pz^2);
pxnorm=px/pnorm;
pznorm=pz/pnorm;

% create, position, and resize figure
scrsz = get(0,'ScreenSize'); % scrsz(3) contains screen width
figAspectRatio=2;
figWidth=scrsz(3)-100;
figHeight=figWidth/figAspectRatio;
figure('Name','Radiation profiles', ...
    'Position',[(scrsz(3)-figWidth)/2 50 figWidth figHeight]);
% length of dipole arrow in relative units
plength=0.6;
% define four colors
scol='brgm';


for indphi=1:2
    phi=phiarray(indphi);
    MdMax=0;
    for ll=1:length(lambda0)
        ind=find(lambda==lambda0(ll),1);
        if isempty(ind)
            disp(['DipPlotEfarForP: lambda=' num2str(lambda0(ll)) ...
                ' cannot be found. Using lambda=' num2str(lambda(1)) ' instead']);
            ind=1;
        end
        Er2Phi=abs(pxnorm*cos(phi)*stEfarAllP.Ecr(ind,:)+pznorm*stEfarAllP.Em0r(ind,:)).^2;
        Et2Phi=abs(pxnorm*cos(phi)*stEfarAllP.Ect(ind,:)+pznorm*stEfarAllP.Em0t(ind,:)).^2;
        Ef2Phi=pxnorm^2*sin(phi)^2* abs(stEfarAllP.Esf(ind,:)).^2;
        MdRadPhi(ll,:)=(8*pi)/3*(Er2Phi+Et2Phi+Ef2Phi);
        MdMax=max(MdMax,max(MdRadPhi(ll,:))); % find limits for axis scale
        % theta-dependent MdRad for phi
        % note that the symmetry around the z axis is lost in this case
        % For theta<0, the value must be obtained from |theta| and phi=phi+pi, i.e.
        Er2Phippi=abs(-pxnorm*cos(phi)*stEfarAllP.Ecr(ind,:)+pznorm*stEfarAllP.Em0r(ind,:)).^2;
        Et2Phippi=abs(-pxnorm*cos(phi)*stEfarAllP.Ect(ind,:)+pznorm*stEfarAllP.Em0t(ind,:)).^2;
        MdRadPhippi(ll,:)=(8*pi)/3*(Er2Phippi+Et2Phippi+Ef2Phi);
        MdMax=max(MdMax,max(MdRadPhippi(ll,:))); % find limits for axis scale
        % prepare legend for figure
        MRad=pxnorm^2*stEfarAllP.MRadPara(ind)+pznorm^2*stEfarAllP.MRadPerp(ind);
        if indphi==1
            sLegend{ll}=['\lambda=' num2str(lambda(ind)) 'nm'];
        else
            sLegend{ll}=['M_{Rad}=' num2str(MRad)];
        end
    end

    hpl=subplot(1,2,indphi);
    set(hpl,'Outerposition',[0.5*(indphi-1),0,0.5,1]);

    h = polar([0 2*pi], [0 MdMax]);
    delete(h);
    hold on;
    for ll=1:length(lambda0)
        % note that the symmetry around the z axis is lost in this case
        % For theta<0, the value must be obtained from |theta| and phi=pi, i.e.
        h=polar(thetaAll,[MdRadPhippi(ll,indNegTheta), MdRadPhi(ll,indPosTheta)],scol(1+mod(ll-1,4)));
    end
    if(phi==0) % plot dipole only if in xOz plane
        curxlim=get(gca,'XLim');
        plength2=plength*curxlim(2);
        quiver(-pznorm/2*plength2,-pxnorm/2*plength2, ...
            pznorm*plength2,pxnorm*plength2,'Color',[0.5;0;0.5],'LineWidth',1.5,'MaxHeadSize',0.8);
    end
    rectangle('Position',curxlim(2)*[-0.5,-0.1,0.2,0.2],'Curvature',[1,1],...
          'FaceColor',[0.8 0.8 0.8]);
    hold off;
    title(['M^d_{Rad}(\theta,\phi=' num2str(phi) ') px=' num2str(px) ', pz=' num2str(pz)]);
    %xlabel('Theta [degrees]'); ylabel('M^d_{Rad}');
    legend(sLegend,'Location','NorthEastOutside');
end
