function stMdip=DipSolveSingleSphere(nNmax,a,lambda,epsilonM,epsilonIn,d,nNmaxESA,sPlot,sCoeff)
% Solves the problem of dipole emission close to a single sphere with Mie theory
% The parameters are given as arguments or may also be given in a
% structure stMP when called as DipSolveSingleSphere(stMP,sPlot,sCoeff)
% where stMP contains the parameter fields.
% The dipole is assumed to be on the positive z-axis (theta=0)
% and aligned in the plane (xOz) (i.e. p_y=0), and at a
% distance d from the sphere surface (i.e. at r=a+d).
% Note that in this case, we have for the Mie coefficients:
% either |m|=1; a,c even in m; b,d odd in m.
% or |m|=0; a,c=0; only b and d.
% For example, the scattered field is entirely defined by
% c_{n,1}, d_{n,1}, and d_{n,0}
% (c_{n,-1}=c_{n,1}, d_{n,-1}=-d_{n,1}, c_{n,0}=0 and
% all other coefficients are zero).
%
% Results are obtained for a perpendicular and parallel dipole.
% Results for the case of a general dipole can then be easily derived from
% them.
%
% Parameters:
% - nNmax:     integer [1 x 1]
%              number of n in series
% - a:         integer [1 x 1]
%              radius of sphere (typically in NANOMETERS)
% - lambda:    possibly column vector [L x 1]
%              wavelengths (typically in NANOMETERS)
% - epsilonM:  scalar or column vector [L x 1]
%              epsilon of embedding medium (possibly
%              wavelength-dependent)
% - epsilonIn: scalar or column vector [L x 1]
%              epsilon of sphere material (possibly
%              wavelength-dependent)
% - d:         integer [1 x 1]
%              distance from sphere (typically in NANOMETERS)
% - nNmaxESA:  integer [1 x 1]
%              number of n in series for evaluation of MTot in
%              the ESA for n>nNmax
% - sPlot:     optional (default does nothing)
%              'plot' will produce a new figure with a plot
%              of MRad and MTot (Perp and Para cases)
% - sCoeff:    optional (default does nothing)
%              'coeff' will return the Mie coefficients for the internal field
%              (alphan1, betan1, betan0), for the scattered field (cn1, dn1, dn0),
%              and for the non-modified (incident) dipole radiated field
%              (en1, fn1, fn0); all as fields of the result structure
%              'suscep' will return the Mie susceptibilities Gamma, Delta,
%              A, and B as fields of the result structure
%              'both' will return both Mie coefficients and
%              susceptibilities 
%              'coeffSum' will return the coefficients in the sums used to
%              calculate MRad and MTot
%               
%
% Returns: structure stMdip with fields containing the parameters for
%          future reference and additional fields for the results
% - stMdip.nNmax: scalar
% - stMdip.nNmaxESA: scalar
% - stMdip.a: scalar
% - stMdip.lambda: [L x 1]
% - stMdip.epsilonM: scalar or [L x 1]
% - stMdip.epsilonIn: scalar or [L x 1]
% - stMdip.d: scalar
% - stMdip.x: [L x 1] x=kM*a
% - stMdip.s: [L x 1]
% - stMdip.xp: [L x 1] xp=kM*(a+d)
% - stMdip.MRadPerp: [L x 1] wavelength-dependent radiative decay rate EF
%                    for perpendicular dipole
% - stMdip.MTotPerp: [L x 1] wavelength-dependent total decay rate EF
%                    for perpendicular dipole
% - stMdip.MRadPara: [L x 1] wavelength-dependent radiative decay rate EF
%                    for parallel dipole
% - stMdip.MTotPara: [L x 1] wavelength-dependent total decay rate EF
%                    for parallel dipole
% - stMdip.MRadPerpCoeffs [L x nNmax] (if sCoeff='coeffSum'): coeffs of the sums over n
% - stMdip.MRadParaCoeffs [L x nNmax] (if sCoeff='coeffSum'): coeffs of the sums over n
% - stMdip.MTotPerpCoeffs [L x nNmaxESA] (if sCoeff='coeffSum'): coeffs of the sums over n
% - stMdip.MTotParaCoeffs [L x nNmaxESA] (if sCoeff='coeffSum'): coeffs of the sums over n
% - stMdip.alphan1 (if sCoeff='coeff' or 'both'): [L x nNmax]
% - stMdip.betan1 (if sCoeff='coeff' or 'both'): [L x nNmax]
% - stMdip.betan0 (if sCoeff='coeff' or 'both'): [L x nNmax]
% - stMdip.cn1 (if sCoeff='coeff' or 'both'): [L x nNmax]
% - stMdip.dn1 (if sCoeff='coeff' or 'both'): [L x nNmax]
% - stMdip.dn0 (if sCoeff='coeff' or 'both'): [L x nNmax]
% - stMdip.en1 (if sCoeff='coeff' or 'both'): [L x nNmax]
% - stMdip.fn1 (if sCoeff='coeff' or 'both'): [L x nNmax]
% - stMdip.fn0 (if sCoeff='coeff' or 'both'): [L x nNmax]
% - stMdip.Gamma (if sCoeff='suscep' or 'both'): [L x nNmax]
% - stMdip.Delta (if sCoeff='suscep' or 'both'): [L x nNmax]
% - stMdip.A (if sCoeff='suscep' or 'both'): [L x nNmax]
% - stMdip.B (if sCoeff='suscep' or 'both'): [L x nNmax]
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

global noCheckSum;
if (isempty(noCheckSum) || ~noCheckSum)
    disp 'DipSolveSingleSphere: Solving dipole Mie for single sphere - CheckSum ON'
else
    disp 'DipSolveSingleSphere: Solving dipole Mie for single sphere - CheckSum OFF'
end

% rearrange function parameters and define optional parameters
% number of parameters is 1,2, or 3 if called as stMP,sOption,sCoeff
% or 7,8, or 9 if nMax,a,lambda,epsilonM,epsilonIn,d,nNmaxESA,sOption,sCoeff
nNbParam=nargin;
if ((nNbParam==1) || (nNbParam==7))
    sPlot='No';
    sCoeff='No';
end
if ((nNbParam==2) || (nNbParam==8))
    sCoeff='No';
end
if (nNbParam<4)
    nNmax=stMP.nNmax;
    a=stMP.a;
    lambda=stMP.lambda;
    epsilonM=stMP.epsilonM;
    epsilonIn=stMP.epsilonIn;
    d=stMP.d;
    nNmaxESA=stMP.nNmaxESA;
end

% Calculate x=k_M a where k_M is wavevector outside the sphere
% see Eq. H.45
x=2*pi* sqrt(epsilonM) *a ./ lambda; % [L x 1]
% Calculate s=k_in/k_M where k_in  is wavevector inside sphere
% see Eq. H.45
% 0*lambda is used to ensure that s is [L x 1] even when both epsilon are
% scalar
s=sqrt(epsilonIn+0*lambda)./sqrt(epsilonM); % [L x 1]
% Calculate xp=k_M (a+d) for dipole position
xp=x/a*(a+d);

if nNmax>0
    
    % Calculate susceptibilities Gamma_n, Delta_n, A_n, and B_n
    % (defined in Eqs. H.12 and H.13)
    % for all n and all lambda
    % Gamma, Delta, A, and B are matrices [L x Nmax]
    stGDAB=GenSuscepGDAB(nNmax,s,x);

    % Calculate M coeffs for dipole emission
    % return coeffs in the sum if sCoeff='coeffSum'
    stMdip=DipMcoeff(xp,stGDAB,a,d,s,nNmaxESA,sCoeff);
else % nNmax=0 means ESA calculation only
    stGDAB=0;
    stMdip=DipMcoeff(xp,stGDAB,a,d,s,nNmaxESA,'ESAonly');
    sCoeff='No'; % deactive additional options (sCoeff is ignored if nNmax=0)
end
    
% return results
stMdip.nNmax=nNmax;
stMdip.nNmaxESA=nNmaxESA;
stMdip.a=a;
stMdip.lambda=lambda;
stMdip.epsilonM=epsilonM;
stMdip.epsilonIn=epsilonIn;
stMdip.d=d;
stMdip.x=x;
stMdip.s=s;
stMdip.xp=xp;


if (strcmpi(sCoeff,'suscep') || strcmpi(sCoeff,'both'))
    stMdip.Gamma=stGDAB.Gamma;
    stMdip.Delta=stGDAB.Delta;
    stMdip.A=stGDAB.A;
    stMdip.B=stGDAB.B;
end

if (strcmpi(sCoeff,'coeff') || strcmpi(sCoeff,'both'))
    % calculate incident field coefficient an1, bn1, and bn0
    stIncEabn1bn0=DipIncEabn1bn0(nNmax,xp);
    stMdip.cn1=stGDAB.Gamma .* stIncEabn1bn0.an1;
    stMdip.dn1=stGDAB.Delta .* stIncEabn1bn0.bn1;
    stMdip.dn0=stGDAB.Delta .* stIncEabn1bn0.bn0;
    stMdip.alphan1=stGDAB.A .* stIncEabn1bn0.an1;
    stMdip.betan1=stGDAB.B .* stIncEabn1bn0.bn1;
    stMdip.betan0=stGDAB.B .* stIncEabn1bn0.bn0;
    % coefficient of expansion of incident dipole field in far field
    stIncEefn1fn0=DipIncEefn1fn0(nNmax,xp);
    stMdip.en1=stIncEefn1fn0.en1;
    stMdip.fn1=stIncEefn1fn0.fn1;
    stMdip.fn0=stIncEefn1fn0.fn0;
end

% plot if required
if strcmpi(sPlot,'plot')
    disp 'Drawing plot...'
    DipPlotM(stMdip);
end

disp 'DipSolveSingleSphere: done.'
disp ' '