function stRBpsi2=GenRBpsi2(nNmax, rho)
% Calculates the Ricatti-Bessel function psi_n(rho)=j_n(rho)*rho and its derivative for n=1:nNmax
%
% Parameters:
% - nNmax: scalar integer
%          number of n in series 
% - rho:   column vector [R x 1] (with possibly zero components)
%          arguments of the Ricatti-Bessel function  
%
% Returns: structure with 2 fields
%          each a matrix [R x nNmax] 
%          with values for each rho and n=1..nNmax
% stRBpsi2.psi:  psi_n(rho)
% stRBpsi2.Dpsi: psi'_n(rho)} 
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

n=1:nNmax;
nm1=0:nNmax;
nu=nm1+0.5;

[numat, rhomat] = meshgrid(nu,rho);
f = besselj(numat,rhomat);
% f is matrix [R x nNmax+1] of cylindrical Bessel
% J_{n+0.5}(rho), n=0..nNmax 

% find and exclude indices where rho=0
ind0 = find(rho==0); % ind0 is possibly empty vector
% replace with 1 to avoid error messages
rho(ind0) = 1;

sq=sqrt((pi/2).*rho); % [R x 1]
f=bsxfun(@times,f,sq); % [R x nNmax+1]
% f is now matrix of spherical Ricati-Bessel
% psi_n(rho), n=0..nNmax or equivalently psi_{n-1}(rho), n=1..nNmax+1

stRBpsi2.psi=f(:,n+1);

% Computes: psi_n'=psi_{n-1} - n psi_n/rho
% and check for loss of precision in sum
% Note that (1./rho) * n is a matrix [R x nMax]
stRBpsi2.Dpsi=GenCheckSum2Mat(f(:,n), - ( (1./rho)*n ).*f(:,n+1),'Dpsi','GenRBpsi2');

% Replace proper value for cases where rho=0, i.e. psi_n'(0)=0
if (~isempty(ind0))
    stRBpsi2.Dpsi(ind0,:)=zeros(length(ind0),nNmax);
end

