function stMdip=MulDipSolveMultiSphere(nNmax,Ca,lambda,Cepsilon,d,nNmaxESA,sPlot,sCoeff)
% Solves the problem of dipole emission close to a multilayer spherical system with Mie theory
% Note that only dipoles outside the largest spheres (at a distance d) are
% considered.
% The parameters are given as arguments or may also be given in a
% structure stMP when called as MulDipSolveMultiSphere(stMP,sPlot,sCoeff)
% where stMP contains the parameter fields.
% The dipole is assumed to be on the positive z-axis (theta=0)
% and aligned in the plane (xOz) (i.e. p_y=0), and at a
% distance d from the sphere surface (i.e. at r=a+d).
% Note that in this case, we have for the Mie coefficients:
% either |m|=1; a,c even in m; b,d odd in m.
% or |m|=0; a,c=0; only b and d.
% For example, the scattered field is entirely defined by
% c_{n,1}, d_{n,1}, and d_{n,0}
% (c_{n,-1}=c_{n,1}, d_{n,-1}=-d_{n,1}, c_{n,0}=0 and
% all other coefficients are zero).
%
% Results are obtained for a perpendicular and parallel dipole.
% Results for the case of a general dipole can then be easily derived from
% them.
%
% Parameters:
% - nNmax:     integer [1 x 1]
%              number of n in series
% - Ca:        cell of integer {K x [1 x 1]}
%              K is number of interfaces (K=1 for single sphere)
%              radii of spherical interfaces (typically in NANOMETERS)
%              Ca{K} is outer interface (largest sphere)
% - lambda:    possibly column vector [L x 1]
%              wavelengths (typically in NANOMETERS)
% - Cepsilon:  cell of scalars or column vectors {K+1 x [L x 1]}
%              epsilon of media (possibly
%              wavelength-dependent) for k=0 (inside sphere)
%              to k=K (embedding medium).
% - d:         integer [1 x 1]
%              distance from sphere (typically in NANOMETERS)
% - nNmaxESA:  integer [1 x 1]
%              number of n in series for evaluation of MTot in
%              the ESA for n>nNmax
% - sPlot:     optional (default does nothing)
%              'plot' will produce a new figure with a plot
%              of MRad and MTot (Perp and Para cases)
% - sCoeff:    optional (default does nothing)
%              'coeff' will return the Mie coefficients for the regular
%              field expansions(alphakn1, betakn1, betakn0), and for the
%              irregular field expansions (gammakn1, deltakn1, deltakn0),
%              and for the non-modified (incident) dipole radiated field
%              (en1, fn1, fn0)
%              'suscep' will return the Mie susceptibilities Gamma^k, Delta^k,
%              A^, and B^k
%              'both' will return both Mie coefficients and
%              susceptibilities 
%
% Returns: structure stMdip with fields containing the parameters for
%          future reference and additional fields for the results
% - stMdip.nNmax: scalar
% - stMdip.nNmaxESA: scalar
% - stMdip.a: scalar
% - stMdip.lambda: [L x 1]
% - stMdip.epsilonM: scalar or [L x 1]
% - stMdip.d: scalar
% - stMdip.x: [L x 1] x=kM*a
% - stMdip.xp: [L x 1] xp=kM*(a+d)
% - stMieRes.nK: scalar, number of interfaces
% - stMieRes.Ca: cell of {K scalars}
% - stMieRes.CepsilonM: cell of {K+1 x (scalar or [L x 1])}
% - stMieRes.Cx: cell of {K x [L x 1]}
% - stMieRes.Cs: cell of {K x [L x 1]}
% - stMdip.MRadPerp: [L x 1] wavelength-dependent radiative decay rate EF
%                    for perpendicular dipole
% - stMdip.MTotPerp: [L x 1] wavelength-dependent total decay rate EF
%                    for perpendicular dipole
% - stMdip.MRadPara: [L x 1] wavelength-dependent radiative decay rate EF
%                    for parallel dipole
% - stMdip.MTotPara: [L x 1] wavelength-dependent total decay rate EF
%                    for parallel dipole
% - stMdip.MRadPerpCoeffs [L x nNmax] (if sCoeff='coeffSum'): coeffs of the sums over n
% - stMdip.MRadParaCoeffs [L x nNmax] (if sCoeff='coeffSum'): coeffs of the sums over n
% - stMdip.MTotPerpCoeffs [L x nNmaxESA] (if sCoeff='coeffSum'): coeffs of the sums over n
% - stMdip.MTotParaCoeffs [L x nNmaxESA] (if sCoeff='coeffSum'): coeffs of the sums over n
% - stMdip.cn1 (if sCoeff='coeff' or 'both'): [L x nNmax]
% - stMdip.dn1 (if sCoeff='coeff' or 'both'): [L x nNmax]
% - stMdip.dn0 (if sCoeff='coeff' or 'both'): [L x nNmax]
% - stMdip.en1 (if sCoeff='coeff' or 'both'): [L x nNmax]
% - stMdip.fn1 (if sCoeff='coeff' or 'both'): [L x nNmax]
% - stMdip.fn0 (if sCoeff='coeff' or 'both'): [L x nNmax]
% - stMdip.Gamma (if sCoeff='suscep' or 'both'): [L x nNmax]
% - stMdip.Delta (if sCoeff='suscep' or 'both'): [L x nNmax]
% - stMdip.CstMulGDAB (if sCoeff='suscep' or 'both'): [L x nNmax]
% - stMdip.Cgammakn1 (if sCoeff='coeff' or 'both'): cell {K+1 x [L x nNmax]}
% - stMdip.Cdeltakn1 (if sCoeff='coeff' or 'both'): cell {K+1 x [L x nNmax]}
% - stMdip.Calphakn1 (if sCoeff='coeff' or 'both'): cell {K+1 x [L x nNmax]}
% - stMdip.Cbetakn1 (if sCoeff='coeff' or 'both'): cell {K+1 x [L x nNmax]}
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

disp ' ';
global noCheckSum;
if (isempty(noCheckSum) || ~noCheckSum)
    disp 'MulDipSolveMultiSphere: Solving dipole Mie for sphere multilayer- CheckSum ON'
else
    disp 'MulDipSolveMultiSphere: Solving dipole Mie for sphere multilayer - CheckSum OFF'
end

% rearrange function parameters and define optional parameters
% number of parameters is 1,2, or 3 if called as stMP,sOption,sCoeff
% or 6,7, or 8 if nMax,Ca,lambda,Cepsilon,d,nNmaxESA,sOption,sCoeff
nNbParam=nargin;
if ((nNbParam==1) || (nNbParam==6))
    sPlot='No';
    sCoeff='No';
end
if ((nNbParam==2) || (nNbParam==7))
    sCoeff='No';
end
if (nNbParam<4)
    nNmax=stMP.nNmax;
    Ca=stMP.Ca;
    lambda=stMP.lambda;
    Cepsilon=stMP.Cepsilon;
    d=stMP.d;
    nNmaxESA=stMP.nNmaxESA;
end

nK=length(Ca); % number of spherical interfaces K

% Get s_k and x_k for k=1..nK
[Cs,Cx]=MulGetCsCx(lambda,Ca,Cepsilon);

% Calculate xp=k_M (a+d) for dipole position
xp=Cx{nK}/Ca{nK}*(Ca{nK}+d);

if nNmax>0
    % Calculate susceptibilities Gamma^k_n, Delta^k_n, A^k_n, and B^k_n
    % (defined in Eqs. H.108 and H.117)
    % for all n,k and all lambda
    CstMulGDAB=MulSuscepGDAB(nNmax,Cs,Cx);
    % CstMulGDAB is a cell of K structures, each with the corresponding
    % susceptibilities
    % Gamma^k_n, Delta^k_n, A^k_n, and B^_n as matrices [L x Nmax]

    % Calculate M coeffs for dipole emission
    % return coeffs in the sum if sCoeff='coeffSum'
    stMdip=DipMcoeff(xp,CstMulGDAB{nK},Ca{nK},d,Cs{nK},nNmaxESA,sCoeff);
else % nNmax=0 means ESA calculation only
    stMdip=DipMcoeff(xp,[],Ca{nK},d,Cs{nK},nNmaxESA,'ESAonly');
    sCoeff='No'; % deactive additional options (sCoeff is ignored if nNmax=0)
end
    
% return results
stMdip.nNmax=nNmax;
stMdip.nNmaxESA=nNmaxESA;
stMdip.a=Ca{nK};
stMdip.lambda=lambda;
stMdip.epsilonM=Cepsilon{nK+1};
stMdip.d=d;
stMdip.x=Cx{nK};
stMdip.xp=xp;

stMdip.nK=nK;
stMdip.Ca=Ca;
stMdip.Cepsilon=Cepsilon;
stMdip.Cx=Cx;
stMdip.Cs=Cs;

if (strcmpi(sCoeff,'suscep') || strcmpi(sCoeff,'both'))
    stMdip.Gamma=CstMulGDAB{nK}.Gamma; % for compatibility with single spheres
    stMdip.Delta=CstMulGDAB{nK}.Delta; % for compatibility with single spheres
    stMdip.CstMulGDAB=CstMulGDAB; 
end

if (strcmpi(sCoeff,'coeff') || strcmpi(sCoeff,'both'))
    % calculate incident field coefficient an1, bn1, and bn0
    stIncEabn1bn0=DipIncEabn1bn0(nNmax,xp);
    % results are [L x nNmax]
    
    % calculate Mie coefficients using a downward recurrence (pp. 623,624)
    % each cell of coeff corresponds to a given kk=0..nK
    stMdip.Cgammakn1=cell(1,nK+1);
    stMdip.Cdeltakn1=cell(1,nK+1);
    stMdip.Cdeltakn0=cell(1,nK+1);
    stMdip.Calphakn1=cell(1,nK+1);
    stMdip.Cbetakn1=cell(1,nK+1);
    stMdip.Cbetakn0=cell(1,nK+1);
    stMdip.Cgammakn1{1}=0; % no scattered field inside the smallest sphere
    stMdip.Cdeltakn1{1}=0;
    stMdip.Cdeltakn0{1}=0;
    % Initialize recurrence
    stMdip.Calphakn1{nK+1}=stIncEabn1bn0.an1;
    stMdip.Cbetakn1{nK+1}=stIncEabn1bn0.bn1;
    stMdip.Cbetakn0{nK+1}=stIncEabn1bn0.bn0;
    for kk=nK:-1:1
        % Eq. H.108 gamma^k=Gamma^k * alpha^k
        stMdip.Cgammakn1{kk+1}=CstMulGDAB{kk}.Gamma .* stMdip.Calphakn1{kk+1};
        stMdip.Cdeltakn1{kk+1}=CstMulGDAB{kk}.Delta .* stMdip.Cbetakn1{kk+1};
        stMdip.Cdeltakn0{kk+1}=CstMulGDAB{kk}.Delta .* stMdip.Cbetakn0{kk+1};
        % Eq. H.117 alpha^{k-1}=A^k alpha^k
        stMdip.Calphakn1{kk}=CstMulGDAB{kk}.A .* stMdip.Calphakn1{kk+1};
        stMdip.Cbetakn1{kk}=CstMulGDAB{kk}.B .* stMdip.Cbetakn1{kk+1};
        stMdip.Cbetakn0{kk}=CstMulGDAB{kk}.B .* stMdip.Cbetakn0{kk+1};
    end
    stMdip.cn1=stMdip.Cgammakn1{nK+1}; % for compatibility with single spheres
    stMdip.dn1=stMdip.Cdeltakn1{nK+1}; % for compatibility with single spheres
    stMdip.dn0=stMdip.Cdeltakn0{nK+1}; % for compatibility with single spheres

    % coefficient of expansion of incident dipole field in far field
    stIncEefn1fn0=DipIncEefn1fn0(nNmax,xp);
    stMdip.en1=stIncEefn1fn0.en1; % [L x nNmax]
    stMdip.fn1=stIncEefn1fn0.fn1; % [L x nNmax]
    stMdip.fn0=stIncEefn1fn0.fn0; % [L x nNmax]
end

% plot if required
if strcmpi(sPlot,'plot')
    disp 'Drawing plot...'
    DipPlotM(stMdip);
end

disp 'MulDipSolveMultiSphere: done.'
disp ' '