function CstMulSuscep=MulSuscepGDAB(nNmax,Cs,Cx)
% calculates the Mie susceptibilities for a multilayer sphere problem
% i.e. Gamma^k_n, Delta^k_n, A^k_n, and B^k_n for n=1:nNmax and k=1..nK.
% See Section H.5.2 for more details.
%
% Parameters:
% - nNmax:  integer scalar
% - Cs:     cell K column vectors [L x 1]
%           wavelength-dependent relative refractive index for each
%           interface s_k = k_{k-1}/k_k (see p. 623)
% - x:      cell of K column vectors [L x 1]
%           wavelength-dependent x_k=k_k*a_k (see p. 623)
%
% Returns: a cell of K structures, each with 4 fields 
%          with susceptibilities
%          defined in Eqs. H.108 and H.117
% CstMulSuscep{k}.Gamma: Gamma^k_n [L x nNmax]
% CstMulSuscep{k}.Delta: Delta^k_n [L x nNmax]
% CstMulSuscep{k}.A: A^k_n [L x nNmax]
% CstMulSuscep{k}.B: B^k_n [L x nNmax]
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

% Extract number of interfaces nK
nK=length(Cx);
nNbLambda=length(Cx{1});

disp(['Calculating susceptibilities for ' int2str(nK) ' spherical layers'])

% Calculate the necessary Riccati-Bessel functions
CstRBz=cell(1,nK);
CstRBx=cell(1,nK);
for kk=1:nK
    zk=Cs{kk}.*Cx{kk}; % [L x 1]
    xk=Cx{kk};  % [L x 1]

    % get psi_n(sk*xk), xi_n(sk*xk) and derivatives
    CstRBz{kk}=GenRBall(nNmax,zk);

    % get psi_n(xk), xi_n(xk) and derivatives
    CstRBx{kk}=GenRBall(nNmax,xk);
end

CstMulSuscep=cell(1,nK);
% upward recurrence (see page 623) for Gamma and Delta
% A and B can be calculated at the same time
for kk=1:nK
    if kk==1 % implement initial condition inside loop for convenience
        Gamkm1=zeros(nNbLambda,nNmax); % [L x N]
        Delkm1=Gamkm1; % [L x N]
    else
        % Get Gamma^{k-1} and Delta^{k-1}
        Gamkm1=CstMulSuscep{kk-1}.Gamma; % [L x N]
        Delkm1=CstMulSuscep{kk-1}.Delta; % [L x N]
    end
    
    smat=repmat(Cs{kk},1,nNmax);

    % auxialiary functions for Gamma and A
    PP1 = GenCheckSum2Mat(CstRBz{kk}.psi, Gamkm1.*CstRBz{kk}.xi,'PP1_1','MulSuscepGDAB');
    PP2 = GenCheckSum2Mat(CstRBz{kk}.Dpsi, Gamkm1.*CstRBz{kk}.Dxi,'PP2_1','MulSuscepGDAB');
    % Eq. H.112 
    Dnk=GenCheckSum2Mat(smat .* CstRBx{kk}.xi .* PP2, - PP1 .* CstRBx{kk}.Dxi,'Dnk_1','MulSuscepGDAB');
    % Eqs. H.110 and H.111 for Gamma
    CstMulSuscep{kk}.Gamma= GenCheckSum2Mat(PP1 .* CstRBx{kk}.Dpsi, ...
        - smat .* CstRBx{kk}.psi .* PP2, ...
        'Gamma','MulSuscepGDAB') ./ Dnk;
    % Eqs. H.118, H.119, H.120 for A
    CstMulSuscep{kk}.A= -i*smat./ Dnk;
    
    % Same method for Delta and B
    PP1 = GenCheckSum2Mat(CstRBz{kk}.psi, Delkm1.*CstRBz{kk}.xi,'PP1_2','MulSuscepGDAB');
    PP2 = GenCheckSum2Mat(CstRBz{kk}.Dpsi, Delkm1.*CstRBz{kk}.Dxi,'PP2_2','MulSuscepGDAB');
    % Eq. H.115
    Dnk=GenCheckSum2Mat(smat .* CstRBx{kk}.Dxi .* PP1, - PP2 .* CstRBx{kk}.xi,'Dnk_2','MulSuscepGDAB');
    % Eqs. H.113 and H.114
    CstMulSuscep{kk}.Delta= GenCheckSum2Mat(PP2 .* CstRBx{kk}.psi, ...
        - smat .* CstRBx{kk}.Dpsi .* PP1, ...
        'Delta','MulSuscepGDAB') ./ Dnk;
    % Eqs. H.121, H.122, H.123 for B
    CstMulSuscep{kk}.B= i*smat./ Dnk;

end
