function stE=PweEFaverages(stE)
% Calculates surface-averaged EFs for PWE
% The E field is specified as 3 [L x T] or [R x T] matrices
% in the sturcture stE containing Ecr, Ect, and Esf
% Ecr, Ect, Esf are discussed in the supplementary information.
% This is a low-level function called by PweEsurf and PweEmap.
%
% Parameters:
% - stE: structure with fields (LR is L or R)
%   stE.Ecr: [LR x T] 
%   stE.Ect: [LR x T] 
%   stE.Esf: [LR x T] 
%   stE.theta: [1 x T] row vector with theta's (equally-spaced
%              between 0 and pi)
%
% Returns: same structure stE with the additional fields:
% - stE.MLocParaAve: [LR x 1] wavelength- or r-dependent average MLocPara
% - stE.MLocPerpAve: [LR x 1] wavelength- or r-dependent average MLocPerp
% - stE.MLocAve: [LR x 1] wavelength- or r-dependent average MLoc
% - stE.F0E4Ave: [LR x 1] wavelength- or r-dependent average SERS EF F^0_{E4}
% - stE.F0E4PerpAve: [LR x 1] wavelength- or r-dependent average SERS EF
%                        F^0_{E4} for perpendicular component
% - stE.F0E4ParaAve: [LR x 1] wavelength- or r-dependent average SERS EF
%                        F^0_{E4} for parallel component
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

theta=stE.theta; % [1 x T]
nNbTheta=length(theta); % T

Ecr2theta=abs(stE.Ecr).^2;
Ect2theta=abs(stE.Ect).^2;
Esf2theta=abs(stE.Esf).^2;

if nNbTheta==1
    disp 'PweEFaverages: only one theta, all averages will be set to zero.'
    dtheta=0;
else
    dtheta=pi/(nNbTheta-1);
end
sintcolnorm=(dtheta/2)*transpose(sin(theta)); % [T x 1]

% computes surface-averages (integrating
% <f>=0.5*int(f(t)*sin(t)dt using a simple sums in the rectangle approximation)
% Sums are computed as matrix [LR x T]* vector [T x 1] multiplication
% All results are [LR x 1]

% average LFIEF
stE.MLocPerpAve=1/2* Ecr2theta * sintcolnorm;
stE.MLocParaAve=1/2* (Ect2theta +Esf2theta) * sintcolnorm;
stE.MLocAve=stE.MLocPerpAve+stE.MLocParaAve;

% average SERS EF (E4 approximation)
stE.F0E4Ave= ...
     (3/8* ( ((Ecr2theta+Ect2theta).^2+Esf2theta.^2) * sintcolnorm) + ...
     1/4* ( ((Ecr2theta+Ect2theta).*Esf2theta) * sintcolnorm) );
% average SERS EF (E4 approximation - perpendicular component only)
stE.F0E4PerpAve= 3/8* (Ecr2theta.^2) * sintcolnorm;
% average SERS EF (E4 approximation - parallel component only)
stE.F0E4ParaAve= 1/8* ( (3*(Ect2theta.^2+Esf2theta.^2) + 2*Ect2theta.*Esf2theta) * sintcolnorm );
 