function stEAllPhi=PweEgenRThetaAllPhi(lambda0,epsilon0,cn1,dn1,r,theta,sBessel,stPinTaun)
% Low-level function to calculate VSH expansions for PWE for a fixed lambda, but many r and theta
% The VSHs used can either be of type 1 (sBessel='j') or type 3
% (sBessel='h1')
% For PWE, we have: |m|=1, c_{n,1}=c_{n,-1}, d_{n,1}=-d_{n,-1}).
% The fields Ecr, Ect, Esf given in the results are discussed in the
% supplementary information.
% lambda0 and epsilon0 MUST BE A SCALAR here (one wavelength only)
%
% Parameters:
% - lambda0: scalar [1 x 1]
%           wavelengths in nm
% - epsilon0: scalar [1 x 1]
%           epsilon(lambda0) of dielectric where field is evaluated
% - cn1, dn1: 2 row vectors [1 x nNmax]
%             containing the Mie coefficients c_{n,1} and d_{n,1} for the 
%             field expansion of M^(i)_{n,1} and N^(i)_{n,1}, respectively
% - r:      column [R x 1], possibly with zero-component (if sBessel='j')
%           spherical coordinate r (in nm) of points
% - theta:  possibly row vector [1 x T]
%           with spherical coordinate theta of points
% - sBessel: string defining the Bessel function to be used
%           sBessel='j' for or sBessel='h1'
% - stPinTaun: structure (optional)
%              with functions of theta pi_n and tau_n
%              if omitted, then the functions are computed from scrath
%              it is faster to pass this structure as argument if these
%              functions have already been calculated
%
% Returns:  stEAllPhi, structure with 3 fields
%           containing matrices [R x T]
%           representing the three components E_{cr}, E_{ct}, E_{sf} such as: of
%           E = E_{cr} cos(phi) e_r + E_{ct} cos(phi) e_theta + E_{sf} sin(phi) e_phi
% - stEAllPhi.Ecr is E_{cr}
% - stEAllPhi.Ect is E_{ct}
% - stEAllPhi.Esf is E_{sf}
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

nNmax=size(cn1,2);
% check that only one lambda
if ~((size(lambda0,1)==1) && (size(epsilon0,1)==1) && (size(cn1,1)==1) && (size(dn1,1)==1))
    disp 'Error in PweEgenRThetaAllPhi: only one wavelength allowed, lambda0 and epsilon0 should be scalar.')
end;

nNbR=length(r);
nNbTheta=length(theta);

% get Zn(rho) for radial dependence
rho=2*pi*sqrt(epsilon0)/lambda0 * r; % column [R x 1]
% exclude rho=0 (treat separately) and replace by rho=1 
indRho0=find(rho==0);
rho(indRho0)=1;
stZnAll=GenZnAll(nNmax,rho,sBessel); % fields are [R x nNmax]

% get theta dependence if not provided
if nargin < 8
    stPinTaun=PwePinTaun(nNmax,transpose(theta)); % fields are [T x nNmax]
end

n=1:nNmax; %[1 x nNmax]
% need n-dep coeff for series (mu_n *n *(n+1) and mu_n)
% can be multiplied already by c_{n,1} and d_{n,1} to improve speed
cffnr=sqrt((2*n+1)/(4*pi)); %[1 x nNmax] 
mun=cffnr./(n.*(n+1));
cn1mun=cn1.*mun; % cn1*mu_n [1 x nNmax] for Et and Ef
dn1cffnr=dn1.*cffnr; %[1 x nNmax] for Er
dn1mun=dn1.*mun; % cn1*mu_n [1 x nNmax] for Et and Ef
clear cffnr mun;

% loop over rho's to avoid using 3-dimensional matrices:
% At a fixed rho, the sum over n for all theta can be carried out
% using a matrix product of the theta-and-n-dependent [T x nNmax] matrix
% by a n-dependent column vector [nNmax x 1]
% the result, a [T x 1] matrix is then transposed to a [1 x T] line
Ersum=zeros(nNbR,nNbTheta);
Etsum=zeros(nNbR,nNbTheta);
Efsum=zeros(nNbR,nNbTheta);
for ll=1:nNbR
    if isempty(find(indRho0==ll,1)) % will treat case rho(ll)==0 separately
        % for Er, vecN=d_{n,1} * Z_n^1(rho) * mu_n * n *(n+1)
        vecNdep=transpose(stZnAll.Z1(ll,:).*dn1cffnr); % [nNmax x 1]
        % Ersum=sum_n(pi_n(t) * vecN_n)
        % Do the sum as a matrix product (and check for loss of precision)
        Ersum(ll,:)=transpose(GenCheckSumMatVec(stPinTaun.pin, vecNdep, ...
            'Ersum','PweEgenRThetaAllPhi')); % [1 x T]

        % for Et and Ef
        vecNdep=transpose(i*stZnAll.Z0(ll,:).*cn1mun); % [nNmax x 1]
        vecNdep2=transpose(stZnAll.Z2(ll,:).*dn1mun); % [nNmax x 1]
        % Do the sums and check for loss of precision
        tmp1=GenCheckSumMatVec(stPinTaun.pin, vecNdep, ...
            'tmp1_1','PweEgenRThetaAllPhi');
        tmp2=GenCheckSumMatVec(stPinTaun.taun, vecNdep2, ...
            'tmp2_1','PweEgenRThetaAllPhi');
        Etsum(ll,:)=transpose(GenCheckSum2Mat(tmp1,tmp2, ...
            'Etsum','PweEgenRThetaAllPhi')); % [1 x T]

        tmp1=GenCheckSumMatVec(stPinTaun.taun, vecNdep, ...
            'tmp1_2','PweEgenRThetaAllPhi');
        tmp2=GenCheckSumMatVec(stPinTaun.pin, vecNdep2, ...
            'tmp2_2','PweEgenRThetaAllPhi');
        Efsum(ll,:)=transpose(GenCheckSum2Mat(tmp1,tmp2, ...
            'Efsum','PweEgenRThetaAllPhi')); % [1 x T]
    else
        % special case where rho=0
        % the following is equivalent to \mathbf{E}=-4/3 * mu_1 *dn1 \mathbf{e}_x
        Ersum(ll,:)=repmat(2/3*dn1mun(1),1,nNbTheta);
        Etsum(ll,:)=2/3*dn1mun(1)* cos(theta);
        Efsum(ll,:)=Ersum(ll,:);
        disp 'r=0'
    end
end   

% Results are all [R x T] matrices
stEAllPhi.Ecr=-2*repmat(sin(theta),nNbR,1).*Ersum;
stEAllPhi.Ect=-2*Etsum;
stEAllPhi.Esf=2*Efsum;


