function stEAllPhi=PweEincThetaAllPhi(lambda,epsilonM,r0,theta)
% Calculates the incident electric field E from its PWE expression for a fixed r0 but many theta and lambda
% The PWE expression is simply \mathbf{E}=exp(i kM z) \mathbf{e}_x
% The fields Ecr, Ect, Esf given in the results are discussed in the
% supplementary information.
%
% Parameters:
% - lambda: column vector [L x 1]
%           wavelengths in nm
% - epsilonM: scalar or column vector [L x 1]
%           epsilon of dielectric of outside region
% - r0:     scalar [1 x 1] 
%           spherical coordinate r0 (in nm) of points
% - theta:  possibly row vector [1 x T]
%           with spherical coordinate theta of points
%
% Returns:  stEAllPhi, structure with 3 fields
%           containing matrices [L x T]
%           representing the three components E_{cr}, E_{ct}, E_{sf} such as: of
%           E = E_{cr} cos(phi) e_r + E_{ct} cos(phi) e_theta + E_{sf} sin(phi) e_phi
% - stEAllPhi.Ecr is E_{cr}
% - stEAllPhi.Ect is E_{ct}
% - stEAllPhi.Esf is E_{sf}
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

nNbLambda=length(lambda);

% exp(ikM z) is [L x T], obtained by matrix product of [L x 1] by [1 x T]
phasefact=exp(i*2*pi* (sqrt(epsilonM)./lambda) * (r0*cos(theta) ) );

% Results are all [L x T] matrices
% They result from Eq. H.16 for e_x and H.76 for E_inc
stEAllPhi.Ecr= phasefact .* repmat(sin(theta),nNbLambda,1);
stEAllPhi.Ect= phasefact .* repmat(cos(theta),nNbLambda,1);
stEAllPhi.Esf= - phasefact;

