function stEmap=PweEmap(lambda0,epsilon,stAbcdn1,r,nNbTheta,sRegion,stPinTaun)
% Calculates several properties as a function of r and theta for PWE at a single wavelength
% For PWE, we have: |m|=1; a,c even in m; b,d odd in m.
% The 4 Mie coefficients in stAabcdn1 must be the relevant ones
% in the region considered.
% ONLY ONE WAVELENGTH for this function. lambda0 must be scalar.
% The fields Ecr, Ect, Esf given in the results are discussed in the
% supplementary information. 
%
% Parameters:
% - lambda0: SCALAR [1 x 1]
%           wavelength in nm
% - epsilon: SCALAR  [1 x 1]
%           epsilon of dielectric where field is evaluated
% - stAbcdn1: structure with 4 fields, an1, bn1, cn1, dn1,
%             each a matrix [1 x nNmax]
%             containing the Mie coefficients a_{n1,}, b_{n,1}, c_{n,1} and d_{n,1} for the 
%             FOR THE RELEVANT WAVELENGTH ONLY
% - r:      column vector [R x 1] with possibly zero-component
%           distance from origin (in nm)
% - nNbTheta: integer scalar
%             number of theta points used for computations
% - sRegion: string
%            'outside', 'inside', 'scattering, or otherwise, 'all' is
%            assumed:
%            * if 'outside': the points should be in the outside region (outside the largest
%              sphere). The regular part of the field (coeffs a and b) is then known and not
%              computed from the plane wave incident field (faster).
%            * if 'scattering': the regular part of the field (coeffs a and
%              b) is set to zero (no a and b needed)
%            * if 'inside': the points should be in the inside region (containing the origin), then
%              the irregular part of the field is zero (no coeffs c and d needed).
%            * otherwise: all of a,b,c,d are used.
% - stPinTaun: structure (optional)
%              with functions of theta pi_n and tau_n
%              if omitted, then the functions are computed from scrath
%              it is faster to pass this structure as argument if these
%              functions have already been calculated 
%
% Returns: structure stEmap with fields
% - stEmap.theta: [1 x T] row vector with theta's
% - stEmap.r: [R x 1] column vector with r's
% - stEmap.lambda0: [1 x 1] scalar
% - stEmap.Ecr: [R x T] r-and-theta-dependent Ecr
% - stEmap.Ect: [R x T] r-and-theta-dependent Ect
% - stEmap.Esf: [R x T] r-and-theta-dependent Esf
% - stEmap.MLocParaAve: [R x 1] r-dependent average MLocPara
% - stEmap.MLocPerpAve: [R x 1] r-dependent average MLocPerp
% - stEmap.MLocAve: [R x 1] r-dependent average MLoc
% - stEmap.F0E4Ave: [R x 1] r-dependent average SERS EF F^0_{E4}
% - stEmap.F0E4PerpAve: [R x 1] r-dependent average SERS EF
%                        F^0_{E4} for perpendicular component
% - stEmap.F0E4ParaAve: [R x 1] r-dependent average SERS EF
%                        F^0_{E4} for parallel component
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

global noCheckSum;
if (isempty(noCheckSum) || ~noCheckSum)
    disp 'PweEmap: CheckSum ON'
else
    disp 'PweEmap: CheckSum OFF'
end

if isfield(stAbcdn1,'an1')
    nNmax=size(stAbcdn1.an1,2);
    if ~(size(stAbcdn1.an1,1)==1)
        disp 'Error in PweEmap: only one wavelength allowed, an1 should be ROW vector.')
    end;
else
    if isfield(stAbcdn1,'cn1')
        nNmax=size(stAbcdn1.cn1,2);
        if ~(size(stAbcdn1.cn1,1)==1)
            disp 'Error in PweEmap: only one wavelength allowed, cn1 should be ROW vector.')
        end;
    else
    disp 'Error in PweEmap: cannot recognize stAbcdn1 structure fields')
    end
end

% check that only one lambda
if ~(size(lambda0,1)==1)
    disp 'Error in PweEmap: only one wavelength allowed, lambda0 should be scalar.')
end;

if (nNbTheta<91)
    disp 'Warning in PweEmap: nNbTheta must be large for averages to be meaningful'
end

theta=linspace(0,pi,nNbTheta); % row [1 x T]

% get theta dependence if not provided
if nargin < 7
    stPinTaun=PwePinTaun(nNmax,transpose(theta)); % fields are [T x nNmax]
end

% calculate regular VSH expansion (coeffs a,b)
if strcmpi(sRegion,'outside')
    % get regular field from known plane wave expression of incident field
    disp 'PweEmap: Outside region: get regular field from PW expression'
    stEAllPhiReg=PweEincRThetaAllPhi(lambda0,epsilon,r,theta);
else
    if strcmpi(sRegion,'scattering')
        disp 'PweEmap: scattering only: regular VSH expansion is zero...'
        stEAllPhiReg.Ecr=0;
        stEAllPhiReg.Ect=0;
        stEAllPhiReg.Esf=0;
    else
        disp 'PweEmap: Computing regular VSH expansions (coeffs a,b)...'
        stEAllPhiReg=PweEgenRThetaAllPhi(lambda0,epsilon,stAbcdn1.an1,stAbcdn1.bn1,r,theta,'j',stPinTaun);
    end
end
if strcmpi(sRegion,'inside')
    disp 'PweEmap: Inside: Irregular VSH expansions is zero...'
    stEAllPhiIrr.Ecr=0;
    stEAllPhiIrr.Ect=0;
    stEAllPhiIrr.Esf=0;
else
    % calculate irregular VSH expansion (coeffs c,d)
    disp 'PweEmap: Computing irregular VSH expansions (coeffs c,d)...'
    stEAllPhiIrr=PweEgenRThetaAllPhi(lambda0,epsilon,stAbcdn1.cn1,stAbcdn1.dn1,r,theta,'h1',stPinTaun);
end

disp 'PweEmap: Compiling results and averages...'
% Ecr, Ect, and Esf are [R x T]
stEmap.Ecr=GenCheckSum2Mat(stEAllPhiReg.Ecr,stEAllPhiIrr.Ecr,'Ecr','PweEmap');
stEmap.Ect=GenCheckSum2Mat(stEAllPhiReg.Ect,stEAllPhiIrr.Ect,'Ect','PweEmap');
stEmap.Esf=GenCheckSum2Mat(stEAllPhiReg.Esf,stEAllPhiIrr.Esf,'Esf','PweEmap');

clear stEAllPhiReg stEAllPhiIrr;

stEmap.theta=theta;
stEmap.r=r;
stEmap.lambda0=lambda0;

% computes surface-averages
stEmap=PweEFaverages(stEmap);

disp 'PweEmap: done...'
disp ' '


