function stEptArray=PweEpts(lambda,epsilon,stAbcdn1,stPtArray,sRegion)
% Calculates the electric field at given points for PWE
% For PWE, we have: |m|=1; a,c even in m; b,d odd in m.
% The 4 Mie coefficients in stAabcdn1 must be the relevant ones
% at all the point positions.
% This function is to be used for a few points only.
% To compute the fields at many points on the surface or in a volume,
% use PweEsurf or PweEmap instead.
%
% Parameters:
% - lambda: column vector [L x 1]
%           wavelengths in nm
% - epsilon: scalar or column vector [L x 1]
%           epsilon of dielectric where field is evaluated
% - stAbcdn1: structure with 4 fields, an1, bn1, cn1, dn1,
%             each a matrix [L x nNmax]
%             containing the Mie coefficients a_{n,1}, b_{n,1},
%             c_{n,1} and d_{n,1} relevant at the points positions 
% - stPtArray: array of stPt structures, each with fields
%               (r, theta, phi) or (x,y,z)
% - sRegion: string
%            'outside', 'inside', 'scattering, or otherwise, 'all' is
%            assumed:
%            * if 'outside': the points should be in the outside region (outside the largest
%              sphere). The regular part of the field (coeffs a and b) is then known and not
%              computed from the plane wave incident field (faster).
%            * if 'scattering': the regular part of the field (coeffs a and
%              b) is set to zero (no a and b needed)
%            * if 'inside': the points should be in the inside region (containing the origin), then
%              the irregular part of the field is zero (no coeffs c and d needed).
%            * otherwise: all of a,b,c,d are used.
%
% Returns: stEptArray, array of structures stEpt, each with fields
% - stEpt.Er: [L x 1] column vector with Er
% - stEpt.Etheta: [L x 1] column vector with Etheta
% - stEpt.Ephi: [L x 1] column vector with Ephi
% - stEpt.MLoc: [L x 1] column vector with MLoc
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

global noCheckSum;
if (isempty(noCheckSum) || ~noCheckSum)
    disp 'PweEpts: CheckSum ON'
else
    disp 'PweEpts: CheckSum OFF'
end

% loop through points
nNbPts=length(stPtArray);
for nn=1:nNbPts
    % get r,theta, and phi. stPts contains either r,theta,phi or x,y,z
    if (isfield(stPtArray(nn),'r')) && (~isempty(stPtArray(nn).r))
        r=stPtArray(nn).r;
        theta=stPtArray(nn).theta;
        phi=stPtArray(nn).phi;
    else
        % pts is in Cartesian coordinates
        stPtSph=GenGetStPtSph(stPtArray(nn));
        r=stPtSph.r; % scalar
        theta=stPtSph.theta; % scalar
        phi=stPtSph.phi; % scalar
    end
     % calculate regular VSH expansion (coeffs a,b)
    if strcmpi(sRegion,'outside')
        % get regular field from known plane wave expression of incident field
        stEAllPhiReg=PweEincThetaAllPhi(lambda,epsilon,r,theta);   
    else
        if strcmpi(sRegion,'scattering')
            % scattering only: regular VSH expansion is zero
            stEAllPhiReg.Ecr=0;
            stEAllPhiReg.Ect=0;
            stEAllPhiReg.Esf=0;
        else
            % computing regular VSH expansions (coeffs a,b)
            stEAllPhiReg=PweEgenThetaAllPhi(lambda,epsilon,stAbcdn1.an1,stAbcdn1.bn1,r,theta,'j');
        end
    end
    if strcmpi(sRegion,'inside')
        % inside: Irregular VSH expansions is zero
        stEAllPhiIrr.Ecr=0;
        stEAllPhiIrr.Ect=0;
        stEAllPhiIrr.Esf=0;
    else
        % calculate irregular VSH expansion (coeffs c,d)
        stEAllPhiIrr=PweEgenThetaAllPhi(lambda,epsilon,stAbcdn1.cn1,stAbcdn1.dn1,r,theta,'h1');  
    end

    % Ecr, Ect, and Esf are [L x 1]
    Ecr=GenCheckSum2Mat(stEAllPhiReg.Ecr,stEAllPhiIrr.Ecr,'Ecr',['PweEpts, point wih index ' int2str(nn)]);
    Ect=GenCheckSum2Mat(stEAllPhiReg.Ect,stEAllPhiIrr.Ect,'Ect',['PweEpts, point wih index ' int2str(nn)]);
    Esf=GenCheckSum2Mat(stEAllPhiReg.Esf,stEAllPhiIrr.Esf,'Esf',['PweEpts, point wih index ' int2str(nn)]);

    stEptArray(nn).Er=Ecr*cos(phi);
    stEptArray(nn).Etheta=Ect*cos(phi);
    stEptArray(nn).Ephi=Esf*sin(phi);
    stEptArray(nn).MLoc=abs(stEptArray(nn).Er).^2 + ...
        abs(stEptArray(nn).Etheta).^2 + ...
        abs(stEptArray(nn).Ephi).^2;
end