function PwePlotEmap(CstEmap,sLinLog,sHalf)
% Plots the results of PweEmap or PweVolProperties in terms of spatial distribution of EFs
% Either the SERS EF or LFIEF or field EF can be plotted.
% Two plots are produced, for phi=0 and phi=90 degrees.
%
% Parameters:
% - CstEmap: Cell of stEmap structures
%            or simply a stEmap structure if only one.
% - sLinLog: string optional
%            determines the type of plot
%            'Elinear', (F)^{1/4} is plotted on linear scale
%            'Elog', (F)^{1/4} is plotted on log10 scale
%            'Mlinear', (F)^{1/2} is plotted on linear scale
%            'Mlog', (F)^{1/2} is plotted on log10 scale
%            'Flinear', (F) is plotted on linear scale
%            'Flog', (F) is plotted on log10 scale
%            Default is 'Flog': the log10 of the SERS EFs are plotted.
% - sHalf:   string optional
%            if sHalf='half' then plots are only on theta positive
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

if nargin<3
    sHalf='full';
end

if nargin<2
    sLinLog='Flog';
end

nNbMap=length(CstEmap);

% create, position, and resize figure
scrsz = get(0,'ScreenSize'); % scrsz(3) contains screen width
figAspectRatio=2;
figWidth=scrsz(3);
figure('Name','SERS EF maps', ...
    'Position',[(scrsz(3)-figWidth)/2 scrsz(4)-150-figWidth/figAspectRatio figWidth figWidth/figAspectRatio]);
hax1=subplot(1,2,1); hold on;
hax2=subplot(1,2,2); hold on;
set(hax1,'Outerposition',[0,0,0.5,1.0])
set(hax2,'Outerposition',[0.5,0,0.5,1.0])

% loop through CstEmap and plot maps
rMax=0;
for nn=1:nNbMap
    if isstruct(CstEmap) % if single structure stEmap as argument
        F0E4phi0map=(abs(CstEmap.Ecr).^2+abs(CstEmap.Ect).^2).^2;
        F0E4phi90map=abs(CstEmap.Esf).^4;
        theta=CstEmap.theta;
        rVec=CstEmap.r;
        lambda0=CstEmap.lambda0;
    else % if cell of structure stEmap as arguments
        F0E4phi0map=(abs(CstEmap{nn}.Ecr).^2+abs(CstEmap{nn}.Ect).^2).^2;
        F0E4phi90map=abs(CstEmap{nn}.Esf).^4;
        theta=CstEmap{nn}.theta;
        rVec=CstEmap{nn}.r;
        lambda0=CstEmap{1}.lambda0; % same lambda0 for all in principle
        % lambda0 is used only for figure legend anyway
    end

    rMax=max(rMax,max(rVec)); % update rMax for axis scales
    
    % exclude r=0 (causes problem for contourf plotting)
    indr0=find(rVec==0);
    if ~isempty(indr0)
        indcor=[1:(indr0-1) (indr0+1):length(rVec)];
        rVec=rVec(indcor);
        F0E4phi0map=F0E4phi0map(indcor,:);
        F0E4phi90map=F0E4phi90map(indcor,:);
    end

    % computes what needs to be plotted
    switch lower(sLinLog)
        case 'elinear'
            F0E4phi0map=(F0E4phi0map).^(0.25);
            F0E4phi90map=(F0E4phi90map).^(0.25);
        case 'elog'
            F0E4phi0map=0.25*log10(F0E4phi0map);
            F0E4phi90map=0.25*log10(F0E4phi90map);
        case 'mlinear'
            F0E4phi0map=sqrt(F0E4phi0map);
            F0E4phi90map=sqrt(F0E4phi90map);
        case 'mlog'
            F0E4phi0map=0.5*log10(F0E4phi0map);
            F0E4phi90map=0.5*log10(F0E4phi90map);
        case 'flinear'
            % nothing already ok
        otherwise % assume 'Flog' as default
            F0E4phi0map=log10(F0E4phi0map);
            F0E4phi90map=log10(F0E4phi90map);
    end

    
    xymat = rVec * sin(theta); %  [R x T]
    zmat =  rVec * cos(theta); % [R x T]
    if strcmpi(sHalf,'half')
        % Half-contour-plot of log10(F0_E4)
        axes(hax1);
        contourf(xymat,zmat,F0E4phi0map);
        % Half-contour-plot of log10(F0_E4)
        axes(hax2);
        contourf(xymat,zmat,F0E4phi90map);
    else
        % Full-contour-plot of log10(F0_E4)
        indNegTheta=length(theta):-1:2;
        indAllTheta=[indNegTheta,1:length(theta)];
        axes(hax1);
        contourf([-xymat(:,indNegTheta), xymat],zmat(:,indAllTheta),F0E4phi0map(:,indAllTheta) );
        axes(hax2);
        contourf([-xymat(:,indNegTheta), xymat],zmat(:,indAllTheta),F0E4phi90map(:,indAllTheta) );
    end
end

switch lower(sLinLog)
    case 'elinear'
        sTitle='|E/E_0|';
    case 'elog'
        sTitle='log10 |E/E_0|';
    case 'mlinear'
        sTitle='M_{Loc}';
    case 'mlog'
        sTitle='log10 M_{Loc}';
    case 'flinear'
        sTitle='F_{E4}^0';
    otherwise % assume 'Flog' as default
        sTitle='log10 F_{E4}^0';
end


axes(hax1);
axis equal;
if strcmpi(sHalf,'half')
    axis([0 rMax -rMax rMax]);
else
    axis([-rMax rMax -rMax rMax]);
end
hold off;
caxis(get(gca,'CLim'))
colorbar('peer',gca);
xlabel('x [nm]');
ylabel('z [nm]');
title([sTitle '(\phi=0) at \lambda=' num2str(lambda0) 'nm']);

axes(hax2);
axis equal;
if strcmpi(sHalf,'half')
    axis([0 rMax -rMax rMax]);
else
    axis([-rMax rMax -rMax rMax]);
end
hold off;
caxis(get(gca,'CLim'))
colorbar('peer',gca);
xlabel('y [nm]');
ylabel('z [nm]');
title([sTitle '(\phi=90^\circ) at \lambda=' num2str(lambda0) 'nm']);
