function stMieRes=PweSolveSingleSphere(nNmax,a,lambda,epsilonM,epsilonIn,sPlot,sCoeff)
% Solves the problem of PWE of single sphere with Mie theory
% The parameters are given as arguments or may also be given in a
% structure stMP when called as PweSolveSingleSphere(stMP,sPlot,sCoeff)
% where stMP contains the parameter fields.
% Note that for PWE, we have for the Mie coefficients:
% |m|=1 only; a,c even in m; b,d odd in m.
% For example, the scattered field is entirely defined by
% c_{n,1} and d_{n,1}
% (c_{n,-1}=c_{n,1}, d_{n,-1}=-d_{n,1}, and
% all other coefficients are zero).
%
% Parameters:
% - nNmax:     integer [1 x 1]
%              number of n in series
% - a:         integer [1 x 1]
%              radius of sphere (typically in NANOMETERS)
% - lambda:    possibly column vector [L x 1]
%              wavelengths (typically in NANOMETERS)
% - epsilonM:  scalar or column vector [L x 1]
%              epsilon of embedding medium (possibly
%              wavelength-dependent)
% - epsilonIn: scalar or column vector [L x 1]
%              epsilon of sphere material (possibly
%              wavelength-dependent)
% - sPlot:     optional (default does nothing)
%              'plot' will produce a new figure with a plot
%              of Qext, Qabs, Qsca, and MLocAve
% - sCoeff:    optional (default does nothing)
%              'coeff' will return the Mie coefficients alphan1, betan1, cn1, and
%              dn1 as fields of the result structure
%              'suscep' will return the Mie susceptibilities Gamma, Delta,
%              A, and B as fields of the result structure
%              'both' will return both Mie coefficients and
%              susceptibilities 
%
% Returns: structure stMieRes with fields containing the parameters for
%          future reference and additional fields for the results
% - stMieRes.nNmax: scalar
% - stMieRes.a: scalar
% - stMieRes.lambda: [L x 1]
% - stMieRes.epsilonM: scalar or [L x 1]
% - stMieRes.epsilonIn: scalar or [L x 1]
% - stMieRes.x: [L x 1]
% - stMieRes.s: [L x 1]
% - stMieRes.Qext: [L x 1] wavelength-dependent extinction coefficient
% - stMieRes.Qsca: [L x 1] wavelength-dependent scattering coefficient
% - stMieRes.Qabs: [L x 1] wavelength-dependent absorption coefficient
% - stMieRes.MLocAve: [L x 1] wavelength-dependent average LFIEF
% - stMieRes.alphan1 (if sCoeff='coeff' or 'both'): [L x nNmax]
% - stMieRes.betan1 (if sCoeff='coeff' or 'both'): [L x nNmax]
% - stMieRes.cn1 (if sCoeff='coeff' or 'both'): [L x nNmax]
% - stMieRes.dn1 (if sCoeff='coeff' or 'both'): [L x nNmax]
% - stMieRes.Gamma (if sCoeff='suscep' or 'both'): [L x nNmax]
% - stMieRes.Delta (if sCoeff='suscep' or 'both'): [L x nNmax]
% - stMieRes.A (if sCoeff='suscep' or 'both'): [L x nNmax]
% - stMieRes.B (if sCoeff='suscep' or 'both'): [L x nNmax]
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

disp ' ';
global noCheckSum;
if (isempty(noCheckSum) || ~noCheckSum)
    disp 'PweSolveSingleSphere: Solving Mie for single sphere - CheckSum ON'
else
    disp 'PweSolveSingleSphere: Solving Mie for single sphere - CheckSum OFF'
end

% rearrange function parameters and define optional parameters
% number of parameters is 1,2, or 3 if called as stMP,sOption,sCoeff
% or 5,6, or 7 if nMax,a,lambda,epsilonM,epsilonIn,sOption,sCoeff
nNbParam=nargin;
if ((nNbParam==1) || (nNbParam==5))
    sPlot='No';
    sCoeff='No';
end
if ((nNbParam==2) || (nNbParam==6))
    sCoeff='No';
end
if (nNbParam<4)
    nNmax=stMP.nNmax;
    a=stMP.a;
    lambda=stMP.lambda;
    epsilonM=stMP.epsilonM;
    epsilonIn=stMP.epsilonIn;
end

% Calculate x=k_M a where k_M is wavevector outside the sphere
% see Eq. H.45
x=2*pi* sqrt(epsilonM) *a ./ lambda; % [L x 1]
% Calculate s=k_in/k_M where k_in  is wavevector inside sphere
% see Eq. H.45
% 0*lambda is used to ensure that s is [L x 1] even when both epsilon are
% scalar
s=sqrt(epsilonIn+0*lambda)./sqrt(epsilonM); % [L x 1]

% Calculate susceptibilities Gamma_n, Delta_n, A_n, and B_n
% (defined in Eqs. H.12 and H.13)
% for all n and all lambda
% Gamma, Delta, A, and B are matrices [L x Nmax]
stGDAB=GenSuscepGDAB(nNmax,s,x);

% Calculate Q coeffs and average local field for PWEs
stMieRes=PweQcoeff(x,stGDAB);
stMieRes.MLocAve=PweMLocAve(x,stGDAB);

% return results
stMieRes.nNmax=nNmax;
stMieRes.a=a;
stMieRes.lambda=lambda;
stMieRes.epsilonM=epsilonM;
stMieRes.epsilonIn=epsilonIn;
stMieRes.x=x;
stMieRes.s=s;

if (strcmpi(sCoeff,'suscep') || strcmpi(sCoeff,'both'))
    stMieRes.Gamma=stGDAB.Gamma;
    stMieRes.Delta=stGDAB.Delta;
    stMieRes.A=stGDAB.A;
    stMieRes.B=stGDAB.B;
end

if (strcmpi(sCoeff,'coeff') || strcmpi(sCoeff,'both'))
    % calculate incident PW coefficient an1 and bn1
    stIncEabn1=PweIncEabn1(nNmax);
    an1mat=repmat(stIncEabn1.an1,length(lambda),1); % [L x nNmax]
    bn1mat=repmat(stIncEabn1.bn1,length(lambda),1); % [L x nNmax]
    % Eq. H.12
    stMieRes.cn1=stGDAB.Gamma .* an1mat;
    stMieRes.dn1=stGDAB.Delta .* bn1mat;
    % Eq. H.13
    stMieRes.alphan1=stGDAB.A .* an1mat;
    stMieRes.betan1=stGDAB.B .* bn1mat;
end

% plot if required
if strcmpi(sPlot,'plot')
    disp 'Drawing plot...'
    PwePlotQandM(stMieRes);
end

disp 'PweSolveSingleSphere: done.'
disp ' '