function stEsurf=PweSurfProperties(stM,r0,nNbTheta,stPinTaun)
% Calculates several properties of the field on a spherical surface at r=r0 for PWE.
%
% Parameters:
% - stM:    structure with results of the Mie computation
%           can be obtained by calling PweSolveSingleSphere
%           or MulPweSolveMultiSphere with sCoeff='coeff'
% - r0:     scalar [1 x 1] non-zero
%           distance from origin (in nm)
% - nNbTheta: integer scalar
%             number of theta points used for computations
% - stPinTaun: structure (optional)
%              with functions of theta pi_n and tau_n
%              if omitted, then the functions are computed from scrath
%              it is faster to pass this structure as argument if these
%              functions have already been calculated 
% 
% Returns: structure stEsurf  (see PweEsurf for details)
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

% get theta dependence if not provided
if nargin < 4
    theta=linspace(0,pi,nNbTheta); % row [1 x T]
    stPinTaun=PwePinTaun(stM.nNmax,transpose(theta)); % fields are [T x nNmax]
end


if ~isfield(stM,'nK') % then stM corresponds to a single sphere
    % results depend on whether surface is inside or outside
    if (r0<0.99999*stM.a) % note that if r0=a, properties are computed outside the sphere
        stAbcdn1.an1=stM.alphan1;
        stAbcdn1.bn1=stM.betan1;
        stEsurf=PweEsurf(stM.lambda,stM.epsilonIn,stAbcdn1,r0,nNbTheta,'Inside',stPinTaun);
    else
        % stM already contains fields cn1 and dn1
        stEsurf=PweEsurf(stM.lambda,stM.epsilonM,stM,r0,nNbTheta,'Outside',stPinTaun);
    end
else % then stM corresponds to a spherical multilayer
    % find layer where r0 is located
    nK=stM.nK;
    kk=nK;
    while ((kk>0) && (r0<0.99999*stM.Ca{kk})) % note that if r0=Ca{kk}, properties are computed just outside
        kk=kk-1;
    end
    % r0 has been located in region kk
    % extract corresponding Mie coefficients
    stAbcdn1.an1=stM.Calphakn1{kk+1};
    stAbcdn1.bn1=stM.Cbetakn1{kk+1};
    stAbcdn1.cn1=stM.Cgammakn1{kk+1};
    stAbcdn1.dn1=stM.Cdeltakn1{kk+1};
    if (kk==nK) % outside region
        sRegion='Outside';
    elseif (kk==0) % inside sphere
        sRegion='Inside';
    else % other cases
        sRegion='General';
    end
    stEsurf=PweEsurf(stM.lambda,stM.Cepsilon{kk+1},stAbcdn1,r0,nNbTheta,sRegion,stPinTaun);
end


end

