function CstEmap=PweVolProperties(stM,lambda0,rMax,nNbRout,nNbRin,nNbTheta,stPinTaun)
% Calculates several properties of the field everywhere up to r=rMax for a single wavelength
%
% Parameters:
% - stM:    structure with results of the Mie computation
%           can be obtained by calling PweSolveSingleSphere
%           or MulPweSolveMultiSphere with sCoeff='coeff'
% - lambda0: wavelength in nm (must obviously be one of the
%            wavelengths computed in stM)
% - rMax:    scalar [1 x 1] non-zero
%            distance from origin (in nm)
% - nNbRout: integer scalar [1 x 1] 
%            number of r considered outside (zero if not required)
% - nNbRin:  if single sphere: integer scalar [1 x 1]
%            number of r considered inside (zero if not required)
%            if multi sphere: cell of K integer scalars one for each of 
%            the K inside regions (from region 0 to region K-1)
% - nNbTheta: integer scalar
%             number of theta points used for computations
% - stPinTaun: structure (optional)
%              with functions of theta pi_n and tau_n
%              if omitted, then the functions are computed from scrath
%              it is faster to pass this structure as argument if these
%              functions have already been calculated 
% 
% Returns: cell (row) of structures of type stEmap (see PweEmap for details)
%          for outside and inside computations (if both required)
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

% find lambda0 and extract relevant coefficients
lambda=stM.lambda;
indLambda=find(lambda==lambda0,1);
if isempty(indLambda)
        disp(['PweVolProperties: lambda0=' num2str(lambda0) ...
            ' cannot be found. Using lambda=' num2str(lambda(1)) ' instead']);
        indLambda=1;
end

% get theta dependence if not provided
if nargin < 7
    theta=linspace(0,pi,nNbTheta); % row [1 x T]
    stPinTaun=PwePinTaun(stM.nNmax,transpose(theta)); % fields are [T x nNmax]
end

% computes outside map:
nNbMap=0;
if (nNbRout~=0)
    % extract epsilonM(lambda0)
    % the following is a trick to handle both scalar and vector epsilon
    epsilonM0=stM.epsilonM(min(length(stM.epsilonM),indLambda));
    disp ' ';
    disp 'PweVolProperties: computing outside map...';
    rVec=transpose(linspace(stM.a,rMax,nNbRout)); % [R x 1]
    stMieCcdn1L0.cn1=stM.cn1(indLambda,:); % [1 x N]
    stMieCcdn1L0.dn1=stM.dn1(indLambda,:); % [1 x N]
    nNbMap=nNbMap+1;
    CstEmap{1,nNbMap}=PweEmap(lambda0,epsilonM0,stMieCcdn1L0,rVec,nNbTheta,'Outside',stPinTaun);
    clear stMieCcdn1L0;
end

% computes inside maps:
if ~isfield(stM,'nK') % then stM is for single sphere
    if (nNbRin~=0)  % do nothing if nNbRin=0
        % extract epsilonIn(lambda0)
        epsilonIn0=stM.epsilonIn(min(length(stM.epsilonIn),indLambda));
        disp ' ';
        disp 'PweVolProperties: computing single sphere inside map...';
        rVec=transpose(linspace(0,stM.a,nNbRin)); % [R x 1]
        stMieCabn1L0.an1=stM.alphan1(indLambda,:); % [1 x N]
        stMieCabn1L0.bn1=stM.betan1(indLambda,:); % [1 x N]
        nNbMap=nNbMap+1;
        CstEmap{1,nNbMap}=PweEmap(lambda0,epsilonIn0,stMieCabn1L0,rVec,nNbTheta,'Inside',stPinTaun);
    end
else % then stM is for sphere multilayer
    disp ' ';
    disp 'PweVolProperties: computing multilayer sphere inside map...';
    nK=stM.nK;
    for kk=(nK-1):-1:0
        % for region kk
        if nNbRin{kk+1}~=0 % do not compute this region otherwise
            % extract epsilon_kk(lambda0)
            epsilonL0=stM.Cepsilon{kk+1}(min(length(stM.Cepsilon{kk+1}),indLambda));
            if kk==0
                sRegion='Inside';
                % r between 0 and a_{1}
                rVec=transpose(linspace(0,stM.Ca{1},nNbRin{1})); % [R x 1]end
            else
                sRegion='General';
                % r between a_{kk-1} and a_{kk}
                rVec=transpose(linspace(stM.Ca{kk},stM.Ca{kk+1},nNbRin{kk+1})); % [R x 1]end
                % get corresponding coefficients (but not c and d when inside)
                stMieCabcdn1L0.cn1=stM.Cgammakn1{kk+1}(indLambda,:); % [1 x N]
                stMieCabcdn1L0.dn1=stM.Cdeltakn1{kk+1}(indLambda,:); % [1 x N]
            end
            stMieCabcdn1L0.an1=stM.Calphakn1{kk+1}(indLambda,:); % [1 x N]
            stMieCabcdn1L0.bn1=stM.Cbetakn1{kk+1}(indLambda,:); % [1 x N]
            nNbMap=nNbMap+1;
            % compute map
            CstEmap{1,nNbMap}=PweEmap(lambda0,epsilonL0,stMieCabcdn1L0,rVec,nNbTheta,sRegion,stPinTaun);
        end
    end
end