% Script for symbolic expressions for the lowest orders Z_n functions and their small-argument Taylor expansions
% The Z_n functions are derived from the spherical Bessel functions as in Eq. H.35.
% The spherical Bessel function j and spherical Hankel function h1 are used here
% This script requires the Matlab symbolic toolbox to run.
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

nNmax=4;
nTaylor=9;
syms x; % use x real positive for better simplification

nm1=0:nNmax;
nu=nm1+0.5;

fjnm1=besselj(nu,x);
fh1nm1=fjnm1+1i*bessely(nu,x);

sq=sqrt((pi/2)/x); 
sqmat=repmat(sq,1,nNmax+1); % [1 x nNmax+1]
fjnm1=simplify(fjnm1.*sqmat);
fh1nm1=simplify(fh1nm1.*sqmat);
% fjnm1 and fh1nm1  are now matrix of spherical Bessel
% j_n(rho), n=0..nNmax or equivalently j_{n-1}(rho), n=1..nNmax+1

Z0j=fjnm1(2:(nNmax+1));
Z1j=simplify(Z0j/x);
Z2j=simplify(fjnm1(1:nNmax)-(1:nNmax).*Z1j);
%Z2jcheck=simplify(diff(x*Z0j,x)/x);

Z0h1=simplify(factor(fh1nm1(2:(nNmax+1))));
Z1h1=simplify(factor(Z0h1/x));
Z2h1=simplify(factor(fh1nm1(1:nNmax)-(1:nNmax).*Z1h1));
%Z2h1check=simplify(factor(diff(x*Z0h1,x)/x));

% Write output:
disp('Functions:')
disp(' ')
for n=1:(nNmax)
    disp(['j:Z^0_' int2str(n) '(x)= ' char(Z0j(n))])
    disp(['j:Z^1_' int2str(n) '(x)= ' char(Z1j(n))])
    disp(['j:Z^2_' int2str(n) '(x)= ' char(Z2j(n))])
%    disp(['j:Z^2c_' int2str(n) '(x)= ' char(Z2jcheck(n))])
    disp(' ')
    disp(['h1:Z^0_' int2str(n) '(x)= exp(i*x)* [' char(simple(Z0h1(n)/(cos(x)+1i*sin(x)))) ']'])
    disp(['h1:Z^1_' int2str(n) '(x)= exp(i*x)* [' char(simple(Z1h1(n)/(cos(x)+1i*sin(x)))) ']'])
    disp(['h1:Z^2_' int2str(n) '(x)= exp(i*x)* [' char(simple(Z2h1(n)/(cos(x)+1i*sin(x)))) ']'])
%    disp(['h1:Z^2c_' int2str(n) '(x)= exp(-i*x)* [' char(simple(Z2h1check(n)/(cos(x)-i*sin(x)))) ']'])
    disp(' ')
    disp(' ')
end

% Write output:
disp('Taylor expansions around x=0:')
disp(' ')
for n=1:(nNmax)
    disp(['j:Z^0_' int2str(n) '(x)= x^' int2str(n) '* [' ...
        char(taylor(simplify(Z0j(n))/x^(n),x,'Order',nTaylor+2*n+1)) ']'])
%    disp(['j:Z^1_' int2str(n) '(x)= x^' int2str(n-1) '* [' ...
%        char(taylor(simplify(Z1j(n))/x^(n-1),x,'Order',nTaylor+2*n)) ']'])
    disp(['j:Z^2_' int2str(n) '(x)= x^' int2str(n-1) '* [' ...
        char(taylor(simplify(Z2j(n))/x^(n-1),x,'Order',nTaylor+2*n+1)) ']'])
    disp(' ')
    disp(['h1:Z^0_' int2str(n) '(x)= 1/x^' int2str(n+1) '* [' ...
        char(taylor(simplify(factor(Z0h1(n))*(x^(n+1))),x,'Order',nTaylor)) ']'])
%   disp(['h1:Z^1_' int2str(n) '(x)= 1/x^' int2str(n+2) '* [' ...
%        char(taylor(simplify(factor(Z1h1(n))*(x^(n+2))),x,'Order',nTaylor)) ']'])
    disp(['h1:Z^2_' int2str(n) '(x)= 1/x^' int2str(n+2) '* [' ...
        char(taylor(simplify(factor(Z2h1(n))*(x^(n+2))),x,'Order',nTaylor)) ']'])
    disp(' ')
    disp(' ')
end

