function stResMulti = PlnMultiRef (sPol, nNbSurf, lambda, Cepsilon, CL, aideg, d)
% Computes the reflection/refraction problem at a multilayer interface for TM or TE polarizations
% The problem is defined by j=1..nNbSurf+1 regions separated by
% i=1..nNbSurf interfaces at z=Z_i (see Fig. F.3). The first interface is at z=0.
% Region 1 is z<0 and contains the incident wave (incident from z=-infty)
% The plane of incidence is by convention xOz.
% 
% Parameters:
% - sPol:   string
%           sPol='TE' for TE or sPol='TM' for TM (default value)
%           polarizations
% - nNbSurf: scalar integer [1x1]
%            number of interfaces (i.e. there are nNbSurf+1 regions)
%            see Sec. F.4.1 and Fig. F.3 for more details.
% - lambda: column vector [Lx1]
%           wavelengths in NANOMETERS (nm)
% - Cepsilon: cell of nNbSurf+1 column vectors (same size as lambda):
%             i.e.: {(nNbSurf+1) * [Lx1]}
%             lambda-dependent epsilons in each region.
% - CL:     cell of nNbSurf scalar real numbers: {nNbSurf * [1x1]}
%           region thicknesses (L_j=Z_{j+1}-Z_j) in NANOMETERS (i.e. distance between two interfaces).
%           Note that CL{1}=L_1 must be zero by convention (see Fig. F.3)
% - aideg:  row vector [1xA]
%           angles of incidence in DEGREES.
% - d:      optional scalar real number [1x1] (d=0 if not supplied)
%           distance in NANOMETERS from interface where local field EFs are estimated
%      
% Returns: a stResMulti structure containing fields as listed below:
% Note that EM fields are defined as in Eq. F.11 (TM) and Eq. F.18 (TE)
%
% For TM waves, we have:
% ** The Fresnel coefficients, which can be used for general properties:
% - rP: matrix [LxA]
%       Fresnel reflection coefficients (Eqs. F.45, F.79)
%       for each wavelength and angle of incidence
% - tP: matrix [LxA]
%       Fresnel transmission coefficients (Eqs. F.46, F.80)
%       for each wavelength and angle of incidence
%
% ** The field amplitudes, which can be used to calculate the EM field at
% any points:
% - HiyOvH1y: Cell of nNbSurf+1 matrices, {(nNbsurf+1)*[LxA]}
%             field amplitude of first wave in each region i
%             characterized by the ratio \bar{H}_{iy}/H_{1y}
%             (see Eq. F.74 for a definition of \bar{H}_{iy})
%             given for each wavelength and angle of incidence
% - HipyOvH1y: Cell of nNbSurf+1 matrices, {(nNbsurf+1)*[LxA]}
%              same as HiyOvH1y but for second wave: \bar{H}'_{iy}/H_{1y}
% - EixOvE1: Cell of nNbSurf+1 matrices, {(nNbsurf+1)*[LxA]}
%            \bar{E}_{ix}/E_1
%            where E_1=H_{1y}/(\epsilon_0 c \sqrt{\epsilon_1})
% - EizOvE1: {(nNbsurf+1)*[LxA]}
%            \bar{E}_{iz}/E_1
% - EipxOvE1: {(nNbsurf+1)*[LxA]}
%            \bar{E}'_{ix}/E_1
% - EipzOvE1: {(nNbsurf+1)*[LxA]}
%            \bar{E}'_{iz}/E_1
%
% ** The local field intensity enhancement factors (LFIEF) at a distance d on either side of
% each of the nNbSurf interface.
% For interface i, "outside" means towards region i and inside means
% towards region i+1.
% - MoutPerp: {nNbSurf * [LxA]}
%             perpendicular LFIEF, i.e. |E_z|^2/|E_1|^2 at a distance d
%             on the "outside" of each interface
% - MoutPara: {nNbSurf * [LxA]}
%             parallel LFIEF, i.e. |E_x|^2/|E_1|^2 at a distance d
%             on the "outside" of each interface
% - MinPerp: {nNbSurf * [LxA]}
%             perpendicular LFIEF, i.e. |E_z|^2/|E_1|^2 at a distance d
%             on the "inside" of each interface
% - MinPara: {nNbSurf * [LxA]}
%             parallel LFIEF, i.e. |E_x|^2/|E_1|^2 at a distance d
%             on the "inside" of each interface
%
%
% For TE waves, the output is similar but the name are changed to reflect
% the different nature of the fiels:
% - rS: matrix [LxA]
%       Fresnel reflection coefficients (Eqs. F.62, F.79)
%       for each wavelength and angle of incidence
% - tS: matrix [LxA]
%       Fresnel transmission coefficients (Eqs. F.63, F.80)
%       for each wavelength and angle of incidence
% - EiyOvE1y: {(nNbsurf+1)*[LxA]}
%             field amplitude of first wave in each region i
%             characterized by the ratio \bar{E}_{iy}/E_{1y}
%             (see Eq. F.74 for a definition of \bar{E}_{iy})
%             given for each wavelength and angle of incidence
% - EipyOvE1y: {(nNbsurf+1)*[LxA]}
%              same as EiyOvE1y but for second wave: \bar{E}'_{iy}/E_{1y}
% - HixOvH1: {(nNbsurf+1)*[LxA]}
%            \bar{H}_{ix}/H_1
%            where H_1=E_{1y}*(\epsilon_0 c \sqrt{\epsilon_1})
% - HizOvH1: {(nNbsurf+1)*[LxA]}
%            \bar{H}_{iz}/H_1
% - HipxOvH1: {(nNbsurf+1)*[LxA]}
%            \bar{H}'_{ix}/H_1
% - HipzOvH1: {(nNbsurf+1)*[LxA]}
%            \bar{H}'_{iz}/H_1
% - MoutPerp: {nNbSurf * [LxA]}
%             perpendicular LFIEF, is zero for TE waves
% - MoutPara: {nNbSurf * [LxA]}
%             parallel LFIEF, i.e. |E_x|^2/|E_1|^2 at a distance d
%             on the "outside" of each interface
% - MinPerp: {nNbSurf * [LxA]}
%             perpendicular LFIEF is zero for TE waves
% - MinPara: {nNbSurf * [LxA]}
%             parallel LFIEF, i.e. |E_x|^2/|E_1|^2 at a distance d
%             on the "inside" of each interface
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information


%%%%%%%%%%%%%%%%%%%%%%%
% Check parameters
%%%%%%%%%%%%%%%%%%%%%%%
% optional parameters
if nargin < 7, d = 0; end

if ~((strcmp(sPol,'TM')) || (strcmp(sPol,'TE')))
    disp 'Warning (PlnMultiRef): Polarization not properly specified. Assuming TM polarization.';
    sPol='TM';
end

if (CL{1}~=0)
    disp 'Warning (PlnMultiRef): L_1 must be zero. Check CL parameter. Changing to CL{1}=0';
    % enforce L_1=0 (by convention)
    CL{1}=0;
end

%%%%%%%%%%%%%%%%%%%%%%%
% Computations
%%%%%%%%%%%%%%%%%%%%%%%

nNbAngle=length(aideg); % nb of columns (angles), i.e. A
nNbLambda=length(lambda); % nb of rows (wavelengths), i.e. L

k0=2*pi./lambda; % column [Lx1]

% angle of incidence in radian
ai=aideg/180*pi; % row [1xA]

% calculate k_x (same for all regions), Eq. F.42
k1=k0.*sqrt(Cepsilon{1}); % column [Lx1]
kx=k1 * sin(ai); % matrix [LxA] (lambda in rows and angles in columns)

% calculates k_{iz} in each region (matrices) and place in a cell
Ckiz=cell(1,nNbSurf+1);
for ii=1:(nNbSurf+1)
    % each CKiz{ii} is a matrix [LxA]
    % Computed from Eq. F.71
    Ckiz{ii}=sqrt(repmat(Cepsilon{ii}.*k0.^2,1,nNbAngle)-kx.^2); 
    % Note that k_{iz} is assumed non-zero
    % except possibly in last region i=nNbSurf+1
    % Check this and issue a warning if not the case.
    % Assume k_{iz} is zero if k_{iz}/k0 smaller than 1e-6
    if (ii<nNbSurf+1)
        indPb=find(abs(Ckiz{ii}./repmat(k0,1,nNbAngle))<1e-6);
        for jj=1:length(indPb)
            % issue warning for each problem
            disp (['Warning: kiz is close to zero in region ' ...
                num2str(ii) ' at wavelength ' num2str(lambda(mod(indPb(jj),nNbLambda))) ...
                ' nm and angle ' num2str(aideg(floor(indPb(jj)-1)/nNbLambda)) ' degrees.']);
            disp (['kiz = ' num2str(Ckiz{indPb(jj)}/k0(mod(indPb(jj),nNbLambda))) ' * k0']);
        end
    end
end


% initialize M matrix to identity
M11=1;
M21=0;
M12=0;
M22=1;

% loop through the interfaces to compute Mi (Eq. F.76) and M (Eq. F.78)
Mi11=cell(1,nNbSurf);
Mi21=cell(1,nNbSurf);
Mi12=cell(1,nNbSurf);
Mi22=cell(1,nNbSurf);
for ii=1:nNbSurf
    % calculate Ki [LxA]
    if (strcmp(sPol,'TM')) % TM wave, see Eq. F.16 and Eq. F.72
        Ki=repmat(Cepsilon{ii}./Cepsilon{ii+1},1,nNbAngle).*Ckiz{ii+1}./Ckiz{ii};
    else % TE wave, see Eq. F.22
        Ki=Ckiz{ii+1}./Ckiz{ii};
    end
    
    % calculate matrix Mi components (all are matrices [LxA])
    % using Eq. F.76
    AuxMi=exp(i*CL{ii}*Ckiz{ii});
    Mi11{ii}=0.5*(1+Ki)./ AuxMi;
    Mi21{ii}=0.5*(1-Ki).* AuxMi;
    Mi12{ii}=0.5*(1-Ki)./ AuxMi;
    Mi22{ii}=0.5*(1+Ki).* AuxMi;

    % update M matrix (Eq. F.78)
    M11new=M11.*Mi11{ii} + M12.*Mi21{ii};
    M21new=M21.*Mi11{ii} + M22.*Mi21{ii};
    M12new=M11.*Mi12{ii} + M12.*Mi22{ii};
    M22new=M21.*Mi12{ii} + M22.*Mi22{ii};
    M11=M11new;
    M21=M21new;
    M12=M12new;
    M22=M22new;
end

%%%%%%%%%%%%%%%%%%%%%%%
% Outputs
%%%%%%%%%%%%%%%%%%%%%%%

% calculate Fresnel coefficients
% see Eq. F.79 and F.80 (for TM)
% same expressions for TE but relate to electric field
tF=1./M11;  
rF=M21.*tF; % Eq. F.80 (for TM)

% initialize local field intensity EFs at each interface
MoutPerp=cell(1,nNbSurf);
MoutPara=cell(1,nNbSurf);
MinPerp=cell(1,nNbSurf);
MinPara=cell(1,nNbSurf);


% treat separately TM and TE from now on
% All field outputs are cells of matrices [LxA]
if (strcmp(sPol,'TM'))
%%%%%%%%%%%%%%%%%
% TM waves
%%%%%%%%%%%%%%%%%
    % initialize field amplitudes in each region
    HiyOvH1y=cell(1,nNbSurf+1); 
    HpiyOvH1y=cell(1,nNbSurf+1); 
    EixOvE1=cell(1,nNbSurf+1);
    EpixOvE1=cell(1,nNbSurf+1);
    EizOvE1=cell(1,nNbSurf+1);
    EpizOvE1=cell(1,nNbSurf+1);

    % Fields in last region (nNbSurf+1)
    HiyOvH1y{nNbSurf+1}=tF; % H_{iy} / H_{1y}
    HpiyOvH1y{nNbSurf+1}=0; % H'_{iy} / H_{1y}
    % use for reference (possibly complex) E field: E1= H_{1y}/|H_{1y}| |E_1|
    % E1=H_{1y}/ [(epsilon_0 c) sqrt{epsilon_1}]
    AuxE1=repmat(sqrt(Cepsilon{1})./k0./Cepsilon{nNbSurf+1},1,nNbAngle);
    EixOvE1{nNbSurf+1}=HiyOvH1y{nNbSurf+1}.* Ckiz{nNbSurf+1} .* AuxE1;
    EpixOvE1{nNbSurf+1}=0;
    EizOvE1{nNbSurf+1}=-HiyOvH1y{nNbSurf+1}.* ( (Cepsilon{1}./Cepsilon{nNbSurf+1}) * sin(ai) );
    EpizOvE1{nNbSurf+1}=0;

    % loop (downwards) to compute field amplitudes in other regions
    for ii=nNbSurf:-1:1
        HiyOvH1y{ii}=Mi11{ii}.*HiyOvH1y{ii+1}+Mi12{ii}.*HpiyOvH1y{ii+1};
        HpiyOvH1y{ii}=Mi21{ii}.*HiyOvH1y{ii+1}+Mi22{ii}.*HpiyOvH1y{ii+1};
    
        AuxE1=repmat(sqrt(Cepsilon{1})./k0./Cepsilon{ii},1,nNbAngle);
        EixOvE1{ii}=HiyOvH1y{ii}.* Ckiz{ii} .* AuxE1;
        EpixOvE1{ii}=-HpiyOvH1y{ii}.* Ckiz{ii} .* AuxE1;
        AuxE2=(Cepsilon{1}./Cepsilon{ii}) * sin(ai) ; % matrix product
        EizOvE1{ii}=-HiyOvH1y{ii}.* AuxE2;
        EpizOvE1{ii}=-HpiyOvH1y{ii}.* AuxE2;
    end

    % loop again to compute local field EFs on each of the nNbSurf
    % interfaces
    for ii=1:nNbSurf
        MoutPerp{ii}=abs( EizOvE1{ii}.*exp(i*(CL{ii}-d)*Ckiz{ii})+ ...
            EpizOvE1{ii}.*exp(-i*(CL{ii}-d)*Ckiz{ii}) ).^2;
        MoutPara{ii}=abs( EixOvE1{ii}.*exp(i*(CL{ii}-d)*Ckiz{ii})+ ...
            EpixOvE1{ii}.*exp(-i*(CL{ii}-d)*Ckiz{ii}) ).^2;

        MinPerp{ii}=abs( EizOvE1{ii+1}.*exp(i*d*Ckiz{ii+1})+ ...
            EpizOvE1{ii+1}.*exp(-i*d*Ckiz{ii+1}) ).^2;
        MinPara{ii}=abs( EixOvE1{ii+1}.*exp(i*d*Ckiz{ii+1})+ ...
            EpixOvE1{ii+1}.*exp(-i*d*Ckiz{ii+1}) ).^2;
    end


else 
%%%%%%%%%%%%%%%%%
% TE waves
%%%%%%%%%%%%%%%%%
    
    % initialize field amplitudes in each region
    EiyOvE1y=cell(1,nNbSurf+1); 
    EpiyOvE1y=cell(1,nNbSurf+1); 
    HixOvH1=cell(1,nNbSurf+1);
    HpixOvH1=cell(1,nNbSurf+1);
    HizOvH1=cell(1,nNbSurf+1);
    HpizOvH1=cell(1,nNbSurf+1);

    % Fields in last region (nNbSurf+1)
    EiyOvE1y{nNbSurf+1}=tF; % E_{iy} / E_{1y}
    EpiyOvE1y{nNbSurf+1}=0; % E'_{iy} / E_{1y}
    % use for reference (possibly complex) H field: H1= E_{1y}/|E_{1y}| |H_1|
    % H1=E_{1y}* [(epsilon_0 c) sqrt{epsilon_1}]
    AuxH1=repmat(1./(sqrt(Cepsilon{1}).*k0),1,nNbAngle);
    HixOvH1{nNbSurf+1}=-EiyOvE1y{nNbSurf+1}.* Ckiz{nNbSurf+1} .* AuxH1;
    HpixOvH1{nNbSurf+1}=0;
    AuxH2=repmat(sin(ai),nNbLambda,1);
    HizOvH1{nNbSurf+1}=EiyOvE1y{nNbSurf+1}.* AuxH2;
    HpizOvH1{nNbSurf+1}=0;

    % loop (downwards) to compute field amplitudes in other regions
    for ii=nNbSurf:-1:1
        EiyOvE1y{ii}=Mi11{ii}.*EiyOvE1y{ii+1}+Mi12{ii}.*EpiyOvE1y{ii+1};
        EpiyOvE1y{ii}=Mi21{ii}.*EiyOvE1y{ii+1}+Mi22{ii}.*EpiyOvE1y{ii+1};
    
        HixOvH1{ii}=-EiyOvE1y{ii}.* Ckiz{ii} .* AuxH1;
        HpixOvH1{ii}=EpiyOvE1y{ii}.* Ckiz{ii} .* AuxH1;
        HizOvH1{ii}=EiyOvE1y{ii}.* AuxH2;
        HpizOvH1{ii}=EpiyOvE1y{ii}.* AuxH2;
    end

    % loop again to compute local field EFs on each of the nNbSurf
    % interfaces
    for ii=1:nNbSurf
        MoutPara{ii}=abs( EiyOvE1y{ii}.*exp(i*(CL{ii}-d)*Ckiz{ii})+ ...
            EpiyOvE1y{ii}.*exp(-i*(CL{ii}-d)*Ckiz{ii}) ).^2;

        MinPara{ii}=abs( EiyOvE1y{ii+1}.*exp(i*d*Ckiz{ii+1})+ ...
            EpiyOvE1y{ii+1}.*exp(-i*d*Ckiz{ii+1}) ).^2;
        MoutPerp{ii}=zeros(nNbLambda,nNbAngle);
        MinPerp{ii}=zeros(nNbLambda,nNbAngle);
    end
end

% Finally,
% create structure for results

% results common to TM and TE waves
stResMulti.sPol=sPol;
stResMulti.nNbSurf=nNbSurf;
stResMulti.lambda=lambda;
stResMulti.Cepsilon=Cepsilon;
stResMulti.CL=CL;
stResMulti.aideg=aideg;
stResMulti.d=d;

stResMulti.MoutPerp=MoutPerp;
stResMulti.MoutPara=MoutPara;
stResMulti.MinPerp=MinPerp;
stResMulti.MinPara=MinPara;


if (strcmp(sPol,'TM')) % TM waves
    stResMulti.rP=rF;
    stResMulti.tP=tF;
    stResMulti.HiyOvH1y=HiyOvH1y;
    stResMulti.HpiyOvH1y=HpiyOvH1y;
    stResMulti.EixOvE1=EixOvE1;
    stResMulti.EizOvE1=EizOvE1;
    stResMulti.EpixOvE1=EpixOvE1;
    stResMulti.EpizOvE1=EpizOvE1;
else % TE waves
    stResMulti.rS=rF;
    stResMulti.tS=tF;
    stResMulti.EiyOvE1y=EiyOvE1y;
    stResMulti.EpiyOvE1y=EpiyOvE1y;
    stResMulti.HixOvH1=HixOvH1;
    stResMulti.HizOvH1=HizOvH1;
    stResMulti.HpixOvH1=HpixOvH1;
    stResMulti.HpizOvH1=HpizOvH1;
end






    