% Solves the EM problem of excitation of PSPP in the Otto configuration
% The Otto configuration is illustrated in Fig. 3.12(a)
% This is equivalent to a three-multilayer planar system (Prism/Dielectric/Metal).
% Note that the incident wave propagates in the prism, i.e the coupling
% from air to prism must be considered separately (see Sec. 3.4.5).
% This script simply defines the relevant parameters, calls the function
% PlnRefMulti to solve the EM problem, and provides examples of plots
% of the results.
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

%%%%%%%%%%%%%%%%%%
% Parameters:
%%%%%%%%%%%%%%%%%%

% Wavelengths and angles of incidence (inside the prism)
% lambda (in nm) is column vector
lambda=transpose(400:1:800); 
%lambda=633;

% aideg is row vector; angle of incidence in degrees
aideg=0:1:89; % broad angle range
%aideg=32:0.01:40; % ok for 633nm, nM=1.0
%aideg=48:0.005:60; % ok for 633nm, nM=1.33

% Gap thickness in nm, i.e. thickness of dielectric region
Lgap=500; % in nm, ok for 633nm, nM=1.33


% Refractive indices:

% Prism, assumed a constant here
nP=1.766; % Sapphire

% Dielectric gap (for PSPPs), assumed a constant here
%nM=1.0; % Air 
nM=1.33; % Water

% Epsilon of Metal (column vector)
epsMetal=epsAg(lambda); % Analytical expression for Ag
%epsMetal=epsAu(lambda); % Analytical expression for Au

%%%%%%%%%%%%%%%%%%%%%%%%%%
% Solution of the problem
%%%%%%%%%%%%%%%%%%%%%%%%%%

% Defines Otto configuration, 2 interfaces, 3 layers
% Prism/Dielectric/Metal
% all epsilons must be columns (lambda dependent)
% epsilon1 must be real positive
nNbSurf=2;
Cepsilon{1}=nP^2+0*lambda; % Prism
Cepsilon{2}=nM^2+0*lambda; % Dielectric for PSPP
Cepsilon{3}=epsMetal; % Metal
CL{1}=0; % interfaces positions
CL{2}=Lgap;

% solves the problem for TM waves
stResTM=PlnMultiRef ('TM',nNbSurf, lambda, Cepsilon, CL, aideg);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Examples of post-processing
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% see help of MultiRef for description of the results


%Reflectivity (reflection coefficient $R^p=|r^p|^2$)
% Rp is matrix [length(lambda) x length(aideg)]
Rp=abs(stResTM.rP).^2;

% Local field intensity EF outside metal
% i.e. on interface 2 outside
Mperp=stResTM.MoutPerp{2};
Mpara=stResTM.MoutPara{2};
% Total LFIEF (with respect to field amplitude IN PRISM)
M=Mperp+Mpara;

% plot examples

% 3D plot of Rp(aideg, lambda)
surf(aideg, lambda,Rp);

% 2D plots of Rp(lambda) and Rp(aideg)
scrsz = get(0,'ScreenSize'); % scrsz(3) contains screen width
figAspectRatio=3;
figWidth=3/4*scrsz(3);
figure('Name','OttoPSPP', ...
    'Position',[(scrsz(3)-figWidth)/2 scrsz(4)-150-figWidth/figAspectRatio figWidth figWidth/figAspectRatio]);
% plot of Rp(lambda) for given angle% plot of Rp(lambda) for given angle
subplot(1,2,1);
aideg_index=54;
plot(lambda,Rp(:,aideg_index));
title(['Wavelength-dependent reflection coefficient for angle: ' num2str(aideg(aideg_index)) ' degrees']);

% plot of Rp(aideg) for given lambda
subplot(1,2,2);
lambda_index=234;
plot(aideg,Rp(lambda_index,:));
title(['Angle-dependent reflection coefficient for lambda=' num2str(lambda(lambda_index)) ' nm']);
