function stAllM=PlnSinglePlaneDecayRateEFs(epsilonM,lambda,epsilon,d,nNbStep)
% Computes the total and radiative decay rate enhancement factors for a dipole emitting close to a single planar interface.
% See Sec. 4.4.3 for a definition of these decay rate EFs.
% The dipole must be in a non-absorbing dielectric (with epsilonM) at a
% distance d (in nm) from the interace with another material characterized by
% its dielectric function epsilon (in general complex for metals).
% Note that if the second region is also non-absorbing, the returned MRad
% only account for emission in the half-plane containing the dipole.
% 
% Parameters:
% - epsilonM:   scalar
%               relative epsilon of dielectric containing dipole
% - lambda:     scalar or column vector [L x 1]
% - epsilon:    scalar or column vectors [L x 1], must be same size as lambda
%               dielectric function epsilon(lambda) for second region
% - d:          scalar
%               distance of dipole from interface (in NANOMETERS, nm)
% - nNbStep:    scalar
%               Number of steps for integration (in each intervals)
%
% Returns:      structure with 6 fields, each a column vector[L x 1].
%               They contain the computed total, radiative, and total in the ESA, decay rate
%               EFs for dipoles perpendicular and parallel to the interface
%               for each wavelength
% - stAllM.MTotPerp
% - stAllM.MTotPara
% - stAllM.MRadPerp
% - stAllM.MRadPara
% - stAllM.MTotPerpESA
% - stAllM.MTotParaESA
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information


disp (['PlnSinglePlaneDecayRateEFs: computing decay rate EFs (d=' num2str(d) 'nm)...']);

nNbLambda=length(lambda);

zerolambda=0*lambda; % [L x 1]

epsilon2Vec=zerolambda+epsilon; % to make it [L x 1] if scalar
epsilon1Vec=zerolambda+epsilonM; % to make it [L x 1] if scalar

stAllM.MTotPerp=zerolambda;
stAllM.MTotPara=zerolambda;
stAllM.MRadPerp=zerolambda;
stAllM.MRadPara=zerolambda;

k0=2*pi./lambda; % [L x 1]
k1=k0.*sqrt(epsilon1Vec); % [L x 1]
k2=k0.*sqrt(epsilon2Vec); % [L x 1]

% Carry out integrations in three intervals with varying steps
% First: [0,1] (only one for MRad)
% Second: [1,sMid] 
% where sMid=max(2,|sqrt(epsilonIn)/sqrt(epsilonM)|)] 
% Third: [max(1,|sqrt(epsilonIn)/sqrt(epsilonM)|) sMax]
% where sMax=max(50+sMid, 10/(k1*d))
% This leads to good convergence properties, but additional
% tests must be carried out when necessary.
sStep1=1/nNbStep; % scalar, same for all
sVec01=0:sStep1:(1-sStep1+0.5*sStep1); % [1 x N]
indStep=1:nNbStep;
% the 0.5*sStep1 is used to avoid numerical problems leading to a [1 x N-1]
% vector rather than [1 x N]

% Loop through lambda to avoid memory problems for large nNbStep and
% nNbLambda
for ll=1:nNbLambda
    sMid=max(2, abs(k2(ll))./abs(k1(ll))); % [1 x 1]
    sStep2=(sMid-1)*sStep1; % [1 x 1]

    sVec1mid=(1+sStep2):sStep2:(sMid+0.5*sStep2); % [1 x N]

    sMax=max(50+sMid, 10/(k1(ll)*d)); % [1 x 1]
    sStep3=(sMax-sMid)*sStep1; % [1 x 1]

    sVecMidMax=(sMid+sStep3):sStep3:(sMax+0.5*sStep3); % [1 x N]
    sVec=[sVec01 sVec1mid, sVecMidMax]; % [1 x 3N]


    AuxInt3=sVec ./sqrt(1-sVec.^2); % [1 x 3N]
    AuxInt1=sVec.^2 .* AuxInt3; % [1 x 3N]
    AuxInt2= exp(2*i*d * (k1(ll) * sqrt(1-sVec.^2))); % [1 x 3N]

    k1z=sqrt( (k1(ll)^2) * (1-sVec.^2) ); % [1 x 3N]
    k2z=sqrt( (k2(ll)^2) - k1(ll)^2 * sVec.^2); % [1 x 3N]

    rP=(epsilon2Vec(ll)*k1z-epsilon1Vec(ll)*k2z)./ ...
        (epsilon2Vec(ll)*k1z+epsilon1Vec(ll)*k2z); % [1 x 3N]

    rS=(k1z-k2z)./(k1z+k2z); % [1 x 3N]

    PerpIntVec=real( AuxInt1 .*  rP .* AuxInt2 ); % [1 x 3N]
    PerpInt1=3/2*sStep1*sum(PerpIntVec(indStep)); % scalar
    PerpInt2=3/2*sStep2*sum(PerpIntVec(indStep+nNbStep)); % scalar
    PerpInt3=3/2*sStep3*sum(PerpIntVec(indStep+2*nNbStep)); % scalar
    stAllM.MTotPerp(ll)=1.0+PerpInt1+PerpInt2+PerpInt3;
    
    ParaIntVec=real( AuxInt3 .* (rS-(1-sVec.^2).*rP) .* AuxInt2 ); % matrix

    ParaInt1=3/4*sStep1*sum(ParaIntVec(indStep)); % scalar
    ParaInt2=3/4*sStep2*sum(ParaIntVec(indStep+nNbStep)); % scalar
    ParaInt3=3/4*sStep3*sum(ParaIntVec(indStep+2*nNbStep)); % scalar

    stAllM.MTotPara(ll)=1.0+ParaInt1+ParaInt2+ParaInt3;

    PerpIntRadVec=AuxInt1(indStep).*abs(rP(indStep)).^2; % [1 x N]
    PerpIntRad1=3/4*sStep1*sum(PerpIntRadVec); % scalar
    
    stAllM.MRadPerp(ll)=0.5+PerpIntRad1+PerpInt1; 

    ParaIntRadVec=sVec01.*(sqrt(1-sVec01.^2)) .* ...
        abs(rP(indStep)).^2+ AuxInt3(indStep).*abs(rS(indStep)).^2; % matrix
    ParaIntRad1=3/8*sStep1*sum(ParaIntRadVec); % scalar

    stAllM.MRadPara(ll)=0.5+ParaIntRad1+ParaInt1;


end

% Also calculates M_{Tot}^{Perp} and M_{Tot}^{Para} within the
% electrostatics approximation, following Eq. 6.13
% Get betaP from Eq. 6.8
betaP=(epsilon2Vec-epsilon1Vec)./(epsilon2Vec+epsilon1Vec); % [L x 1]

tmp=3/16 ./ (k1*d).^3 .* imag(betaP); % [L x 1]

stAllM.MTotPerpESA=1+2*tmp;
stAllM.MTotParaESA=1+tmp;

disp 'PlnSinglePlaneDecayRateEFs: done.'

